/*
 * RestrictedTextField
 * https://www.github.com/kloverde/jquery-RestrictedTextField
 *
 * Copyright (c) 2016, Kurtis LoVerde
 * All rights reserved.
 *
 * Donations:  https://paypal.me/KurtisLoVerde/10
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     1. Redistributions of source code must retain the above copyright
 *        notice, this list of conditions and the following disclaimer.
 *     2. Redistributions in binary form must reproduce the above copyright
 *        notice, this list of conditions and the following disclaimer in the
 *        documentation and/or other materials provided with the distribution.
 *     3. Neither the name of the copyright holder nor the names of its
 *        contributors may be used to endorse or promote products derived from
 *        this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

"use strict";

var testCases = [
   tc(  FieldType.ALPHA,                    "ignore_alpha_all",                     true,  Characters.ALL,  Characters.ALPHA,        Characters.ALPHA,         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ALPHA,                    "ignore_alpha_blank",                   true,  "",              "",                      "",                       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.UPPER_ALPHA,              "ignore_upperAlpha_all",                true,  Characters.ALL,  Characters.UPPER_ALPHA,  Characters.UPPER_ALPHA,   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.UPPER_ALPHA,              "ignore_upperAlpha_blank",              true,  "",              "",                      "",                       Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.LOWER_ALPHA,              "ignore_lowerAlpha_all",                true,  Characters.ALL,  Characters.LOWER_ALPHA,  Characters.LOWER_ALPHA,   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.LOWER_ALPHA,              "ignore_lowerAlpha_blank",              true,  "",              "",                      "",                       Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.ALPHA_SPACE,              "ignore_alphaSpace_all",                true,  Characters.ALL,  Characters.ALPHA_SPACE,  Characters.ALPHA_SPACE,   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ALPHA_SPACE,              "ignore_alphaSpace_blank",              true,  "",              "",                      "",                       Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.UPPER_ALPHA_SPACE,        "ignore_upperAlphaSpace_all",           true,  Characters.ALL,  Characters.UPPER_ALPHA_SPACE,  Characters.UPPER_ALPHA_SPACE,    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.UPPER_ALPHA_SPACE,        "ignore_upperAlphaSpace_blank",         true,  "",              "",                            "",                              Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.LOWER_ALPHA_SPACE,        "ignore_lowerAlphaSpace_all",           true,  Characters.ALL,  Characters.LOWER_ALPHA_SPACE,  Characters.LOWER_ALPHA_SPACE,    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.LOWER_ALPHA_SPACE,        "ignore_lowerAlphaSpace_blank",         true,  "",              "",                            "",                              Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.ALPHANUMERIC,             "ignore_alphanumeric_all",              true,  Characters.ALL,  Characters.ALPHANUMERIC,       Characters.ALPHANUMERIC,         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ALPHANUMERIC,             "ignore_alphanumeric_blank",            true,  "",              "",                            "",                              Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.UPPER_ALPHANUMERIC,       "ignore_upperAlphanumeric_all",         true,  Characters.ALL,  Characters.UPPER_ALPHANUMERIC,  Characters.UPPER_ALPHANUMERIC,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.UPPER_ALPHANUMERIC,       "ignore_upperAlphaNumeric_blank",       true,  "",              "",                             "",                             Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.LOWER_ALPHANUMERIC,       "ignore_lowerAlphanumeric_all",         true,  Characters.ALL,  Characters.LOWER_ALPHANUMERIC,  Characters.LOWER_ALPHANUMERIC,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.LOWER_ALPHANUMERIC,       "ignore_lowerAlphanumeric_blank",       true,  "",              "",                             "",                             Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.ALPHANUMERIC_SPACE,       "ignore_alphanumericSpace_all",         true,  Characters.ALL,  Characters.ALPHANUMERIC_SPACE,  Characters.ALPHANUMERIC_SPACE,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ALPHANUMERIC_SPACE,       "ignore_alphanumericSpace_blank",       true,  "",              "",                             "",                             Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.UPPER_ALPHANUMERIC_SPACE, "ignore_upperAlphanumericSpace_all",    true,  Characters.ALL,  Characters.UPPER_ALPHANUMERIC_SPACE,  Characters.UPPER_ALPHANUMERIC_SPACE,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.UPPER_ALPHANUMERIC_SPACE, "ignore_upperAlphanumericSpace_blank",  true,  "",              "",                                   "",                                   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.LOWER_ALPHANUMERIC_SPACE, "ignore_lowerAlphanumericSpace_all",    true,  Characters.ALL,  Characters.LOWER_ALPHANUMERIC_SPACE,  Characters.LOWER_ALPHANUMERIC_SPACE,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.LOWER_ALPHANUMERIC_SPACE, "ignore_lowerAlphanumericSpace_blank",  true,  "",              "",                                   "",                                   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.INT,                  "ignore_int_all",                           true,  Characters.ALL,  Characters.NUMBERS_END_ZERO,  Characters.NUMBERS_END_ZERO,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.INT,                  "ignore_int_blank",                         true,  "",       "",       "",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.INT,                  "ignore_int_multipleZero",                  true,  "000",    "000",    "000",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.INT,                  "ignore_int_positive_leadingZero",          true,  "001",    "001",    "001",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.INT,                  "ignore_int_dash",                          true,  "-",      "-",      "-",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.INT,                  "ignore_int_negative_negativeZero",         true,  "-0",     "-0",     "-0",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.INT,                  "ignore_int_negative",                      true,  "-123",   "-123",   "-123",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.INT,                  "ignore_int_doubleNegative",                true,  "--1",    "-1",     "-1",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.INT,                  "ignore_int_floatingPoint",                 true,  "1.23",   "123",    "123",    Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.POSITIVE_INT,         "ignore_positiveInt",                       true,  Characters.ALL,  Characters.NUMBERS_END_ZERO,  Characters.NUMBERS_END_ZERO,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_INT,         "ignore_positiveInt_all",                   true,  "",       "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_INT,         "ignore_positiveInt_multipleZero",          true,  "000",    "000",   "000",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_INT,         "ignore_positiveInt_leadingZero",           true,  "001",    "001",   "001",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_INT,         "ignore_positiveInt_negative",              true,  "-1",     "1",     "1",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_INT,         "ignore_positiveInt_floatingPoint",         true,  "1.23",   "123",   "123",   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.NEGATIVE_INT,         "ignore_negativeInt",                       true,  "-" + Characters.ALPHANUMERIC,
                                                                                           "-" + Characters.NUMBERS_END_ZERO,
                                                                                           "-" + Characters.NUMBERS_END_ZERO,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_INT,         "ignore_negativeInt_blank",                 true,  "",              "",           "",  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_INT,         "ignore_negativeInt_positives",             true,  Characters.NUMBERS_END_ZERO,   "0",      "0",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_INT,         "ignore_negativeInt_dash",                  true,  "-",       "-",      "-",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_INT,         "ignore_negativeInt_negativeZero",          true,  "-0",      "-0",     "-0",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_INT,         "ignore_negativeInt_doubleDash1",           true,  "--123",   "-123",   "-123",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_INT,         "ignore_negativeInt_doubleDash2",           true,  "-12-3",   "-123",   "-123",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_INT,         "ignore_negativeInt_floatingPoint",         true,  "-1.23",   "-123",   "-123",   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.STRICT_INT,           "ignore_strictInt_all",                      true,  Characters.ALL,  Characters.NUMBERS_END_ZERO, Characters.NUMBERS_END_ZERO,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_INT,           "ignore_strictInt_blank",                    true,  "",             "",         "",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_INT,           "ignore_strictInt_multipleZero",             true,  "000",          "000",      "000",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_INT,           "ignore_strictInt_positive_leadingZero",     true,  "001",          "001",      "001",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_INT,           "ignore_strictInt_negative_leadingZero",     true,  "-004.32",      "-00432",   "-00432",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_INT,           "ignore_strictInt_dash",                     true,  "-",            "-",        "-",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_INT,           "ignore_strictInt_negative_negativeZero",    true,  "-0",           "-0",       "-0",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_INT,           "ignore_strictInt_negative",                 true,  "-123",         "-123",     "-123",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_INT,           "ignore_strictInt_doubleNegative",           true,  "--1",          "-1",       "-1",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_INT,           "ignore_strictInt_floatingPoint",            true,  "1.23",         "123",      "123",      Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.STRICT_POSITIVE_INT,  "ignore_strictPositiveInt",                  true,  Characters.ALL_EXCEPT_MINUS,  Characters.NUMBERS_END_ZERO,  Characters.NUMBERS_END_ZERO,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_INT,  "ignore_strictPositiveInt_blank",            true,  "",       "",     "",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_INT,  "ignore_strictPositiveInt_multipleZero",     true,  "000",    "000",  "000",  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_INT,  "ignore_strictPositiveInt_leadingZero",      true,  "001",    "001",  "001",  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_INT,  "ignore_strictPositiveInt_negative",         true,  "-1",     "1",    "1",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_INT,  "ignore_strictPositiveInt_floatingPoint",    true,  "1.23",   "123",  "123",  Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.STRICT_NEGATIVE_INT,  "ignore_strictNegativeInt",                  true,  "-" + Characters.ALPHANUMERIC,
                                                                                                                "-" + Characters.NUMBERS_END_ZERO,
                                                                                                                "-" + Characters.NUMBERS_END_ZERO,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,  "ignore_strictNegativeInt_positives",        true,  Characters.NUMBERS_END_ZERO,    "0",       "0",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,  "ignore_strictNegativeInt_blank",            true,  "",          "",        "",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,  "ignore_strictNegativeInt_zero",             true,  "0",         "0",       "0",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,  "ignore_strictNegativeInt_dash",             true,  "-",         "-",       "-",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,  "ignore_strictNegativeInt_negativeZero",     true,  "-0",        "-0",      "-0",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,  "ignore_strictNegativeInt_doubleDash1",      true,  "--123",     "-123",     "-123",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,  "ignore_strictNegativeInt_doubleDash2",      true,  "-12-3",     "-123",     "-123",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,  "ignore_strictNegativeInt_noFloatingPoint",  true,  "-1.23",     "-123",     "-123",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,  "ignore_strictNegativeInt_leadingZero",      true,  "-004.32",   "-00432",   "-00432",   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.FLOAT,  "ignore_float_all",                  true,  Characters.ALL_EXCEPT_MINUS + "." + Characters.ALL_EXCEPT_MINUS,
                                                                      Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_END_ZERO,
                                                                      Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_END_ZERO,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_blank",                true,  "",              "",              "",              Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_posInt",               true,  "123",           "123",           "123",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_negInt",               true,  "-123",          "-123",          "-123",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_negFloat",             true,  "-1023.456789",  "-1023.456789",  "-1023.456789",  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_zero1",                true,  "0",             "0",             "0",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_zero2",                true,  "0.0",           "0.0",           "0.0",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_zero3",                true,  ".0",            ".0",            ".0",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_leadingDoubleZero1",   true,  "00",            "00",            "00",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_leadingDoubleZero2",   true,  "00.0",          "00.0",          "00.0",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_extraTrailingZero1",   true,  "0.00",          "0.00",          "0.00",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_extraTrailingZero2",   true,  "12.3450",       "12.3450",       "12.3450",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_extraTrailingZero3",   true,  "12.34500",      "12.34500",      "12.34500",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_leadingDoubleZeros3",  true,  "-00.0",         "-00.0",         "-00.0",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_negativeZero1",        true,  "-0",            "-0",            "-0",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_negativeZero2",        true,  "-.0",           "-.0",           "-.0",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_negativeZero3",        true,  "-0.000000",     "-0.000000",     "-0.000000",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_negativeZero4",        true,  "-0.0",          "-0.0",          "-0.0",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_dash",                 true,  "-",             "-",             "-",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.FLOAT,  "ignore_float_doubleDash",           true,  "--",            "-",             "-",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.FLOAT,  "ignore_float_dashDot",              true,  "-.",            "-.",            "-.",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.FLOAT,  "ignore_float_endInDot",             true,  "-1.",           "-1.",           "-1.",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.FLOAT,  "ignore_float_dashInWrongPlace1",    true,  "1-.2",          "1.2",           "1.2",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_dashInWrongPlace2",    true,  "1.-2",          "1.2",           "1.2",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_dashInWrongPlace3",    true,  "1.2-",          "1.2",           "1.2",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_dashInWrongPlace4",    true,  "1.-0",          "1.0",           "1.0",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_doubleDot1",           true,  "..",            ".",             ".",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.FLOAT,  "ignore_float_doubleDot2",           true,  "1..2",          "1.2",           "1.2",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_dotsEverywhere",       true,  ".1.2.",         ".12",           ".12",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "ignore_float_forceBlank",           true,  "a",             "",              "",              Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_all",  true,  Characters.ALL_EXCEPT_MINUS + "." + Characters.ALL_EXCEPT_MINUS,
                                                                       Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_END_ZERO,
                                                                       Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_END_ZERO,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_blank",                true,  "",              "",              "",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_posInt",               true,  "123",           "123",           "123",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_negInt",               true,  "-123",          "123",           "123",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_negFloat",             true,  "-1023.456789",  "1023.456789",   "1023.456789",  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_zero1",                true,  "0",             "0",             "0",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_zero2",                true,  "0.0",           "0.0",           "0.0",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_zero3",                true,  ".0",            ".0",            ".0",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_leadingDoubleZero1",   true,  "00",            "00",            "00",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_leadingDoubleZero2",   true,  "00.0",          "00.0",          "00.0",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_extraTrailingZero1",   true,  "0.00",          "0.00",          "0.00",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_extraTrailingZero2",   true,  "12.3450",       "12.3450",       "12.3450",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_extraTrailingZero3",   true,  "12.34500",      "12.34500",      "12.34500",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_leadingDoubleZeros3",  true,  "-00.0",         "00.0",          "00.0",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_negativeZero1",        true,  "-0",            "0",             "0",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_negativeZero2",        true,  "-.0",           ".0",            ".0",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_negativeZero3",        true,  "-0.000000",     "0.000000",      "0.000000",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_negativeZero4",        true,  "-0.0",          "0.0",           "0.0",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_dash",                 true,  "-",             "",              "",             Event.VALIDATION_SUCCESS  ),
   //{ FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_doubleDash",           true,  "--",            "",              "",             Event.VALIDATION_SUCCESS  ),  // already testing standalone hyphen in this set
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_dashDot",              true,  "-.",            ".",             ".",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_endInDot",             true,  "-1.",           "1.",            "1.",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_dashInWrongPlace1",    true,  "1-.2",          "1.2",           "1.2",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_dashInWrongPlace2",    true,  "1.-2",          "1.2",           "1.2",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_dashInWrongPlace3",    true,  "1.2-",          "1.2",           "1.2",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_dashInWrongPlace4",    true,  "1.-0",          "1.0",           "1.0",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_doubleDot1",           true,  "..",            ".",             ".",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_doubleDot2",           true,  "1..2",          "1.2",           "1.2",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_dotsEverywhere",       true,  ".1.2.",         ".12",           ".12",          Event.VALIDATION_SUCCESS  ),
   //{ FieldType.POSITIVE_FLOAT,  "ignore_positiveFloat_forceBlank",           true,  "a",             "",              "",             Event.VALIDATION_SUCCESS  ),  // already testing blank in this set

   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_all",  true,  "-" + Characters.ALL_EXCEPT_MINUS + "." + Characters.ALL_EXCEPT_MINUS,
                                                                       "-" + Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_END_ZERO,
                                                                       "-" + Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_END_ZERO,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_blank",                true,  "",              "",              "",               Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_posInt",               true,  "123",           "",              "",               Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_negInt",               true,  "-123",          "-123",          "-123",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_negFloat",             true,  "-1023.456789",  "-1023.456789",  "-1023.456789",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_zero1",                true,  "0",             "0",             "0",              Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_zero2",                true,  "0.0",           "0.0",           "0.0",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_zero3",                true,  ".0",            ".0",            ".0",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_leadingDoubleZero1",   true,  "00",            "00",            "00",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_leadingDoubleZero2",   true,  "00.0",          "00.0",          "00.0",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_extraTrailingZero1",   true,  "0.00",          "0.00",          "0.00",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_extraTrailingZero2",   true,  "12.3450",       ".0",            ".0",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_extraTrailingZero3",   true,  "-12.34500",     "-12.34500",     "-12.34500",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_leadingDoubleZeros3",  true,  "-00.0",         "-00.0",         "-00.0",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_negativeZero1",        true,  "-0",            "-0",            "-0",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_negativeZero2",        true,  "-.0",           "-.0",           "-.0",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_negativeZero3",        true,  "-0.000000",     "-0.000000",     "-0.000000",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_negativeZero4",        true,  "-0.0",          "-0.0",          "-0.0",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_dash",                 true,  "-",             "-",             "-",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_doubleDash",           true,  "--",            "-",             "-",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_dashDot",              true,  "-.",            "-.",            "-.",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_endInDot",             true,  "-1.",           "-1.",           "-1.",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_dashInWrongPlace1",    true,  "1-.2",          "-.2",           "-.2",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_dashInWrongPlace2",    true,  "1.-2",          ".",             ".",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_dashInWrongPlace3",    true,  "1.2-",          ".",             ".",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_dashInWrongPlace4",    true,  "1.-0",          ".0",            ".0",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_doubleDot1",           true,  "..",            ".",             ".",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_doubleDot2",           true,  "1..2",          ".",             ".",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_dotsEverywhere",       true,  ".1.2.",         ".",             ".",              Event.VALIDATION_FAILED  ),
   //{ FieldType.NEGATIVE_FLOAT,  "ignore_negativeFloat_forceBlank",           true,  "a",             "",              "",               Event.VALIDATION_SUCCESS  ),  // already testing blank in this set

   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_all",                  true,  Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_END_ZERO,
                                                                                   Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_END_ZERO,
                                                                                   Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_END_ZERO,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_blank",                true,  "",              "",              "",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_posInt",               true,  "123",           "123",           "123", Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_negInt",               true,  "-123",          "-123",          "-123",  Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_negFloat",             true,  "-1023.456789",  "-1023.456789",  "-1023.456789",  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_zero1",                true,  "0",             "0",             "0",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_zero2",                true,  "0.0",           "0.0",           "0.0",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_zero3",                true,  ".0",            ".0",            ".0",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_leadingZero1",         true,  "00",            "00",            "00",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_leadingZero2",         true,  "00.0",          "00.0",          "00.0",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_leadingZero3",         true,  "0123.456",      "0123.456",      "0123.456",  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_extraTrailingZero1",   true,  "0.00",          "0.00",          "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_extraTrailingZero2",   true,  "12.3450",       "12.3450",       "12.3450",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_leadingDoubleZeros3",  true,  "-00.0",         "-00.0",         "-00.0",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_negativeZero1",        true,  "-0",            "-0",            "-0",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_negativeZero2",        true,  "-0.00",         "-0.00",         "-0.00",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_dash",                 true,  "-",             "-",             "-",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_doubleDash",           true,  "--",            "-",             "-",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_dashDot",              true,  "-.",            "-.",            "-.",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_endInDot",             true,  "-1.",           "-1.",           "-1.",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_dashInWrongPlace1",    true,  "1-.2",          "1.2",           "1.2",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_dashInWrongPlace2",    true,  "1.-2",          "1.2",           "1.2",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_dashInWrongPlace3",    true,  "1.2-",          "1.2",           "1.2",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_dashInWrongPlace4",    true,  "1.-0",          "1.0",           "1.0",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_doubleDot1",           true,  "..",            ".",             ".",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_doubleDot2",           true,  "1..2",          "1.2",           "1.2",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_dotsEverywhere",       true,  ".1.2.",         ".12",           ".12",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,  "ignore_strictFloat_forceBlank",           true,  "a",             "",              "",          Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_all",                  true,   Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_START_ZERO,
                                                                                                     Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_START_ZERO,
                                                                                                     Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_START_ZERO,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_blank",                true,   "",              "",              "",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_posInt",               true,   "123",           "123",           "123",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_negInt",               true,   "-123",          "123",           "123",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_negFloat",             true,   "-1023.456789",  "1023.456789",   "1023.456789",  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_zero1",                true,   "0",             "0",             "0",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_zero2",                true,   "0.0",           "0.0",           "0.0",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_zero3",                true,   ".0",            ".0",            ".0",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_leadingZero1",         true,   "00",            "00",            "00",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_leadingZero2",         true,   "00.0",          "00.0",          "00.0",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_leadingZero3",         true,   "0123.456",      "0123.456",      "0123.456",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_extraTrailingZero1",   true,   "0.00",          "0.00",          "0.00",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_extraTrailingZero2",   true,   "12.3450",       "12.3450",       "12.3450",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_leadingDoubleZeros3",  true,   "-00.0",         "00.0",          "00.0",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_negativeZero",         true,   "-0.000000",     "0.000000",      "0.000000",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_dash",                 true,   "-",             "",              "",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_dashDot",              true,   ".",             ".",             ".",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_doubleDot1",           true,   "..",            ".",             ".",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_doubleDot2",           true,   "1..2",          "1.2",           "1.2",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_dotsEverywhere",       true,   ".1.2.",         ".12",           ".12",          Event.VALIDATION_SUCCESS  ),
   //{ FieldType.STRICT_POSITIVE_FLOAT,  "ignore_strictPositiveFloat_forceBlank",           true,   "a",             "",              "",             Event.VALIDATION_SUCCESS  ),  // already testing blank in this set

   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_all",                   true,   "-" + Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_START_ZERO,
                                                                                                      "-" + Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_START_ZERO,
                                                                                                      "-" + Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_START_ZERO,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_blank",                 true,   "",              "",              "", Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_posInt",                true,   "123",           "",              "", Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_negInt",                true,   "-123",          "-123",          "-123",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_zero1",                 true,   "0",             "0",             "0",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_zero2",                 true,   "0.0",           "0.0",           "0.0",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_zero3",                 true,   ".0",            ".0",            ".0",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_leadingZero1",          true,   "00",            "00",            "00",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_leadingZero2",          true,   "00.0",          "00.0",          "00.0",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_leadingZero3",          true,   "0123.456",      "0.",            "0.",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_extraTrailingZero1",    true,   "0.00",          "0.00",          "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_extraTrailingZero2",    true,   "12.3450",       ".0",            ".0",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_leadingDoubleZeros3",   true,   "-00.0",         "-00.0",         "-00.0",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_negativeZero",          true,   "-0.000000",     "-0.000000",     "-0.000000",  Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_dash",                  true,   "-",             "-",             "-",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_dashDot",               true,   ".",             ".",             ".",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_doubleDot1",            true,   "..",            ".",             ".",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_doubleDot2",            true,   "-1..2",         "-1.2",          "-1.2",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_dotsEverywhere",        true,   "-.1.2.",        "-.12",          "-.12",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,  "ignore_strictNegativeFloat_letter1",               true,   "1.a",           ".",             ".",          Event.VALIDATION_FAILED  ),

   tc(  FieldType.MONEY,   "ignore_money_all",                   true,   Characters.ALL_EXCEPT_MINUS + ".01",
                                                                         Characters.NUMBERS_END_ZERO + ".01",
                                                                         Characters.NUMBERS_END_ZERO + ".01",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_blank",                 true,   "",            "",          "",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_negInt",                true,   "-123",        "-123",      "-123.00",  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_zero1",                 true,   "0",           "0",         "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_zero2",                 true,   "0.0",         "0.0",       "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_zero3",                 true,   ".0",          ".0",        "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_leadingZero1",          true,   "00",          "00",        "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_leadingZero2",          true,   "00.0",        "00.0",      "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_leadingZero3",          true,   "0123.456",    "0123.45",   "123.45",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_extraTrailingZero1",    true,   "0.00",        "0.00",      "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_extraTrailingZero2",    true,   "12.3450",     "12.34",     "12.34",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_leadingDoubleZeros3",   true,   "-00.0",       "-00.0",     "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_negativeZero",          true,   "-0.000000",   "-0.00",     "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_dash",                  true,   "-",           "-",         "-",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.MONEY,   "ignore_money_dashDot",               true,   ".",           ".",         ".",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.MONEY,   "ignore_money_doubleDot1",            true,   "..",          ".",         ".",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.MONEY,   "ignore_money_doubleDot2",            true,   "-1..2",       "-1.2",      "-1.20",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_dotsEverywhere",        true,   "-.1.2.",      "-.12",      "-0.12",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_letter1",               true,   "1.a",         "1.",        "1.",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.MONEY,   "ignore_money_1",                     true,   ".2",          ".2",        "0.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_2",                     true,   ".20",         ".20",       "0.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_3",                     true,   "0.2",         "0.2",       "0.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_4",                     true,   "0.20",        "0.20",      "0.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_5",                     true,   "1.2",         "1.2",       "1.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_6",                     true,   "1.23",        "1.23",      "1.23",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_7",                     true,   "-.2",         "-.2",       "-0.20",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "ignore_money_8",                     true,   "-0.2",        "-0.2",      "-0.20",    Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_all",                   true,   Characters.ALL_EXCEPT_MINUS + "." + "01",
                                                                                          Characters.NUMBERS_END_ZERO + ".01",
                                                                                          Characters.NUMBERS_END_ZERO + ".01",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_blank",                 true,   "",           "",          "",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_space",                 true,   " ",          "",          "",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_negInt",                true,   "-123",       "123",       "123.00",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_zero1",                 true,   "0",          "0",         "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_zero2",                 true,   "0.0",        "0.0",       "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_zero3",                 true,   ".0",         ".0",        "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_leadingZero1",          true,   "00",         "00",        "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_leadingZero2",          true,   "00.0",       "00.0",      "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_leadingZero3",          true,   "0123.456",   "0123.45",   "123.45",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_zeroDotZeroZero",       true,   "0.00",       "0.00",      "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_extraTrailingDigits",   true,   "12.3450",    "12.34",     "12.34",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_leadingDoubleZeros",    true,   "00.0",       "00.0",      "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_extraTrailingZeros",    true,   "0.000000",   "0.00",      "0.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_dash",                  true,   "-",          "",          "",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_dashDot",               true,   ".",          ".",         ".",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_doubleDot1",            true,   "..",         ".",         ".",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_doubleDot2",            true,   "1..2",       "1.2",       "1.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_dotsEverywhere",        true,   ".1.2.",      ".12",       "0.12",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_letter1",               true,   "1.a",        "1.",        "1.",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_1",                     true,   ".2",          ".2",        "0.20",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_2",                     true,   ".20",        ".20",       "0.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_3",                     true,   "0.2",        "0.2",       "0.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_4",                     true,   "0.20",       "0.20",      "0.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_5",                     true,   "1.2",        "1.2",       "1.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "ignore_positiveMoney_6",                     true,   "1.23",       "1.23",      "1.23",     Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_all",                   true,   "-" + Characters.ALL_EXCEPT_MINUS + "." + "01",
                                                                                          "-" + Characters.NUMBERS_END_ZERO + ".01",
                                                                                          "-" + Characters.NUMBERS_END_ZERO + ".01",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_blank",                 true,   "",            "",           "",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_space",                 true,   " ",           "",           "",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_negInt",                true,   "-123",        "-123",       "-123.00",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_posInt",                true,   "123",         "",           "",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_zero1",                 true,   "0",           "0",          "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_zero2",                 true,   "0.0",         "0.0",        "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_zero3",                 true,   ".0",          ".0",         "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_leadingZero1",          true,   "00",          "00",         "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_leadingZero2",          true,   "00.0",        "00.0",       "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_leadingZero3",          true,   "-0123.456",   "-0123.45",   "-123.45",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_zeroDotZeroZero",       true,   "-0.00",       "-0.00",      "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_extraTrailingDigits",   true,   "-12.3450",    "-12.34",     "-12.34",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_leadingDoubleZeros",    true,   "00.0",        "00.0",       "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_extraTrailingZeros",    true,   "0.000000",    "0.00",       "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_dash",                  true,   "-",           "-",          "-",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_dashDot",               true,   ".",           ".",          ".",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_doubleDot1",            true,   "..",          ".",          ".",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_doubleDot2",            true,   "-1..2",       "-1.2",       "-1.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_dotsEverywhere",        true,   "-.1.2.",      "-.12",       "-0.12",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_letter1",               true,   "-1.a",        "-1.",        "-1.",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_1",                     true,   "-.2",         "-.2",        "-0.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_2",                     true,   "-.20",        "-.20",       "-0.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_3",                     true,   "-0.2",        "-0.2",       "-0.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_4",                     true,   "-0.20",       "-0.20",      "-0.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_5",                     true,   "-1.2",        "-1.2",       "-1.20",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "ignore_negativeMoney_6",                     true,   "-1.23",       "-1.23",      "-1.23",     Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accounting_money_all",                  true,   Characters.ALL + "." + Characters.NUMBERS_END_ZERO,
                                                                                              Characters.NUMBERS_END_ZERO + ".12",
                                                                                              Characters.NUMBERS_END_ZERO + ".12",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_space",                 true,   " ",           "",           "",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_dash",                  true,   "-",           "",           "",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_negInt",                true,   "(123)",       "(123)",      "(123.00)",  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_posInt",                true,   "123",         "123",        "123.00",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_zero1",                 true,   "0",           "0",          "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_zero2",                 true,   "0.0",         "0.0",        "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_zero3",                 true,   ".0",          ".0",         "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_leadingZero1",          true,   "00",          "00",         "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_leadingZero2",          true,   "00.0",        "00.0",       "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_leadingZero3",          true,   "(0123.456)",  "(0123.45)",  "(123.45)",  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_extraTrailingZeros1",   true,   "0.000000",    "0.00",       "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_extraTrailingZeros2",   true,   "(0.000000)",  "(0.00)",     "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_dashDot",               true,   ".",           ".",          ".",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_doubleDot1",            true,   "..",          ".",          ".",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_doubleDot2",            true,   "(1..2)",      "(1.2)",      "(1.20)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_dotsEverywhere",        true,   "(.1.2.)",     "(.12)",      "(0.12)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_letter1",               true,   "(1.a)",       "(1.",        "(1.",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_1",                     true,   "(.2)",        "(.2)",       "(0.20)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_2",                     true,   "(.20)",       "(.20)",      "(0.20)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_3",                     true,   "(0.2)",       "(0.2)",      "(0.20)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_4",                     true,   "(0.20)",      "(0.20)",     "(0.20)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_5",                     true,   "(1.2)",       "(1.2)",      "(1.20)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_6",                     true,   "(1.23)",      "(1.23)",     "(1.23)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_noClosingParen",        true,   "(1.23",       "(1.23",      "(1.23",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_noOpeningParen",        true,   "1.23)",       "1.23",       "1.23",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_nonDigit1",             true,   "1.a",         "1.",         "1.",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.ACCOUNTING_MONEY,   "ignore_accountingMoney_nonDigit2",             true,   "(1.a",        "(1.",        "(1.",       Event.VALIDATION_FAILED  ),

   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_all",                   true,   "(" + Characters.ALPHANUMERIC + Characters.SYMBOLS_EXCEPT_PARENS + "." + Characters.NUMBERS_END_ZERO + ")",
                                                                                                               "(" + Characters.NUMBERS_END_ZERO + ".12" + ")",
                                                                                                               "(" + Characters.NUMBERS_END_ZERO + ".12" + ")",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_space",                 true,   " ",           "",           "",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_dash",                  true,   "-",           "",           "",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_negInt",                true,   "(123)",       "(123)",      "(123.00)",  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_posInt",                true,   "123",         "",           "",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_posFloat1",             true,   "1.23",        ".",          ".",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_posFloat2",             true,   "1.2",         ".",          ".",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_zero1",                 true,   "0",           "0",          "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_zero2",                 true,   "0.0",         "0.0",        "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_zero3",                 true,   ".0",          ".0",         "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_leadingZero1",          true,   "00",          "00",         "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_leadingZero2",          true,   "00.0",        "00.0",       "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_leadingZero3",          true,   "(0123.456)",  "(0123.45)",  "(123.45)",  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_extraTrailingZeros1",   true,   "0.000000",    "0.00",       "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_extraTrailingZeros2",   true,   "(0.000000)",  "(0.00)",     "0.00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_dashDot",               true,   ".",           ".",          ".",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_doubleDot1",            true,   "..",          ".",          ".",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_doubleDot2",            true,   "(1..2)",      "(1.2)",      "(1.20)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_dotsEverywhere",        true,   "(.1.2.)",     "(.12)",      "(0.12)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_letter1",               true,   "(1.a)",       "(1.",        "(1.",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_1",                     true,   "(.2)",        "(.2)",       "(0.20)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_2",                     true,   "(.20)",       "(.20)",      "(0.20)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_3",                     true,   "(0.2)",       "(0.2)",      "(0.20)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_4",                     true,   "(0.20)",      "(0.20)",     "(0.20)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_5",                     true,   "(1.2)",       "(1.2)",      "(1.20)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_6",                     true,   "(1.23)",      "(1.23)",     "(1.23)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_noClosingParen",        true,   "(1.23",       "(1.23",      "(1.23",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_noOpeningParen",        true,   "1.23)",       ".",          ".",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_nonDigit1",             true,   "1.a",         ".",          ".",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "ignore_negativeAccountingMoney_nonDigit2",             true,   "(1.a",        "(1.",        "(1.",       Event.VALIDATION_FAILED  ),

   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_prefix34_length15",               true,   "342466101232205",         "342466101232205",   "342466101232205",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_prefix37_length15",               true,   "376766541844884",         "376766541844884",   "376766541844884",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_prefix34_invalidLength14",        true,   "34351314365583",          "34351314365583",    "34351314365583",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_prefix34_invalidLength16",        true,   "3418170037118164",        "341817003711816",   "341817003711816",   Event.VALIDATION_FAILED  ),  // Input is Luhn-valid; accepted input is not
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_prefix37_invalidLength14",        true,   "37124610876877",          "37124610876877",    "37124610876877",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_prefix37_invalidLength16",        true,   "3731310754648247",        "373131075464824",   "373131075464824",   Event.VALIDATION_FAILED  ),  // Input is Luhn-valid; accepted input is not
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_prefix34_length15_invalidChars",  true,   "a#- 34246610G1232_205$",  "342466101232205",   "342466101232205",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix1",                  true,   "1",                       "",                  "",                  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix2",                  true,   "2",                       "",                  "",                  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix30",                 true,   "30",                      "3",                 "3",                 Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix31",                 true,   "31",                      "3",                 "3",                 Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix32",                 true,   "32",                      "3",                 "3",                 Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix33",                 true,   "33",                      "3",                 "3",                 Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix35",                 true,   "35",                      "3",                 "3",                 Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix36",                 true,   "36",                      "3",                 "3",                 Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix38",                 true,   "38",                      "3",                 "3",                 Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix39",                 true,   "30",                      "3",                 "3",                 Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix4",                  true,   "4",                       "",                  "",                  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix5",                  true,   "5",                       "",                  "",                  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix6",                  true,   "6",                       "",                  "",                  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix7",                  true,   "7",                       "",                  "",                  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix8",                  true,   "8",                       "",                  "",                  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix9",                  true,   "9",                       "",                  "",                  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "ignore_americanExpress_invalidPrefix0",                  true,   "0",                       "",                  "",                  Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.DISCOVER,   "ignore_discover_prefix6011_invalidLength15",       true,    "601113250018169",        "601113250018169",       "601113250018169",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix6011_invalidLength17",       true,    "60115061515701181",      "60115061515701181",     "60115061515701181",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix6011_invalidLength18",       true,    "601153441648503411",     "601153441648503411",    "601153441648503411",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix6011_invalidLength20",       true,    "60116551331382308537",   "6011655133138230853",   "6011655133138230853",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622126_invalidLength15",     true,    "622126004380672",        "622126004380672",       "622126004380672",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622126_invalidLength17",     true,    "62212641866873586",      "62212641866873586",     "62212641866873586",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622126_invalidLength18",     true,    "622126126327675339",     "622126126327675339",    "622126126327675339",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622126_invalidLength20",     true,    "62212687126061620224",   "6221268712606162022",   "6221268712606162022",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix644_invalidLength15",        true,    "644756606387446",        "644756606387446",       "644756606387446",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix644_invalidLength17",        true,    "64450658852328034",      "64450658852328034",     "64450658852328034",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix644_invalidLength18",        true,    "644738072107280359",     "644738072107280359",    "644738072107280359",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix644_invalidLength20",        true,    "64402134217085608883",   "6440213421708560888",   "6440213421708560888",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix645_invalidLength15",        true,    "645325137238525",        "645325137238525",       "645325137238525",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix645_invalidLength17",        true,    "64517041878408406",      "64517041878408406",     "64517041878408406",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix645_invalidLength18",        true,    "645171642626304087",     "645171642626304087",    "645171642626304087",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix645_invalidLength20",        true,    "64524161408182660722",   "6452416140818266072",   "6452416140818266072",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix646_invalidLength15",        true,    "646614811810553",        "646614811810553",       "646614811810553",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix646_invalidLength17",        true,    "64617426406243319",      "64617426406243319",     "64617426406243319",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix646_invalidLength18",        true,    "646630860588643713",     "646630860588643713",    "646630860588643713",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix646_invalidLength20",        true,    "64653583267408667474",   "6465358326740866747",   "6465358326740866747",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix647_invalidLength15",        true,    "647002003326407",        "647002003326407",       "647002003326407",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix647_invalidLength17",        true,    "64748211504450301",      "64748211504450301",     "64748211504450301",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix647_invalidLength18",        true,    "647881170248165527",     "647881170248165527",    "647881170248165527",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix647_invalidLength20",        true,    "64728284687165554189",   "6472828468716555418",   "6472828468716555418",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix648_invalidLength15",        true,    "648385588347065",        "648385588347065",       "648385588347065",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix648_invalidLength17",        true,    "64845326563124159",      "64845326563124159",     "64845326563124159",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix648_invalidLength18",        true,    "648255783171775421",     "648255783171775421",    "648255783171775421",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix648_invalidLength20",        true,    "64878048725744221688",   "6487804872574422168",   "6487804872574422168",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix649_invalidLength15",        true,    "649274143307286",        "649274143307286",       "649274143307286",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix649_invalidLength17",        true,    "64920403303634447",      "64920403303634447",     "64920403303634447",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix649_invalidLength18",        true,    "649438660560073667",     "649438660560073667",    "649438660560073667",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix649_invalidLength20",        true,    "64966668531581488089",   "6496666853158148808",   "6496666853158148808",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix65_invalidLength15",         true,    "658827080321400",        "658827080321400",       "658827080321400",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix65_invalidLength17",         true,    "65166676311003586",      "65166676311003586",     "65166676311003586",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix65_invalidLength18",         true,    "655527725847521157",     "655527725847521157",    "655527725847521157",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix65_invalidLength20",         true,    "65386161762781287755",   "6538616176278128775",   "6538616176278128775",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix65_length16",      true,   "6575446417684229",   "6575446417684229",   "6575446417684229",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix644_length16",     true,   "6446086757405046",   "6446086757405046",   "6446086757405046",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix645_length16",     true,   "6458278761757281",   "6458278761757281",   "6458278761757281",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix646_length16",     true,   "6466354430562814",   "6466354430562814",   "6466354430562814",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix647_length16",     true,   "6470602184708049",   "6470602184708049",   "6470602184708049",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix648_length16",     true,   "6483304456413458",   "6483304456413458",   "6483304456413458",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix649_length16",     true,   "6496726126383262",   "6496726126383262",   "6496726126383262",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix6011_length16",    true,   "6011307004482082",   "6011307004482082",   "6011307004482082",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622126_length16",  true,   "6221261410386500",   "6221261410386500",   "6221261410386500",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622127_length16",  true,   "6221277643065653",   "6221277643065653",   "6221277643065653",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622128_length16",  true,   "6221284403533482",   "6221284403533482",   "6221284403533482",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622129_length16",  true,   "6221293211512513",   "6221293211512513",   "6221293211512513",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622130_length16",  true,   "6221305000454689",   "6221305000454689",   "6221305000454689",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622131_length16",  true,   "6221316358870525",   "6221316358870525",   "6221316358870525",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622132_length16",  true,   "6221323737767562",   "6221323737767562",   "6221323737767562",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622133_length16",  true,   "6221330546330524",   "6221330546330524",   "6221330546330524",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622134_length16",  true,   "6221347440386279",   "6221347440386279",   "6221347440386279",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622135_length16",  true,   "6221352621221717",   "6221352621221717",   "6221352621221717",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622136_length16",  true,   "6221367607703801",   "6221367607703801",   "6221367607703801",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622137_length16",  true,   "6221375533305781",   "6221375533305781",   "6221375533305781",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622138_length16",  true,   "6221382411460589",   "6221382411460589",   "6221382411460589",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622139_length16",  true,   "6221395570172415",   "6221395570172415",   "6221395570172415",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622140_length16",  true,   "6221402818423020",   "6221402818423020",   "6221402818423020",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622141_length16",  true,   "6221411451127343",   "6221411451127343",   "6221411451127343",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622142_length16",  true,   "6221423054057322",   "6221423054057322",   "6221423054057322",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622143_length16",  true,   "6221438283466516",   "6221438283466516",   "6221438283466516",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622144_length16",  true,   "6221444707628061",   "6221444707628061",   "6221444707628061",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622145_length16",  true,   "6221453403610752",   "6221453403610752",   "6221453403610752",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622146_length16",  true,   "6221468651545617",   "6221468651545617",   "6221468651545617",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622147_length16",  true,   "6221470717125707",   "6221470717125707",   "6221470717125707",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622148_length16",  true,   "6221485713058223",   "6221485713058223",   "6221485713058223",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622149_length16",  true,   "6221493725082181",   "6221493725082181",   "6221493725082181",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622150_length16",  true,   "6221503561167423",   "6221503561167423",   "6221503561167423",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622151_length16",  true,   "6221514350367470",   "6221514350367470",   "6221514350367470",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622152_length16",  true,   "6221527532584556",   "6221527532584556",   "6221527532584556",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622153_length16",  true,   "6221534322562016",   "6221534322562016",   "6221534322562016",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622154_length16",  true,   "6221543441804324",   "6221543441804324",   "6221543441804324",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622155_length16",  true,   "6221553100230109",   "6221553100230109",   "6221553100230109",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622156_length16",  true,   "6221560076618779",   "6221560076618779",   "6221560076618779",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622157_length16",  true,   "6221574101488108",   "6221574101488108",   "6221574101488108",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622158_length16",  true,   "6221582425753255",   "6221582425753255",   "6221582425753255",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622159_length16",  true,   "6221595784278789",   "6221595784278789",   "6221595784278789",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622160_length16",  true,   "6221603811542456",   "6221603811542456",   "6221603811542456",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622161_length16",  true,   "6221615767422160",   "6221615767422160",   "6221615767422160",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622162_length16",  true,   "6221625653520118",   "6221625653520118",   "6221625653520118",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622163_length16",  true,   "6221634875573558",   "6221634875573558",   "6221634875573558",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622164_length16",  true,   "6221645581341262",   "6221645581341262",   "6221645581341262",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622165_length16",  true,   "6221654414500805",   "6221654414500805",   "6221654414500805",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622166_length16",  true,   "6221664576124088",   "6221664576124088",   "6221664576124088",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622167_length16",  true,   "6221678376480128",   "6221678376480128",   "6221678376480128",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622168_length16",  true,   "6221688880820552",   "6221688880820552",   "6221688880820552",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622169_length16",  true,   "6221690874077686",   "6221690874077686",   "6221690874077686",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622170_length16",  true,   "6221701541380518",   "6221701541380518",   "6221701541380518",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622171_length16",  true,   "6221714384827735",   "6221714384827735",   "6221714384827735",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622172_length16",  true,   "6221726023200017",   "6221726023200017",   "6221726023200017",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622173_length16",  true,   "6221731833685373",   "6221731833685373",   "6221731833685373",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622174_length16",  true,   "6221744442831072",   "6221744442831072",   "6221744442831072",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622175_length16",  true,   "6221755200726783",   "6221755200726783",   "6221755200726783",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622176_length16",  true,   "6221767774315182",   "6221767774315182",   "6221767774315182",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622177_length16",  true,   "6221772371484332",   "6221772371484332",   "6221772371484332",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622178_length16",  true,   "6221782230840129",   "6221782230840129",   "6221782230840129",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622179_length16",  true,   "6221797055483615",   "6221797055483615",   "6221797055483615",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622180_length16",  true,   "6221806115024424",   "6221806115024424",   "6221806115024424",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622181_length16",  true,   "6221812102071725",   "6221812102071725",   "6221812102071725",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622182_length16",  true,   "6221823758745033",   "6221823758745033",   "6221823758745033",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622183_length16",  true,   "6221834637752124",   "6221834637752124",   "6221834637752124",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622184_length16",  true,   "6221847854484437",   "6221847854484437",   "6221847854484437",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622185_length16",  true,   "6221853537378350",   "6221853537378350",   "6221853537378350",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622186_length16",  true,   "6221863826205370",   "6221863826205370",   "6221863826205370",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622187_length16",  true,   "6221877187715751",   "6221877187715751",   "6221877187715751",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622188_length16",  true,   "6221880055726363",   "6221880055726363",   "6221880055726363",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622189_length16",  true,   "6221891430012544",   "6221891430012544",   "6221891430012544",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622190_length16",  true,   "6221903057382538",   "6221903057382538",   "6221903057382538",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622191_length16",  true,   "6221912873374215",   "6221912873374215",   "6221912873374215",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622192_length16",  true,   "6221928427031663",   "6221928427031663",   "6221928427031663",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622193_length16",  true,   "6221930636263269",   "6221930636263269",   "6221930636263269",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622194_length16",  true,   "6221948605723824",   "6221948605723824",   "6221948605723824",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622195_length16",  true,   "6221953214428740",   "6221953214428740",   "6221953214428740",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622196_length16",  true,   "6221963723151865",   "6221963723151865",   "6221963723151865",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622197_length16",  true,   "6221976602555774",   "6221976602555774",   "6221976602555774",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622198_length16",  true,   "6221982603371344",   "6221982603371344",   "6221982603371344",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622199_length16",  true,   "6221995366112515",   "6221995366112515",   "6221995366112515",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622200_length16",  true,   "6222003162782703",   "6222003162782703",   "6222003162782703",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622201_length16",  true,   "6222016512054839",   "6222016512054839",   "6222016512054839",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622202_length16",  true,   "6222028885651661",   "6222028885651661",   "6222028885651661",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622203_length16",  true,   "6222031246453645",   "6222031246453645",   "6222031246453645",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622204_length16",  true,   "6222048680613617",   "6222048680613617",   "6222048680613617",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622205_length16",  true,   "6222057041707349",   "6222057041707349",   "6222057041707349",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622206_length16",  true,   "6222067555344215",   "6222067555344215",   "6222067555344215",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622207_length16",  true,   "6222075006303656",   "6222075006303656",   "6222075006303656",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622208_length16",  true,   "6222085874313034",   "6222085874313034",   "6222085874313034",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622209_length16",  true,   "6222092021156050",   "6222092021156050",   "6222092021156050",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622210_length16",  true,   "6222100535421173",   "6222100535421173",   "6222100535421173",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622211_length16",  true,   "6222112202873750",   "6222112202873750",   "6222112202873750",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622212_length16",  true,   "6222128205501115",   "6222128205501115",   "6222128205501115",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622213_length16",  true,   "6222135860004285",   "6222135860004285",   "6222135860004285",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622214_length16",  true,   "6222142400641287",   "6222142400641287",   "6222142400641287",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622215_length16",  true,   "6222158444760586",   "6222158444760586",   "6222158444760586",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622216_length16",  true,   "6222162811682183",   "6222162811682183",   "6222162811682183",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622217_length16",  true,   "6222176643483024",   "6222176643483024",   "6222176643483024",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622218_length16",  true,   "6222181326414502",   "6222181326414502",   "6222181326414502",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622219_length16",  true,   "6222197707883669",   "6222197707883669",   "6222197707883669",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622220_length16",  true,   "6222207266672450",   "6222207266672450",   "6222207266672450",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622221_length16",  true,   "6222210862474115",   "6222210862474115",   "6222210862474115",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622222_length16",  true,   "6222228841877117",   "6222228841877117",   "6222228841877117",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622223_length16",  true,   "6222235201031425",   "6222235201031425",   "6222235201031425",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622224_length16",  true,   "6222246828804045",   "6222246828804045",   "6222246828804045",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622225_length16",  true,   "6222251047737810",   "6222251047737810",   "6222251047737810",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622226_length16",  true,   "6222267555622087",   "6222267555622087",   "6222267555622087",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622227_length16",  true,   "6222278617056677",   "6222278617056677",   "6222278617056677",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622228_length16",  true,   "6222283657887536",   "6222283657887536",   "6222283657887536",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622229_length16",  true,   "6222293868603309",   "6222293868603309",   "6222293868603309",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622230_length16",  true,   "6222305827683642",   "6222305827683642",   "6222305827683642",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622231_length16",  true,   "6222314583487180",   "6222314583487180",   "6222314583487180",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622232_length16",  true,   "6222327530248729",   "6222327530248729",   "6222327530248729",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622233_length16",  true,   "6222337570658588",   "6222337570658588",   "6222337570658588",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622234_length16",  true,   "6222340210445226",   "6222340210445226",   "6222340210445226",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622235_length16",  true,   "6222358431258608",   "6222358431258608",   "6222358431258608",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622236_length16",  true,   "6222360776163104",   "6222360776163104",   "6222360776163104",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622237_length16",  true,   "6222374868377258",   "6222374868377258",   "6222374868377258",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622238_length16",  true,   "6222380414683800",   "6222380414683800",   "6222380414683800",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622239_length16",  true,   "6222398526213035",   "6222398526213035",   "6222398526213035",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622240_length16",  true,   "6222401623661732",   "6222401623661732",   "6222401623661732",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622241_length16",  true,   "6222416052657001",   "6222416052657001",   "6222416052657001",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622242_length16",  true,   "6222426552772416",   "6222426552772416",   "6222426552772416",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622243_length16",  true,   "6222430146411127",   "6222430146411127",   "6222430146411127",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622244_length16",  true,   "6222442323311301",   "6222442323311301",   "6222442323311301",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622245_length16",  true,   "6222456532102731",   "6222456532102731",   "6222456532102731",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622246_length16",  true,   "6222466841785324",   "6222466841785324",   "6222466841785324",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622247_length16",  true,   "6222475747087610",   "6222475747087610",   "6222475747087610",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622248_length16",  true,   "6222487623858527",   "6222487623858527",   "6222487623858527",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622249_length16",  true,   "6222495070505376",   "6222495070505376",   "6222495070505376",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622250_length16",  true,   "6222505624511355",   "6222505624511355",   "6222505624511355",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622251_length16",  true,   "6222515410170845",   "6222515410170845",   "6222515410170845",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622252_length16",  true,   "6222523503383655",   "6222523503383655",   "6222523503383655",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622253_length16",  true,   "6222534606181631",   "6222534606181631",   "6222534606181631",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622254_length16",  true,   "6222547611424838",   "6222547611424838",   "6222547611424838",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622255_length16",  true,   "6222553556238712",   "6222553556238712",   "6222553556238712",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622256_length16",  true,   "6222568270781045",   "6222568270781045",   "6222568270781045",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622257_length16",  true,   "6222575177764339",   "6222575177764339",   "6222575177764339",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622258_length16",  true,   "6222583847355025",   "6222583847355025",   "6222583847355025",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622259_length16",  true,   "6222592610388089",   "6222592610388089",   "6222592610388089",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622260_length16",  true,   "6222606001741639",   "6222606001741639",   "6222606001741639",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622261_length16",  true,   "6222618663730750",   "6222618663730750",   "6222618663730750",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622262_length16",  true,   "6222621783366877",   "6222621783366877",   "6222621783366877",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622263_length16",  true,   "6222635074617780",   "6222635074617780",   "6222635074617780",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622264_length16",  true,   "6222645378660014",   "6222645378660014",   "6222645378660014",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622265_length16",  true,   "6222654446126446",   "6222654446126446",   "6222654446126446",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622266_length16",  true,   "6222665648387487",   "6222665648387487",   "6222665648387487",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622267_length16",  true,   "6222671167167086",   "6222671167167086",   "6222671167167086",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622268_length16",  true,   "6222688341028703",   "6222688341028703",   "6222688341028703",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622269_length16",  true,   "6222698853737773",   "6222698853737773",   "6222698853737773",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622270_length16",  true,   "6222702884551730",   "6222702884551730",   "6222702884551730",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622271_length16",  true,   "6222718688222567",   "6222718688222567",   "6222718688222567",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622272_length16",  true,   "6222727360032814",   "6222727360032814",   "6222727360032814",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622273_length16",  true,   "6222733274870059",   "6222733274870059",   "6222733274870059",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622274_length16",  true,   "6222743206700340",   "6222743206700340",   "6222743206700340",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622275_length16",  true,   "6222750125277755",   "6222750125277755",   "6222750125277755",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622276_length16",  true,   "6222766032713112",   "6222766032713112",   "6222766032713112",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622277_length16",  true,   "6222778821042553",   "6222778821042553",   "6222778821042553",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622278_length16",  true,   "6222784364615334",   "6222784364615334",   "6222784364615334",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622279_length16",  true,   "6222795343022822",   "6222795343022822",   "6222795343022822",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622280_length16",  true,   "6222805025821423",   "6222805025821423",   "6222805025821423",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622281_length16",  true,   "6222813211325175",   "6222813211325175",   "6222813211325175",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622282_length16",  true,   "6222824125377012",   "6222824125377012",   "6222824125377012",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622283_length16",  true,   "6222833547524150",   "6222833547524150",   "6222833547524150",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622284_length16",  true,   "6222847471780786",   "6222847471780786",   "6222847471780786",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622285_length16",  true,   "6222851035806632",   "6222851035806632",   "6222851035806632",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622286_length16",  true,   "6222866747853425",   "6222866747853425",   "6222866747853425",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622287_length16",  true,   "6222872203517546",   "6222872203517546",   "6222872203517546",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622288_length16",  true,   "6222886344415501",   "6222886344415501",   "6222886344415501",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622289_length16",  true,   "6222895228241628",   "6222895228241628",   "6222895228241628",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622290_length16",  true,   "6222901672221874",   "6222901672221874",   "6222901672221874",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622291_length16",  true,   "6222914426754702",   "6222914426754702",   "6222914426754702",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622292_length16",  true,   "6222926355748018",   "6222926355748018",   "6222926355748018",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622293_length16",  true,   "6222930613414215",   "6222930613414215",   "6222930613414215",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622294_length16",  true,   "6222942464271826",   "6222942464271826",   "6222942464271826",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622295_length16",  true,   "6222950460478444",   "6222950460478444",   "6222950460478444",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622296_length16",  true,   "6222966282722140",   "6222966282722140",   "6222966282722140",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622297_length16",  true,   "6222975828303703",   "6222975828303703",   "6222975828303703",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622298_length16",  true,   "6222986863843156",   "6222986863843156",   "6222986863843156",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622299_length16",  true,   "6222996157148402",   "6222996157148402",   "6222996157148402",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622300_length16",  true,   "6223006580073380",   "6223006580073380",   "6223006580073380",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622301_length16",  true,   "6223018257820407",   "6223018257820407",   "6223018257820407",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622302_length16",  true,   "6223025657184243",   "6223025657184243",   "6223025657184243",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622303_length16",  true,   "6223030814400227",   "6223030814400227",   "6223030814400227",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622304_length16",  true,   "6223048456838553",   "6223048456838553",   "6223048456838553",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622305_length16",  true,   "6223058257672770",   "6223058257672770",   "6223058257672770",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622306_length16",  true,   "6223060074850852",   "6223060074850852",   "6223060074850852",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622307_length16",  true,   "6223071705847472",   "6223071705847472",   "6223071705847472",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622308_length16",  true,   "6223086074562676",   "6223086074562676",   "6223086074562676",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622309_length16",  true,   "6223094058533747",   "6223094058533747",   "6223094058533747",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622310_length16",  true,   "6223106566387703",   "6223106566387703",   "6223106566387703",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622311_length16",  true,   "6223114783864033",   "6223114783864033",   "6223114783864033",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622312_length16",  true,   "6223122664486131",   "6223122664486131",   "6223122664486131",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622313_length16",  true,   "6223131046333754",   "6223131046333754",   "6223131046333754",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622314_length16",  true,   "6223141402083612",   "6223141402083612",   "6223141402083612",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622315_length16",  true,   "6223152075787421",   "6223152075787421",   "6223152075787421",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622316_length16",  true,   "6223162884737707",   "6223162884737707",   "6223162884737707",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622317_length16",  true,   "6223173147476876",   "6223173147476876",   "6223173147476876",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622318_length16",  true,   "6223185737555612",   "6223185737555612",   "6223185737555612",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622319_length16",  true,   "6223191362273216",   "6223191362273216",   "6223191362273216",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622320_length16",  true,   "6223206600086210",   "6223206600086210",   "6223206600086210",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622321_length16",  true,   "6223216017830571",   "6223216017830571",   "6223216017830571",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622322_length16",  true,   "6223227304285486",   "6223227304285486",   "6223227304285486",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622323_length16",  true,   "6223236842684167",   "6223236842684167",   "6223236842684167",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622324_length16",  true,   "6223240038620308",   "6223240038620308",   "6223240038620308",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622325_length16",  true,   "6223254423522524",   "6223254423522524",   "6223254423522524",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622326_length16",  true,   "6223267708620672",   "6223267708620672",   "6223267708620672",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622327_length16",  true,   "6223272506686560",   "6223272506686560",   "6223272506686560",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622328_length16",  true,   "6223281315155162",   "6223281315155162",   "6223281315155162",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622329_length16",  true,   "6223298361346388",   "6223298361346388",   "6223298361346388",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622330_length16",  true,   "6223304878260805",   "6223304878260805",   "6223304878260805",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622331_length16",  true,   "6223315112048269",   "6223315112048269",   "6223315112048269",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622332_length16",  true,   "6223320571340504",   "6223320571340504",   "6223320571340504",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622333_length16",  true,   "6223331106177410",   "6223331106177410",   "6223331106177410",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622334_length16",  true,   "6223342470743463",   "6223342470743463",   "6223342470743463",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622335_length16",  true,   "6223357471041162",   "6223357471041162",   "6223357471041162",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622336_length16",  true,   "6223362502406749",   "6223362502406749",   "6223362502406749",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622337_length16",  true,   "6223373826323767",   "6223373826323767",   "6223373826323767",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622338_length16",  true,   "6223382752576504",   "6223382752576504",   "6223382752576504",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622339_length16",  true,   "6223395523255216",   "6223395523255216",   "6223395523255216",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622340_length16",  true,   "6223402163504851",   "6223402163504851",   "6223402163504851",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622341_length16",  true,   "6223415858817404",   "6223415858817404",   "6223415858817404",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622342_length16",  true,   "6223420564817656",   "6223420564817656",   "6223420564817656",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622343_length16",  true,   "6223431427746701",   "6223431427746701",   "6223431427746701",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622344_length16",  true,   "6223447208612706",   "6223447208612706",   "6223447208612706",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622345_length16",  true,   "6223450756811688",   "6223450756811688",   "6223450756811688",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622346_length16",  true,   "6223467536876666",   "6223467536876666",   "6223467536876666",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622347_length16",  true,   "6223473720104774",   "6223473720104774",   "6223473720104774",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622348_length16",  true,   "6223488403086346",   "6223488403086346",   "6223488403086346",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622349_length16",  true,   "6223497871213332",   "6223497871213332",   "6223497871213332",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622350_length16",  true,   "6223506550641322",   "6223506550641322",   "6223506550641322",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622351_length16",  true,   "6223514540233879",   "6223514540233879",   "6223514540233879",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622352_length16",  true,   "6223526576820254",   "6223526576820254",   "6223526576820254",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622353_length16",  true,   "6223533461643510",   "6223533461643510",   "6223533461643510",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622354_length16",  true,   "6223540362443148",   "6223540362443148",   "6223540362443148",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622355_length16",  true,   "6223558812527328",   "6223558812527328",   "6223558812527328",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622356_length16",  true,   "6223567364436762",   "6223567364436762",   "6223567364436762",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622357_length16",  true,   "6223570547521864",   "6223570547521864",   "6223570547521864",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622358_length16",  true,   "6223588675702312",   "6223588675702312",   "6223588675702312",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622359_length16",  true,   "6223597282308033",   "6223597282308033",   "6223597282308033",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622360_length16",  true,   "6223603053432729",   "6223603053432729",   "6223603053432729",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622361_length16",  true,   "6223613630836078",   "6223613630836078",   "6223613630836078",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622362_length16",  true,   "6223627541652226",   "6223627541652226",   "6223627541652226",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622363_length16",  true,   "6223636560644725",   "6223636560644725",   "6223636560644725",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622364_length16",  true,   "6223643735537552",   "6223643735537552",   "6223643735537552",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622365_length16",  true,   "6223658002762212",   "6223658002762212",   "6223658002762212",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622366_length16",  true,   "6223663652787659",   "6223663652787659",   "6223663652787659",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622367_length16",  true,   "6223677116338438",   "6223677116338438",   "6223677116338438",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622368_length16",  true,   "6223687715341840",   "6223687715341840",   "6223687715341840",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622369_length16",  true,   "6223691258605249",   "6223691258605249",   "6223691258605249",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622370_length16",  true,   "6223708726355585",   "6223708726355585",   "6223708726355585",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622371_length16",  true,   "6223714028827735",   "6223714028827735",   "6223714028827735",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622372_length16",  true,   "6223727876075389",   "6223727876075389",   "6223727876075389",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622373_length16",  true,   "6223730610236564",   "6223730610236564",   "6223730610236564",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622374_length16",  true,   "6223742663134588",   "6223742663134588",   "6223742663134588",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622375_length16",  true,   "6223757678755615",   "6223757678755615",   "6223757678755615",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622376_length16",  true,   "6223763136183242",   "6223763136183242",   "6223763136183242",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622377_length16",  true,   "6223774265475218",   "6223774265475218",   "6223774265475218",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622378_length16",  true,   "6223782761073874",   "6223782761073874",   "6223782761073874",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622379_length16",  true,   "6223793843720424",   "6223793843720424",   "6223793843720424",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622380_length16",  true,   "6223806334241252",   "6223806334241252",   "6223806334241252",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622381_length16",  true,   "6223811747371274",   "6223811747371274",   "6223811747371274",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622382_length16",  true,   "6223821786281482",   "6223821786281482",   "6223821786281482",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622383_length16",  true,   "6223838185220374",   "6223838185220374",   "6223838185220374",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622384_length16",  true,   "6223846472301658",   "6223846472301658",   "6223846472301658",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622385_length16",  true,   "6223855076613533",   "6223855076613533",   "6223855076613533",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622386_length16",  true,   "6223863523205242",   "6223863523205242",   "6223863523205242",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622387_length16",  true,   "6223878568882531",   "6223878568882531",   "6223878568882531",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622388_length16",  true,   "6223885812757450",   "6223885812757450",   "6223885812757450",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622389_length16",  true,   "6223892557855432",   "6223892557855432",   "6223892557855432",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622390_length16",  true,   "6223902837024160",   "6223902837024160",   "6223902837024160",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622391_length16",  true,   "6223916283160237",   "6223916283160237",   "6223916283160237",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622392_length16",  true,   "6223922808650066",   "6223922808650066",   "6223922808650066",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622393_length16",  true,   "6223934432076121",   "6223934432076121",   "6223934432076121",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622394_length16",  true,   "6223941188428828",   "6223941188428828",   "6223941188428828",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622395_length16",  true,   "6223955250434258",   "6223955250434258",   "6223955250434258",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622396_length16",  true,   "6223962842233412",   "6223962842233412",   "6223962842233412",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622397_length16",  true,   "6223974766201218",   "6223974766201218",   "6223974766201218",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622398_length16",  true,   "6223980351834719",   "6223980351834719",   "6223980351834719",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622399_length16",  true,   "6223995574334750",   "6223995574334750",   "6223995574334750",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622400_length16",  true,   "6224002556200148",   "6224002556200148",   "6224002556200148",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622401_length16",  true,   "6224014602181883",   "6224014602181883",   "6224014602181883",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622402_length16",  true,   "6224025066320221",   "6224025066320221",   "6224025066320221",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622403_length16",  true,   "6224030886337819",   "6224030886337819",   "6224030886337819",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622404_length16",  true,   "6224042866166233",   "6224042866166233",   "6224042866166233",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622405_length16",  true,   "6224053124422748",   "6224053124422748",   "6224053124422748",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622406_length16",  true,   "6224060141556259",   "6224060141556259",   "6224060141556259",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622407_length16",  true,   "6224076356165727",   "6224076356165727",   "6224076356165727",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622408_length16",  true,   "6224081522007829",   "6224081522007829",   "6224081522007829",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622409_length16",  true,   "6224090777240639",   "6224090777240639",   "6224090777240639",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622410_length16",  true,   "6224105187066828",   "6224105187066828",   "6224105187066828",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622411_length16",  true,   "6224114655072060",   "6224114655072060",   "6224114655072060",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622412_length16",  true,   "6224126534824776",   "6224126534824776",   "6224126534824776",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622413_length16",  true,   "6224136053633326",   "6224136053633326",   "6224136053633326",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622414_length16",  true,   "6224144878312324",   "6224144878312324",   "6224144878312324",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622415_length16",  true,   "6224150852465020",   "6224150852465020",   "6224150852465020",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622416_length16",  true,   "6224168451263547",   "6224168451263547",   "6224168451263547",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622417_length16",  true,   "6224177118877631",   "6224177118877631",   "6224177118877631",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622418_length16",  true,   "6224184663810660",   "6224184663810660",   "6224184663810660",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622419_length16",  true,   "6224197180744675",   "6224197180744675",   "6224197180744675",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622420_length16",  true,   "6224203208524246",   "6224203208524246",   "6224203208524246",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622421_length16",  true,   "6224218523530330",   "6224218523530330",   "6224218523530330",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622422_length16",  true,   "6224221065545500",   "6224221065545500",   "6224221065545500",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622423_length16",  true,   "6224235703877422",   "6224235703877422",   "6224235703877422",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622424_length16",  true,   "6224246614781447",   "6224246614781447",   "6224246614781447",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622425_length16",  true,   "6224254336325733",   "6224254336325733",   "6224254336325733",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622426_length16",  true,   "6224262873163219",   "6224262873163219",   "6224262873163219",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622427_length16",  true,   "6224277401252334",   "6224277401252334",   "6224277401252334",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622428_length16",  true,   "6224287354811382",   "6224287354811382",   "6224287354811382",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622429_length16",  true,   "6224294712185640",   "6224294712185640",   "6224294712185640",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622430_length16",  true,   "6224307674870106",   "6224307674870106",   "6224307674870106",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622431_length16",  true,   "6224316556488002",   "6224316556488002",   "6224316556488002",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622432_length16",  true,   "6224323332624579",   "6224323332624579",   "6224323332624579",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622433_length16",  true,   "6224338074263667",   "6224338074263667",   "6224338074263667",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622434_length16",  true,   "6224346420872222",   "6224346420872222",   "6224346420872222",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622435_length16",  true,   "6224350281188223",   "6224350281188223",   "6224350281188223",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622436_length16",  true,   "6224368515051256",   "6224368515051256",   "6224368515051256",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622437_length16",  true,   "6224378768264589",   "6224378768264589",   "6224378768264589",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622438_length16",  true,   "6224385560105779",   "6224385560105779",   "6224385560105779",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622439_length16",  true,   "6224395265767880",   "6224395265767880",   "6224395265767880",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622440_length16",  true,   "6224405741853228",   "6224405741853228",   "6224405741853228",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622441_length16",  true,   "6224410660248608",   "6224410660248608",   "6224410660248608",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622442_length16",  true,   "6224420767847202",   "6224420767847202",   "6224420767847202",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622443_length16",  true,   "6224432723354082",   "6224432723354082",   "6224432723354082",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622444_length16",  true,   "6224448432542171",   "6224448432542171",   "6224448432542171",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622445_length16",  true,   "6224455236662030",   "6224455236662030",   "6224455236662030",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622446_length16",  true,   "6224465286316320",   "6224465286316320",   "6224465286316320",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622447_length16",  true,   "6224470583815578",   "6224470583815578",   "6224470583815578",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622448_length16",  true,   "6224484817782678",   "6224484817782678",   "6224484817782678",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622449_length16",  true,   "6224491360733057",   "6224491360733057",   "6224491360733057",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622450_length16",  true,   "6224508181424432",   "6224508181424432",   "6224508181424432",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622451_length16",  true,   "6224514784228501",   "6224514784228501",   "6224514784228501",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622452_length16",  true,   "6224523363433051",   "6224523363433051",   "6224523363433051",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622453_length16",  true,   "6224535712847724",   "6224535712847724",   "6224535712847724",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622454_length16",  true,   "6224545525705365",   "6224545525705365",   "6224545525705365",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622455_length16",  true,   "6224550128648079",   "6224550128648079",   "6224550128648079",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622456_length16",  true,   "6224565823203863",   "6224565823203863",   "6224565823203863",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622457_length16",  true,   "6224572722154643",   "6224572722154643",   "6224572722154643",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622458_length16",  true,   "6224588522863043",   "6224588522863043",   "6224588522863043",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622459_length16",  true,   "6224593267356310",   "6224593267356310",   "6224593267356310",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622460_length16",  true,   "6224606624327830",   "6224606624327830",   "6224606624327830",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622461_length16",  true,   "6224615116844228",   "6224615116844228",   "6224615116844228",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622462_length16",  true,   "6224628584741545",   "6224628584741545",   "6224628584741545",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622463_length16",  true,   "6224636242573713",   "6224636242573713",   "6224636242573713",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622464_length16",  true,   "6224648252342723",   "6224648252342723",   "6224648252342723",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622465_length16",  true,   "6224652182820287",   "6224652182820287",   "6224652182820287",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622466_length16",  true,   "6224661000813101",   "6224661000813101",   "6224661000813101",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622467_length16",  true,   "6224674526802144",   "6224674526802144",   "6224674526802144",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622468_length16",  true,   "6224681133253207",   "6224681133253207",   "6224681133253207",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622469_length16",  true,   "6224696376568244",   "6224696376568244",   "6224696376568244",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622470_length16",  true,   "6224702636626234",   "6224702636626234",   "6224702636626234",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622471_length16",  true,   "6224718550836146",   "6224718550836146",   "6224718550836146",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622472_length16",  true,   "6224726275558077",   "6224726275558077",   "6224726275558077",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622473_length16",  true,   "6224733737064744",   "6224733737064744",   "6224733737064744",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622474_length16",  true,   "6224747768721519",   "6224747768721519",   "6224747768721519",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622475_length16",  true,   "6224756437077880",   "6224756437077880",   "6224756437077880",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622476_length16",  true,   "6224767851551706",   "6224767851551706",   "6224767851551706",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622477_length16",  true,   "6224772412140171",   "6224772412140171",   "6224772412140171",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622478_length16",  true,   "6224788538820280",   "6224788538820280",   "6224788538820280",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622479_length16",  true,   "6224795304525225",   "6224795304525225",   "6224795304525225",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622480_length16",  true,   "6224808823155539",   "6224808823155539",   "6224808823155539",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622481_length16",  true,   "6224816473812432",   "6224816473812432",   "6224816473812432",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622482_length16",  true,   "6224821472524426",   "6224821472524426",   "6224821472524426",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622483_length16",  true,   "6224830141184819",   "6224830141184819",   "6224830141184819",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622484_length16",  true,   "6224844550648701",   "6224844550648701",   "6224844550648701",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622485_length16",  true,   "6224852238157623",   "6224852238157623",   "6224852238157623",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622486_length16",  true,   "6224864380445623",   "6224864380445623",   "6224864380445623",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622487_length16",  true,   "6224875335522167",   "6224875335522167",   "6224875335522167",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622488_length16",  true,   "6224886418581319",   "6224886418581319",   "6224886418581319",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622489_length16",  true,   "6224893514642011",   "6224893514642011",   "6224893514642011",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622490_length16",  true,   "6224902775440229",   "6224902775440229",   "6224902775440229",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622491_length16",  true,   "6224911623257362",   "6224911623257362",   "6224911623257362",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622492_length16",  true,   "6224922213555552",   "6224922213555552",   "6224922213555552",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622493_length16",  true,   "6224934075620051",   "6224934075620051",   "6224934075620051",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622494_length16",  true,   "6224946324385617",   "6224946324385617",   "6224946324385617",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622495_length16",  true,   "6224951272415788",   "6224951272415788",   "6224951272415788",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622496_length16",  true,   "6224965303566567",   "6224965303566567",   "6224965303566567",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622497_length16",  true,   "6224974185214320",   "6224974185214320",   "6224974185214320",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622498_length16",  true,   "6224988847211136",   "6224988847211136",   "6224988847211136",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622499_length16",  true,   "6224997032261665",   "6224997032261665",   "6224997032261665",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622500_length16",  true,   "6225005252020248",   "6225005252020248",   "6225005252020248",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622501_length16",  true,   "6225014784174762",   "6225014784174762",   "6225014784174762",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622502_length16",  true,   "6225027702075820",   "6225027702075820",   "6225027702075820",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622503_length16",  true,   "6225033023320200",   "6225033023320200",   "6225033023320200",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622504_length16",  true,   "6225046263522665",   "6225046263522665",   "6225046263522665",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622505_length16",  true,   "6225051251884432",   "6225051251884432",   "6225051251884432",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622506_length16",  true,   "6225066408845276",   "6225066408845276",   "6225066408845276",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622507_length16",  true,   "6225072557810079",   "6225072557810079",   "6225072557810079",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622508_length16",  true,   "6225080844301877",   "6225080844301877",   "6225080844301877",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622509_length16",  true,   "6225090777325280",   "6225090777325280",   "6225090777325280",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622510_length16",  true,   "6225105810030703",   "6225105810030703",   "6225105810030703",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622511_length16",  true,   "6225118420328565",   "6225118420328565",   "6225118420328565",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622512_length16",  true,   "6225127851774213",   "6225127851774213",   "6225127851774213",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622513_length16",  true,   "6225133535307446",   "6225133535307446",   "6225133535307446",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622514_length16",  true,   "6225141800730481",   "6225141800730481",   "6225141800730481",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622515_length16",  true,   "6225155385215551",   "6225155385215551",   "6225155385215551",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622516_length16",  true,   "6225160344725351",   "6225160344725351",   "6225160344725351",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622517_length16",  true,   "6225171310651349",   "6225171310651349",   "6225171310651349",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622518_length16",  true,   "6225185053447228",   "6225185053447228",   "6225185053447228",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622519_length16",  true,   "6225190313403409",   "6225190313403409",   "6225190313403409",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622520_length16",  true,   "6225200481730754",   "6225200481730754",   "6225200481730754",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622521_length16",  true,   "6225213738041271",   "6225213738041271",   "6225213738041271",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622522_length16",  true,   "6225224822500270",   "6225224822500270",   "6225224822500270",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622523_length16",  true,   "6225235088057748",   "6225235088057748",   "6225235088057748",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622524_length16",  true,   "6225242016465035",   "6225242016465035",   "6225242016465035",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622525_length16",  true,   "6225258028711778",   "6225258028711778",   "6225258028711778",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622526_length16",  true,   "6225265456053409",   "6225265456053409",   "6225265456053409",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622527_length16",  true,   "6225270545784212",   "6225270545784212",   "6225270545784212",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622528_length16",  true,   "6225288710556264",   "6225288710556264",   "6225288710556264",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622529_length16",  true,   "6225292302726616",   "6225292302726616",   "6225292302726616",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622530_length16",  true,   "6225308712186447",   "6225308712186447",   "6225308712186447",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622531_length16",  true,   "6225316788825350",   "6225316788825350",   "6225316788825350",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622532_length16",  true,   "6225327631668020",   "6225327631668020",   "6225327631668020",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622533_length16",  true,   "6225333705863158",   "6225333705863158",   "6225333705863158",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622534_length16",  true,   "6225342382855775",   "6225342382855775",   "6225342382855775",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622535_length16",  true,   "6225354814476385",   "6225354814476385",   "6225354814476385",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622536_length16",  true,   "6225368628885334",   "6225368628885334",   "6225368628885334",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622537_length16",  true,   "6225378653864211",   "6225378653864211",   "6225378653864211",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622538_length16",  true,   "6225386528815029",   "6225386528815029",   "6225386528815029",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622539_length16",  true,   "6225395655613669",   "6225395655613669",   "6225395655613669",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622540_length16",  true,   "6225405570302536",   "6225405570302536",   "6225405570302536",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622541_length16",  true,   "6225413685772742",   "6225413685772742",   "6225413685772742",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622542_length16",  true,   "6225422763230689",   "6225422763230689",   "6225422763230689",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622543_length16",  true,   "6225431438476775",   "6225431438476775",   "6225431438476775",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622544_length16",  true,   "6225444108831021",   "6225444108831021",   "6225444108831021",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622545_length16",  true,   "6225458755030489",   "6225458755030489",   "6225458755030489",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622546_length16",  true,   "6225464702135033",   "6225464702135033",   "6225464702135033",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622547_length16",  true,   "6225472145300676",   "6225472145300676",   "6225472145300676",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622548_length16",  true,   "6225485018303460",   "6225485018303460",   "6225485018303460",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622549_length16",  true,   "6225498230321616",   "6225498230321616",   "6225498230321616",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622550_length16",  true,   "6225507425850427",   "6225507425850427",   "6225507425850427",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622551_length16",  true,   "6225516523581644",   "6225516523581644",   "6225516523581644",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622552_length16",  true,   "6225521512444317",   "6225521512444317",   "6225521512444317",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622553_length16",  true,   "6225534701334504",   "6225534701334504",   "6225534701334504",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622554_length16",  true,   "6225543430605670",   "6225543430605670",   "6225543430605670",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622555_length16",  true,   "6225555808716152",   "6225555808716152",   "6225555808716152",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622556_length16",  true,   "6225565460215112",   "6225565460215112",   "6225565460215112",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622557_length16",  true,   "6225577308582207",   "6225577308582207",   "6225577308582207",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622558_length16",  true,   "6225583518788709",   "6225583518788709",   "6225583518788709",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622559_length16",  true,   "6225596166163546",   "6225596166163546",   "6225596166163546",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622560_length16",  true,   "6225606444877534",   "6225606444877534",   "6225606444877534",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622561_length16",  true,   "6225610616476257",   "6225610616476257",   "6225610616476257",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622562_length16",  true,   "6225623218266802",   "6225623218266802",   "6225623218266802",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622563_length16",  true,   "6225636540407449",   "6225636540407449",   "6225636540407449",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622564_length16",  true,   "6225648761780834",   "6225648761780834",   "6225648761780834",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622565_length16",  true,   "6225654763352663",   "6225654763352663",   "6225654763352663",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622566_length16",  true,   "6225662347458559",   "6225662347458559",   "6225662347458559",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622567_length16",  true,   "6225673457220630",   "6225673457220630",   "6225673457220630",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622568_length16",  true,   "6225682418231735",   "6225682418231735",   "6225682418231735",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622569_length16",  true,   "6225698205662239",   "6225698205662239",   "6225698205662239",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622570_length16",  true,   "6225700144124030",   "6225700144124030",   "6225700144124030",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622571_length16",  true,   "6225713133518732",   "6225713133518732",   "6225713133518732",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622572_length16",  true,   "6225721034053584",   "6225721034053584",   "6225721034053584",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622573_length16",  true,   "6225730733167702",   "6225730733167702",   "6225730733167702",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622574_length16",  true,   "6225745628380582",   "6225745628380582",   "6225745628380582",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622575_length16",  true,   "6225752038155331",   "6225752038155331",   "6225752038155331",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622576_length16",  true,   "6225765337723815",   "6225765337723815",   "6225765337723815",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622577_length16",  true,   "6225777381540045",   "6225777381540045",   "6225777381540045",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622578_length16",  true,   "6225780432855701",   "6225780432855701",   "6225780432855701",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622579_length16",  true,   "6225792631348057",   "6225792631348057",   "6225792631348057",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622580_length16",  true,   "6225800662828531",   "6225800662828531",   "6225800662828531",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622581_length16",  true,   "6225816662535272",   "6225816662535272",   "6225816662535272",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622582_length16",  true,   "6225827358618413",   "6225827358618413",   "6225827358618413",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622583_length16",  true,   "6225838140111328",   "6225838140111328",   "6225838140111328",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622584_length16",  true,   "6225841566571728",   "6225841566571728",   "6225841566571728",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622585_length16",  true,   "6225858841153023",   "6225858841153023",   "6225858841153023",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622586_length16",  true,   "6225861220228069",   "6225861220228069",   "6225861220228069",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622587_length16",  true,   "6225870355555220",   "6225870355555220",   "6225870355555220",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622588_length16",  true,   "6225884182274806",   "6225884182274806",   "6225884182274806",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622589_length16",  true,   "6225894168582338",   "6225894168582338",   "6225894168582338",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622590_length16",  true,   "6225906763722422",   "6225906763722422",   "6225906763722422",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622591_length16",  true,   "6225911300380841",   "6225911300380841",   "6225911300380841",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622592_length16",  true,   "6225923513668540",   "6225923513668540",   "6225923513668540",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622593_length16",  true,   "6225938538111318",   "6225938538111318",   "6225938538111318",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622594_length16",  true,   "6225942602053869",   "6225942602053869",   "6225942602053869",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622595_length16",  true,   "6225956505021575",   "6225956505021575",   "6225956505021575",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622596_length16",  true,   "6225968032357448",   "6225968032357448",   "6225968032357448",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622597_length16",  true,   "6225977368422130",   "6225977368422130",   "6225977368422130",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622598_length16",  true,   "6225987760161103",   "6225987760161103",   "6225987760161103",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622599_length16",  true,   "6225994886086131",   "6225994886086131",   "6225994886086131",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622600_length16",  true,   "6226003220232242",   "6226003220232242",   "6226003220232242",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622601_length16",  true,   "6226016104215562",   "6226016104215562",   "6226016104215562",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622602_length16",  true,   "6226026332184738",   "6226026332184738",   "6226026332184738",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622603_length16",  true,   "6226033343164774",   "6226033343164774",   "6226033343164774",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622604_length16",  true,   "6226040004032125",   "6226040004032125",   "6226040004032125",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622605_length16",  true,   "6226058778578511",   "6226058778578511",   "6226058778578511",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622606_length16",  true,   "6226066165028537",   "6226066165028537",   "6226066165028537",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622607_length16",  true,   "6226071165258225",   "6226071165258225",   "6226071165258225",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622608_length16",  true,   "6226082860130684",   "6226082860130684",   "6226082860130684",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622609_length16",  true,   "6226093171533821",   "6226093171533821",   "6226093171533821",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622610_length16",  true,   "6226106606857282",   "6226106606857282",   "6226106606857282",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622611_length16",  true,   "6226115445535363",   "6226115445535363",   "6226115445535363",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622612_length16",  true,   "6226127181814845",   "6226127181814845",   "6226127181814845",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622613_length16",  true,   "6226136112636532",   "6226136112636532",   "6226136112636532",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622614_length16",  true,   "6226142525287517",   "6226142525287517",   "6226142525287517",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622615_length16",  true,   "6226151742314707",   "6226151742314707",   "6226151742314707",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622616_length16",  true,   "6226163554700733",   "6226163554700733",   "6226163554700733",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622617_length16",  true,   "6226174027601325",   "6226174027601325",   "6226174027601325",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622618_length16",  true,   "6226182485307350",   "6226182485307350",   "6226182485307350",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622619_length16",  true,   "6226198128868616",   "6226198128868616",   "6226198128868616",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622620_length16",  true,   "6226207360643585",   "6226207360643585",   "6226207360643585",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622621_length16",  true,   "6226214737584450",   "6226214737584450",   "6226214737584450",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622622_length16",  true,   "6226224350484219",   "6226224350484219",   "6226224350484219",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622623_length16",  true,   "6226238840840624",   "6226238840840624",   "6226238840840624",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622624_length16",  true,   "6226242627203071",   "6226242627203071",   "6226242627203071",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622625_length16",  true,   "6226258325842705",   "6226258325842705",   "6226258325842705",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622626_length16",  true,   "6226265113008332",   "6226265113008332",   "6226265113008332",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622627_length16",  true,   "6226274086375348",   "6226274086375348",   "6226274086375348",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622628_length16",  true,   "6226282022271562",   "6226282022271562",   "6226282022271562",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622629_length16",  true,   "6226290855205011",   "6226290855205011",   "6226290855205011",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622630_length16",  true,   "6226301815625337",   "6226301815625337",   "6226301815625337",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622631_length16",  true,   "6226317445344701",   "6226317445344701",   "6226317445344701",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622632_length16",  true,   "6226325386544254",   "6226325386544254",   "6226325386544254",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622633_length16",  true,   "6226330256541349",   "6226330256541349",   "6226330256541349",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622634_length16",  true,   "6226342458667459",   "6226342458667459",   "6226342458667459",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622635_length16",  true,   "6226353567728819",   "6226353567728819",   "6226353567728819",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622636_length16",  true,   "6226360813735670",   "6226360813735670",   "6226360813735670",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622637_length16",  true,   "6226377522366373",   "6226377522366373",   "6226377522366373",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622638_length16",  true,   "6226380334878668",   "6226380334878668",   "6226380334878668",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622639_length16",  true,   "6226397536428415",   "6226397536428415",   "6226397536428415",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622640_length16",  true,   "6226406356046072",   "6226406356046072",   "6226406356046072",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622641_length16",  true,   "6226411216847370",   "6226411216847370",   "6226411216847370",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622642_length16",  true,   "6226423501216880",   "6226423501216880",   "6226423501216880",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622643_length16",  true,   "6226437602370081",   "6226437602370081",   "6226437602370081",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622644_length16",  true,   "6226447118125507",   "6226447118125507",   "6226447118125507",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622645_length16",  true,   "6226454144258823",   "6226454144258823",   "6226454144258823",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622646_length16",  true,   "6226461566183710",   "6226461566183710",   "6226461566183710",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622647_length16",  true,   "6226478430055742",   "6226478430055742",   "6226478430055742",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622648_length16",  true,   "6226482524366684",   "6226482524366684",   "6226482524366684",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622649_length16",  true,   "6226493825680673",   "6226493825680673",   "6226493825680673",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622650_length16",  true,   "6226502374504025",   "6226502374504025",   "6226502374504025",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622651_length16",  true,   "6226515132622806",   "6226515132622806",   "6226515132622806",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622652_length16",  true,   "6226528115633229",   "6226528115633229",   "6226528115633229",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622653_length16",  true,   "6226531167061174",   "6226531167061174",   "6226531167061174",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622654_length16",  true,   "6226544621163411",   "6226544621163411",   "6226544621163411",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622655_length16",  true,   "6226555771343611",   "6226555771343611",   "6226555771343611",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622656_length16",  true,   "6226562522810054",   "6226562522810054",   "6226562522810054",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622657_length16",  true,   "6226573531647544",   "6226573531647544",   "6226573531647544",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622658_length16",  true,   "6226580245306440",   "6226580245306440",   "6226580245306440",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622659_length16",  true,   "6226592774266622",   "6226592774266622",   "6226592774266622",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622660_length16",  true,   "6226600381621707",   "6226600381621707",   "6226600381621707",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622661_length16",  true,   "6226610407764803",   "6226610407764803",   "6226610407764803",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622662_length16",  true,   "6226627004172511",   "6226627004172511",   "6226627004172511",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622663_length16",  true,   "6226637871508242",   "6226637871508242",   "6226637871508242",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622664_length16",  true,   "6226641417134083",   "6226641417134083",   "6226641417134083",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622665_length16",  true,   "6226654564540119",   "6226654564540119",   "6226654564540119",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622666_length16",  true,   "6226662251705473",   "6226662251705473",   "6226662251705473",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622667_length16",  true,   "6226675732181577",   "6226675732181577",   "6226675732181577",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622668_length16",  true,   "6226680238273357",   "6226680238273357",   "6226680238273357",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622669_length16",  true,   "6226697452073206",   "6226697452073206",   "6226697452073206",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622670_length16",  true,   "6226700654800267",   "6226700654800267",   "6226700654800267",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622671_length16",  true,   "6226718068346354",   "6226718068346354",   "6226718068346354",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622672_length16",  true,   "6226725642035551",   "6226725642035551",   "6226725642035551",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622673_length16",  true,   "6226733120507356",   "6226733120507356",   "6226733120507356",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622674_length16",  true,   "6226742667525838",   "6226742667525838",   "6226742667525838",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622675_length16",  true,   "6226753876664847",   "6226753876664847",   "6226753876664847",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622676_length16",  true,   "6226762123522229",   "6226762123522229",   "6226762123522229",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622677_length16",  true,   "6226776748604121",   "6226776748604121",   "6226776748604121",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622678_length16",  true,   "6226787440338207",   "6226787440338207",   "6226787440338207",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622679_length16",  true,   "6226796708707813",   "6226796708707813",   "6226796708707813",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622680_length16",  true,   "6226804440043859",   "6226804440043859",   "6226804440043859",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622681_length16",  true,   "6226814133810605",   "6226814133810605",   "6226814133810605",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622682_length16",  true,   "6226820573138142",   "6226820573138142",   "6226820573138142",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622683_length16",  true,   "6226832878684738",   "6226832878684738",   "6226832878684738",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622684_length16",  true,   "6226841848748473",   "6226841848748473",   "6226841848748473",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622685_length16",  true,   "6226850151334649",   "6226850151334649",   "6226850151334649",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622686_length16",  true,   "6226862441343215",   "6226862441343215",   "6226862441343215",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622687_length16",  true,   "6226874285204536",   "6226874285204536",   "6226874285204536",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622688_length16",  true,   "6226883134880776",   "6226883134880776",   "6226883134880776",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622689_length16",  true,   "6226898408164285",   "6226898408164285",   "6226898408164285",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622690_length16",  true,   "6226900024426005",   "6226900024426005",   "6226900024426005",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622691_length16",  true,   "6226910763646630",   "6226910763646630",   "6226910763646630",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622692_length16",  true,   "6226925416007725",   "6226925416007725",   "6226925416007725",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622693_length16",  true,   "6226937705711453",   "6226937705711453",   "6226937705711453",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622694_length16",  true,   "6226948011543613",   "6226948011543613",   "6226948011543613",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622695_length16",  true,   "6226951086404307",   "6226951086404307",   "6226951086404307",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622696_length16",  true,   "6226962571213459",   "6226962571213459",   "6226962571213459",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622697_length16",  true,   "6226972628207644",   "6226972628207644",   "6226972628207644",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622698_length16",  true,   "6226985073251149",   "6226985073251149",   "6226985073251149",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622699_length16",  true,   "6226991210138413",   "6226991210138413",   "6226991210138413",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622700_length16",  true,   "6227004180281707",   "6227004180281707",   "6227004180281707",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622701_length16",  true,   "6227016460014046",   "6227016460014046",   "6227016460014046",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622702_length16",  true,   "6227024826338489",   "6227024826338489",   "6227024826338489",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622703_length16",  true,   "6227034443076859",   "6227034443076859",   "6227034443076859",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622704_length16",  true,   "6227042032428704",   "6227042032428704",   "6227042032428704",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622705_length16",  true,   "6227057321404778",   "6227057321404778",   "6227057321404778",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622706_length16",  true,   "6227065110430623",   "6227065110430623",   "6227065110430623",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622707_length16",  true,   "6227078555150143",   "6227078555150143",   "6227078555150143",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622708_length16",  true,   "6227081122788783",   "6227081122788783",   "6227081122788783",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622709_length16",  true,   "6227098534376403",   "6227098534376403",   "6227098534376403",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622710_length16",  true,   "6227103277031502",   "6227103277031502",   "6227103277031502",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622711_length16",  true,   "6227111688206076",   "6227111688206076",   "6227111688206076",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622712_length16",  true,   "6227120815548680",   "6227120815548680",   "6227120815548680",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622713_length16",  true,   "6227132744442109",   "6227132744442109",   "6227132744442109",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622714_length16",  true,   "6227140887875134",   "6227140887875134",   "6227140887875134",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622715_length16",  true,   "6227155627822782",   "6227155627822782",   "6227155627822782",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622716_length16",  true,   "6227165740045831",   "6227165740045831",   "6227165740045831",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622717_length16",  true,   "6227175478004207",   "6227175478004207",   "6227175478004207",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622718_length16",  true,   "6227180165686225",   "6227180165686225",   "6227180165686225",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622719_length16",  true,   "6227197737612521",   "6227197737612521",   "6227197737612521",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622720_length16",  true,   "6227200166480160",   "6227200166480160",   "6227200166480160",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622721_length16",  true,   "6227216278255340",   "6227216278255340",   "6227216278255340",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622722_length16",  true,   "6227226521625579",   "6227226521625579",   "6227226521625579",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622723_length16",  true,   "6227238261873129",   "6227238261873129",   "6227238261873129",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622724_length16",  true,   "6227241065704037",   "6227241065704037",   "6227241065704037",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622725_length16",  true,   "6227255152803247",   "6227255152803247",   "6227255152803247",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622726_length16",  true,   "6227265340028250",   "6227265340028250",   "6227265340028250",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622727_length16",  true,   "6227273434818818",   "6227273434818818",   "6227273434818818",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622728_length16",  true,   "6227288056183242",   "6227288056183242",   "6227288056183242",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622729_length16",  true,   "6227290602066301",   "6227290602066301",   "6227290602066301",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622730_length16",  true,   "6227307477335718",   "6227307477335718",   "6227307477335718",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622731_length16",  true,   "6227313714330868",   "6227313714330868",   "6227313714330868",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622732_length16",  true,   "6227321584021285",   "6227321584021285",   "6227321584021285",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622733_length16",  true,   "6227332246316047",   "6227332246316047",   "6227332246316047",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622734_length16",  true,   "6227345410367133",   "6227345410367133",   "6227345410367133",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622735_length16",  true,   "6227358360404210",   "6227358360404210",   "6227358360404210",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622736_length16",  true,   "6227365515058866",   "6227365515058866",   "6227365515058866",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622737_length16",  true,   "6227373236630823",   "6227373236630823",   "6227373236630823",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622738_length16",  true,   "6227381856588585",   "6227381856588585",   "6227381856588585",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622739_length16",  true,   "6227397726823572",   "6227397726823572",   "6227397726823572",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622740_length16",  true,   "6227406306685564",   "6227406306685564",   "6227406306685564",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622741_length16",  true,   "6227413134624500",   "6227413134624500",   "6227413134624500",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622742_length16",  true,   "6227428525344153",   "6227428525344153",   "6227428525344153",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622743_length16",  true,   "6227433247735316",   "6227433247735316",   "6227433247735316",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622744_length16",  true,   "6227440631312883",   "6227440631312883",   "6227440631312883",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622745_length16",  true,   "6227455101861052",   "6227455101861052",   "6227455101861052",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622746_length16",  true,   "6227467830354002",   "6227467830354002",   "6227467830354002",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622747_length16",  true,   "6227476345831230",   "6227476345831230",   "6227476345831230",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622748_length16",  true,   "6227482461871752",   "6227482461871752",   "6227482461871752",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622749_length16",  true,   "6227494817513533",   "6227494817513533",   "6227494817513533",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622750_length16",  true,   "6227504640230558",   "6227504640230558",   "6227504640230558",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622751_length16",  true,   "6227518284832438",   "6227518284832438",   "6227518284832438",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622752_length16",  true,   "6227524887237470",   "6227524887237470",   "6227524887237470",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622753_length16",  true,   "6227534661425134",   "6227534661425134",   "6227534661425134",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622754_length16",  true,   "6227542324278345",   "6227542324278345",   "6227542324278345",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622755_length16",  true,   "6227556166235726",   "6227556166235726",   "6227556166235726",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622756_length16",  true,   "6227561775181246",   "6227561775181246",   "6227561775181246",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622757_length16",  true,   "6227573865733331",   "6227573865733331",   "6227573865733331",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622758_length16",  true,   "6227586601523832",   "6227586601523832",   "6227586601523832",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622759_length16",  true,   "6227592367513272",   "6227592367513272",   "6227592367513272",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622760_length16",  true,   "6227601688753788",   "6227601688753788",   "6227601688753788",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622761_length16",  true,   "6227614510564109",   "6227614510564109",   "6227614510564109",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622762_length16",  true,   "6227624664437770",   "6227624664437770",   "6227624664437770",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622763_length16",  true,   "6227633221063318",   "6227633221063318",   "6227633221063318",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622764_length16",  true,   "6227642473664509",   "6227642473664509",   "6227642473664509",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622765_length16",  true,   "6227650258483417",   "6227650258483417",   "6227650258483417",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622766_length16",  true,   "6227665281207781",   "6227665281207781",   "6227665281207781",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622767_length16",  true,   "6227674433774201",   "6227674433774201",   "6227674433774201",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622768_length16",  true,   "6227684210142720",   "6227684210142720",   "6227684210142720",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622769_length16",  true,   "6227691130628746",   "6227691130628746",   "6227691130628746",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622770_length16",  true,   "6227708307825671",   "6227708307825671",   "6227708307825671",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622771_length16",  true,   "6227710677715169",   "6227710677715169",   "6227710677715169",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622772_length16",  true,   "6227720570232238",   "6227720570232238",   "6227720570232238",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622773_length16",  true,   "6227730030440842",   "6227730030440842",   "6227730030440842",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622774_length16",  true,   "6227746348587819",   "6227746348587819",   "6227746348587819",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622775_length16",  true,   "6227756420235716",   "6227756420235716",   "6227756420235716",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622776_length16",  true,   "6227760751231047",   "6227760751231047",   "6227760751231047",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622777_length16",  true,   "6227770481087742",   "6227770481087742",   "6227770481087742",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622778_length16",  true,   "6227787618360511",   "6227787618360511",   "6227787618360511",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622779_length16",  true,   "6227793037155185",   "6227793037155185",   "6227793037155185",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622780_length16",  true,   "6227803584278007",   "6227803584278007",   "6227803584278007",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622781_length16",  true,   "6227811814877274",   "6227811814877274",   "6227811814877274",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622782_length16",  true,   "6227822400008349",   "6227822400008349",   "6227822400008349",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622783_length16",  true,   "6227831363864028",   "6227831363864028",   "6227831363864028",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622784_length16",  true,   "6227845757605854",   "6227845757605854",   "6227845757605854",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622785_length16",  true,   "6227855347107378",   "6227855347107378",   "6227855347107378",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622786_length16",  true,   "6227866132331768",   "6227866132331768",   "6227866132331768",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622787_length16",  true,   "6227874242555706",   "6227874242555706",   "6227874242555706",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622788_length16",  true,   "6227883807301851",   "6227883807301851",   "6227883807301851",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622789_length16",  true,   "6227891058753050",   "6227891058753050",   "6227891058753050",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622790_length16",  true,   "6227900867686805",   "6227900867686805",   "6227900867686805",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622791_length16",  true,   "6227916308523654",   "6227916308523654",   "6227916308523654",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622792_length16",  true,   "6227921248345861",   "6227921248345861",   "6227921248345861",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622793_length16",  true,   "6227937180701663",   "6227937180701663",   "6227937180701663",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622794_length16",  true,   "6227940621278358",   "6227940621278358",   "6227940621278358",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622795_length16",  true,   "6227958074048474",   "6227958074048474",   "6227958074048474",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622796_length16",  true,   "6227960652002568",   "6227960652002568",   "6227960652002568",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622797_length16",  true,   "6227978130017057",   "6227978130017057",   "6227978130017057",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622798_length16",  true,   "6227984137053319",   "6227984137053319",   "6227984137053319",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622799_length16",  true,   "6227990120657065",   "6227990120657065",   "6227990120657065",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622800_length16",  true,   "6228002485200504",   "6228002485200504",   "6228002485200504",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622801_length16",  true,   "6228013172618007",   "6228013172618007",   "6228013172618007",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622802_length16",  true,   "6228025627705866",   "6228025627705866",   "6228025627705866",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622803_length16",  true,   "6228038061523216",   "6228038061523216",   "6228038061523216",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622804_length16",  true,   "6228041537817675",   "6228041537817675",   "6228041537817675",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622805_length16",  true,   "6228052440045833",   "6228052440045833",   "6228052440045833",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622806_length16",  true,   "6228064258763654",   "6228064258763654",   "6228064258763654",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622807_length16",  true,   "6228076733504743",   "6228076733504743",   "6228076733504743",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622808_length16",  true,   "6228086761113226",   "6228086761113226",   "6228086761113226",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622809_length16",  true,   "6228090084166457",   "6228090084166457",   "6228090084166457",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622810_length16",  true,   "6228102633760662",   "6228102633760662",   "6228102633760662",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622811_length16",  true,   "6228112440102073",   "6228112440102073",   "6228112440102073",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622812_length16",  true,   "6228126754623003",   "6228126754623003",   "6228126754623003",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622813_length16",  true,   "6228134107112641",   "6228134107112641",   "6228134107112641",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622814_length16",  true,   "6228148756831855",   "6228148756831855",   "6228148756831855",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622815_length16",  true,   "6228150754660435",   "6228150754660435",   "6228150754660435",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622816_length16",  true,   "6228164277751175",   "6228164277751175",   "6228164277751175",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622817_length16",  true,   "6228171215877319",   "6228171215877319",   "6228171215877319",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622818_length16",  true,   "6228187208674158",   "6228187208674158",   "6228187208674158",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622819_length16",  true,   "6228194854438433",   "6228194854438433",   "6228194854438433",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622820_length16",  true,   "6228208465686113",   "6228208465686113",   "6228208465686113",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622821_length16",  true,   "6228214865057004",   "6228214865057004",   "6228214865057004",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622822_length16",  true,   "6228227518423738",   "6228227518423738",   "6228227518423738",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622823_length16",  true,   "6228237833263123",   "6228237833263123",   "6228237833263123",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622824_length16",  true,   "6228246412820823",   "6228246412820823",   "6228246412820823",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622825_length16",  true,   "6228255803658288",   "6228255803658288",   "6228255803658288",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622826_length16",  true,   "6228262248546557",   "6228262248546557",   "6228262248546557",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622827_length16",  true,   "6228276311538564",   "6228276311538564",   "6228276311538564",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622828_length16",  true,   "6228284650027306",   "6228284650027306",   "6228284650027306",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622829_length16",  true,   "6228293655825184",   "6228293655825184",   "6228293655825184",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622830_length16",  true,   "6228307424017509",   "6228307424017509",   "6228307424017509",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622831_length16",  true,   "6228315275532682",   "6228315275532682",   "6228315275532682",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622832_length16",  true,   "6228326064675244",   "6228326064675244",   "6228326064675244",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622833_length16",  true,   "6228334351873647",   "6228334351873647",   "6228334351873647",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622834_length16",  true,   "6228343781073637",   "6228343781073637",   "6228343781073637",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622835_length16",  true,   "6228351714020211",   "6228351714020211",   "6228351714020211",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622836_length16",  true,   "6228360245188462",   "6228360245188462",   "6228360245188462",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622837_length16",  true,   "6228373451444040",   "6228373451444040",   "6228373451444040",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622838_length16",  true,   "6228383672322222",   "6228383672322222",   "6228383672322222",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622839_length16",  true,   "6228391378161281",   "6228391378161281",   "6228391378161281",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622840_length16",  true,   "6228408054040223",   "6228408054040223",   "6228408054040223",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622841_length16",  true,   "6228411614133132",   "6228411614133132",   "6228411614133132",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622842_length16",  true,   "6228427022675647",   "6228427022675647",   "6228427022675647",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622843_length16",  true,   "6228433045561418",   "6228433045561418",   "6228433045561418",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622844_length16",  true,   "6228443815023358",   "6228443815023358",   "6228443815023358",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622845_length16",  true,   "6228458232078629",   "6228458232078629",   "6228458232078629",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622846_length16",  true,   "6228461766566316",   "6228461766566316",   "6228461766566316",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622847_length16",  true,   "6228472165221528",   "6228472165221528",   "6228472165221528",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622848_length16",  true,   "6228481173656369",   "6228481173656369",   "6228481173656369",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622849_length16",  true,   "6228493437035884",   "6228493437035884",   "6228493437035884",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622850_length16",  true,   "6228504005722263",   "6228504005722263",   "6228504005722263",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622851_length16",  true,   "6228515465340065",   "6228515465340065",   "6228515465340065",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622852_length16",  true,   "6228521746872371",   "6228521746872371",   "6228521746872371",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622853_length16",  true,   "6228534847712461",   "6228534847712461",   "6228534847712461",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622854_length16",  true,   "6228548606132141",   "6228548606132141",   "6228548606132141",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622855_length16",  true,   "6228556820037251",   "6228556820037251",   "6228556820037251",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622856_length16",  true,   "6228561360816809",   "6228561360816809",   "6228561360816809",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622857_length16",  true,   "6228575881786341",   "6228575881786341",   "6228575881786341",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622858_length16",  true,   "6228587714506358",   "6228587714506358",   "6228587714506358",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622859_length16",  true,   "6228596245586268",   "6228596245586268",   "6228596245586268",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622860_length16",  true,   "6228607030642354",   "6228607030642354",   "6228607030642354",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622861_length16",  true,   "6228614175021204",   "6228614175021204",   "6228614175021204",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622862_length16",  true,   "6228620152848527",   "6228620152848527",   "6228620152848527",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622863_length16",  true,   "6228636311224244",   "6228636311224244",   "6228636311224244",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622864_length16",  true,   "6228647517036548",   "6228647517036548",   "6228647517036548",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622865_length16",  true,   "6228658336410012",   "6228658336410012",   "6228658336410012",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622866_length16",  true,   "6228665082614655",   "6228665082614655",   "6228665082614655",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622867_length16",  true,   "6228672215506659",   "6228672215506659",   "6228672215506659",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622868_length16",  true,   "6228683482455306",   "6228683482455306",   "6228683482455306",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622869_length16",  true,   "6228695676053655",   "6228695676053655",   "6228695676053655",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622870_length16",  true,   "6228706766161389",   "6228706766161389",   "6228706766161389",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622871_length16",  true,   "6228714624627088",   "6228714624627088",   "6228714624627088",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622872_length16",  true,   "6228728470851527",   "6228728470851527",   "6228728470851527",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622873_length16",  true,   "6228735682872183",   "6228735682872183",   "6228735682872183",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622874_length16",  true,   "6228740313653788",   "6228740313653788",   "6228740313653788",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622875_length16",  true,   "6228754276618613",   "6228754276618613",   "6228754276618613",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622876_length16",  true,   "6228762856720014",   "6228762856720014",   "6228762856720014",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622877_length16",  true,   "6228778538240742",   "6228778538240742",   "6228778538240742",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622878_length16",  true,   "6228782478701804",   "6228782478701804",   "6228782478701804",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622879_length16",  true,   "6228797573327347",   "6228797573327347",   "6228797573327347",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622880_length16",  true,   "6228807146614764",   "6228807146614764",   "6228807146614764",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622881_length16",  true,   "6228814102445506",   "6228814102445506",   "6228814102445506",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622882_length16",  true,   "6228828404548528",   "6228828404548528",   "6228828404548528",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622883_length16",  true,   "6228834733283134",   "6228834733283134",   "6228834733283134",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622884_length16",  true,   "6228843561670346",   "6228843561670346",   "6228843561670346",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622885_length16",  true,   "6228850655601343",   "6228850655601343",   "6228850655601343",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622886_length16",  true,   "6228865487624388",   "6228865487624388",   "6228865487624388",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622887_length16",  true,   "6228870853181484",   "6228870853181484",   "6228870853181484",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622888_length16",  true,   "6228880515850079",   "6228880515850079",   "6228880515850079",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622889_length16",  true,   "6228893225861310",   "6228893225861310",   "6228893225861310",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622890_length16",  true,   "6228908102511018",   "6228908102511018",   "6228908102511018",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622891_length16",  true,   "6228913431338422",   "6228913431338422",   "6228913431338422",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622892_length16",  true,   "6228920547357584",   "6228920547357584",   "6228920547357584",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622893_length16",  true,   "6228932442212020",   "6228932442212020",   "6228932442212020",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622894_length16",  true,   "6228946445511543",   "6228946445511543",   "6228946445511543",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622895_length16",  true,   "6228951875441724",   "6228951875441724",   "6228951875441724",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622896_length16",  true,   "6228966340312037",   "6228966340312037",   "6228966340312037",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622897_length16",  true,   "6228973474418317",   "6228973474418317",   "6228973474418317",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622898_length16",  true,   "6228987607405736",   "6228987607405736",   "6228987607405736",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622899_length16",  true,   "6228996145235851",   "6228996145235851",   "6228996145235851",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622900_length16",  true,   "6229002576051021",   "6229002576051021",   "6229002576051021",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622901_length16",  true,   "6229017444522524",   "6229017444522524",   "6229017444522524",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622902_length16",  true,   "6229021027712346",   "6229021027712346",   "6229021027712346",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622903_length16",  true,   "6229037001705353",   "6229037001705353",   "6229037001705353",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622904_length16",  true,   "6229043282523036",   "6229043282523036",   "6229043282523036",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622905_length16",  true,   "6229054834768276",   "6229054834768276",   "6229054834768276",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622906_length16",  true,   "6229060811186713",   "6229060811186713",   "6229060811186713",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622907_length16",  true,   "6229078034332328",   "6229078034332328",   "6229078034332328",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622908_length16",  true,   "6229080121015238",   "6229080121015238",   "6229080121015238",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622909_length16",  true,   "6229096860718535",   "6229096860718535",   "6229096860718535",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622910_length16",  true,   "6229100352778336",   "6229100352778336",   "6229100352778336",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622911_length16",  true,   "6229114072412829",   "6229114072412829",   "6229114072412829",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622912_length16",  true,   "6229126260721548",   "6229126260721548",   "6229126260721548",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622913_length16",  true,   "6229130182510880",   "6229130182510880",   "6229130182510880",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622914_length16",  true,   "6229146410677002",   "6229146410677002",   "6229146410677002",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622915_length16",  true,   "6229153333085123",   "6229153333085123",   "6229153333085123",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622916_length16",  true,   "6229164358043426",   "6229164358043426",   "6229164358043426",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622917_length16",  true,   "6229178034216180",   "6229178034216180",   "6229178034216180",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622918_length16",  true,   "6229182212525628",   "6229182212525628",   "6229182212525628",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622919_length16",  true,   "6229197007751627",   "6229197007751627",   "6229197007751627",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622920_length16",  true,   "6229207352755352",   "6229207352755352",   "6229207352755352",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622921_length16",  true,   "6229211045687253",   "6229211045687253",   "6229211045687253",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622922_length16",  true,   "6229228007544777",   "6229228007544777",   "6229228007544777",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622923_length16",  true,   "6229233065315029",   "6229233065315029",   "6229233065315029",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622924_length16",  true,   "6229244451402339",   "6229244451402339",   "6229244451402339",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622925_length16",  true,   "6229254618454123",   "6229254618454123",   "6229254618454123",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix65_length19",      true,   "6526760536385675112",   "6526760536385675112",   "6526760536385675112",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix644_length19",     true,   "6446863430333536039",   "6446863430333536039",   "6446863430333536039",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix645_length19",     true,   "6450287441607723385",   "6450287441607723385",   "6450287441607723385",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix646_length19",     true,   "6462568071054231536",   "6462568071054231536",   "6462568071054231536",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix647_length19",     true,   "6472317740677388385",   "6472317740677388385",   "6472317740677388385",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix648_length19",     true,   "6488003254456560367",   "6488003254456560367",   "6488003254456560367",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix649_length19",     true,   "6494408081888636534",   "6494408081888636534",   "6494408081888636534",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix6011_length19",    true,   "6011318164380217788",   "6011318164380217788",   "6011318164380217788",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622126_length19",  true,   "6221264042716640759",   "6221264042716640759",   "6221264042716640759",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622127_length19",  true,   "6221276042017315479",   "6221276042017315479",   "6221276042017315479",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622128_length19",  true,   "6221283388771284208",   "6221283388771284208",   "6221283388771284208",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622129_length19",  true,   "6221294467382137679",   "6221294467382137679",   "6221294467382137679",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622130_length19",  true,   "6221305578750211131",   "6221305578750211131",   "6221305578750211131",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622131_length19",  true,   "6221312255220611213",   "6221312255220611213",   "6221312255220611213",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622132_length19",  true,   "6221320167860685425",   "6221320167860685425",   "6221320167860685425",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622133_length19",  true,   "6221334603863571745",   "6221334603863571745",   "6221334603863571745",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622134_length19",  true,   "6221346515515663538",   "6221346515515663538",   "6221346515515663538",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622135_length19",  true,   "6221358845760227043",   "6221358845760227043",   "6221358845760227043",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622136_length19",  true,   "6221368401511560684",   "6221368401511560684",   "6221368401511560684",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622137_length19",  true,   "6221377877032230122",   "6221377877032230122",   "6221377877032230122",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622138_length19",  true,   "6221387084063552320",   "6221387084063552320",   "6221387084063552320",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622139_length19",  true,   "6221391704132617317",   "6221391704132617317",   "6221391704132617317",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622140_length19",  true,   "6221403574704726820",   "6221403574704726820",   "6221403574704726820",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622141_length19",  true,   "6221416117737783643",   "6221416117737783643",   "6221416117737783643",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622142_length19",  true,   "6221422045386012554",   "6221422045386012554",   "6221422045386012554",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622143_length19",  true,   "6221435711741081452",   "6221435711741081452",   "6221435711741081452",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622144_length19",  true,   "6221446484187556182",   "6221446484187556182",   "6221446484187556182",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622145_length19",  true,   "6221456105386045852",   "6221456105386045852",   "6221456105386045852",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622146_length19",  true,   "6221467317020758553",   "6221467317020758553",   "6221467317020758553",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622147_length19",  true,   "6221474102444123241",   "6221474102444123241",   "6221474102444123241",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622148_length19",  true,   "6221481331164568084",   "6221481331164568084",   "6221481331164568084",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622149_length19",  true,   "6221497888628842472",   "6221497888628842472",   "6221497888628842472",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622150_length19",  true,   "6221500165686136831",   "6221500165686136831",   "6221500165686136831",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622151_length19",  true,   "6221514668265155712",   "6221514668265155712",   "6221514668265155712",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622152_length19",  true,   "6221523211810375086",   "6221523211810375086",   "6221523211810375086",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622153_length19",  true,   "6221538834053447883",   "6221538834053447883",   "6221538834053447883",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622154_length19",  true,   "6221544051373017575",   "6221544051373017575",   "6221544051373017575",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622155_length19",  true,   "6221552178146818515",   "6221552178146818515",   "6221552178146818515",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622156_length19",  true,   "6221562435588868210",   "6221562435588868210",   "6221562435588868210",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622157_length19",  true,   "6221578628050475009",   "6221578628050475009",   "6221578628050475009",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622158_length19",  true,   "6221583540044616684",   "6221583540044616684",   "6221583540044616684",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622159_length19",  true,   "6221594344210340527",   "6221594344210340527",   "6221594344210340527",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622160_length19",  true,   "6221603883325217632",   "6221603883325217632",   "6221603883325217632",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622161_length19",  true,   "6221614263087512628",   "6221614263087512628",   "6221614263087512628",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622162_length19",  true,   "6221623583124655083",   "6221623583124655083",   "6221623583124655083",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622163_length19",  true,   "6221635842143322737",   "6221635842143322737",   "6221635842143322737",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622164_length19",  true,   "6221647210810554428",   "6221647210810554428",   "6221647210810554428",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622165_length19",  true,   "6221650317260483570",   "6221650317260483570",   "6221650317260483570",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622166_length19",  true,   "6221660514511421841",   "6221660514511421841",   "6221660514511421841",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622167_length19",  true,   "6221672063664321313",   "6221672063664321313",   "6221672063664321313",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622168_length19",  true,   "6221681480330387750",   "6221681480330387750",   "6221681480330387750",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622169_length19",  true,   "6221693127135481512",   "6221693127135481512",   "6221693127135481512",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622170_length19",  true,   "6221706515777155045",   "6221706515777155045",   "6221706515777155045",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622171_length19",  true,   "6221714405227548116",   "6221714405227548116",   "6221714405227548116",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622172_length19",  true,   "6221722237586476575",   "6221722237586476575",   "6221722237586476575",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622173_length19",  true,   "6221734441538560355",   "6221734441538560355",   "6221734441538560355",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622174_length19",  true,   "6221745300351575154",   "6221745300351575154",   "6221745300351575154",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622175_length19",  true,   "6221757465618176743",   "6221757465618176743",   "6221757465618176743",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622176_length19",  true,   "6221766830072870835",   "6221766830072870835",   "6221766830072870835",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622177_length19",  true,   "6221774815222366040",   "6221774815222366040",   "6221774815222366040",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622178_length19",  true,   "6221783466703888463",   "6221783466703888463",   "6221783466703888463",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622179_length19",  true,   "6221797346718222805",   "6221797346718222805",   "6221797346718222805",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622180_length19",  true,   "6221808163842627669",   "6221808163842627669",   "6221808163842627669",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622181_length19",  true,   "6221815161825554067",   "6221815161825554067",   "6221815161825554067",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622182_length19",  true,   "6221826240342032588",   "6221826240342032588",   "6221826240342032588",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622183_length19",  true,   "6221833067344074511",   "6221833067344074511",   "6221833067344074511",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622184_length19",  true,   "6221840356421713641",   "6221840356421713641",   "6221840356421713641",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622185_length19",  true,   "6221858255502106056",   "6221858255502106056",   "6221858255502106056",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622186_length19",  true,   "6221867644552546700",   "6221867644552546700",   "6221867644552546700",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622187_length19",  true,   "6221877177802864324",   "6221877177802864324",   "6221877177802864324",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622188_length19",  true,   "6221884253144317353",   "6221884253144317353",   "6221884253144317353",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622189_length19",  true,   "6221892632166113008",   "6221892632166113008",   "6221892632166113008",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622190_length19",  true,   "6221901643838647389",   "6221901643838647389",   "6221901643838647389",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622191_length19",  true,   "6221915163635243237",   "6221915163635243237",   "6221915163635243237",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622192_length19",  true,   "6221926358055026743",   "6221926358055026743",   "6221926358055026743",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622193_length19",  true,   "6221938331785167513",   "6221938331785167513",   "6221938331785167513",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622194_length19",  true,   "6221946765752171323",   "6221946765752171323",   "6221946765752171323",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622195_length19",  true,   "6221956181681485205",   "6221956181681485205",   "6221956181681485205",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622196_length19",  true,   "6221962214170106040",   "6221962214170106040",   "6221962214170106040",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622197_length19",  true,   "6221977367475751432",   "6221977367475751432",   "6221977367475751432",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622198_length19",  true,   "6221982871481571281",   "6221982871481571281",   "6221982871481571281",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622199_length19",  true,   "6221995828365568515",   "6221995828365568515",   "6221995828365568515",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622200_length19",  true,   "6222007834816212517",   "6222007834816212517",   "6222007834816212517",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622201_length19",  true,   "6222017587378014428",   "6222017587378014428",   "6222017587378014428",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622202_length19",  true,   "6222022666503511111",   "6222022666503511111",   "6222022666503511111",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622203_length19",  true,   "6222035468411763826",   "6222035468411763826",   "6222035468411763826",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622204_length19",  true,   "6222048202380282707",   "6222048202380282707",   "6222048202380282707",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622205_length19",  true,   "6222058078057076862",   "6222058078057076862",   "6222058078057076862",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622206_length19",  true,   "6222064880002682625",   "6222064880002682625",   "6222064880002682625",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622207_length19",  true,   "6222071285168735053",   "6222071285168735053",   "6222071285168735053",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622208_length19",  true,   "6222082486806544470",   "6222082486806544470",   "6222082486806544470",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622209_length19",  true,   "6222091267427475214",   "6222091267427475214",   "6222091267427475214",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622210_length19",  true,   "6222105534344283367",   "6222105534344283367",   "6222105534344283367",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622211_length19",  true,   "6222115408474460442",   "6222115408474460442",   "6222115408474460442",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622212_length19",  true,   "6222127512408884266",   "6222127512408884266",   "6222127512408884266",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622213_length19",  true,   "6222136728687430071",   "6222136728687430071",   "6222136728687430071",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622214_length19",  true,   "6222145535722287526",   "6222145535722287526",   "6222145535722287526",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622215_length19",  true,   "6222150247575332175",   "6222150247575332175",   "6222150247575332175",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622216_length19",  true,   "6222162634312325362",   "6222162634312325362",   "6222162634312325362",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622217_length19",  true,   "6222177400540664656",   "6222177400540664656",   "6222177400540664656",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622218_length19",  true,   "6222181245610606630",   "6222181245610606630",   "6222181245610606630",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622219_length19",  true,   "6222191676244580312",   "6222191676244580312",   "6222191676244580312",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622220_length19",  true,   "6222200676411576829",   "6222200676411576829",   "6222200676411576829",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622221_length19",  true,   "6222213436850061881",   "6222213436850061881",   "6222213436850061881",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622222_length19",  true,   "6222220782542165205",   "6222220782542165205",   "6222220782542165205",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622223_length19",  true,   "6222232622637671889",   "6222232622637671889",   "6222232622637671889",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622224_length19",  true,   "6222244818865566272",   "6222244818865566272",   "6222244818865566272",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622225_length19",  true,   "6222255048116461646",   "6222255048116461646",   "6222255048116461646",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622226_length19",  true,   "6222263782828847342",   "6222263782828847342",   "6222263782828847342",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622227_length19",  true,   "6222270787445684052",   "6222270787445684052",   "6222270787445684052",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622228_length19",  true,   "6222282866785161123",   "6222282866785161123",   "6222282866785161123",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622229_length19",  true,   "6222295085305450685",   "6222295085305450685",   "6222295085305450685",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622230_length19",  true,   "6222304888557613465",   "6222304888557613465",   "6222304888557613465",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622231_length19",  true,   "6222313168843437725",   "6222313168843437725",   "6222313168843437725",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622232_length19",  true,   "6222322348100362522",   "6222322348100362522",   "6222322348100362522",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622233_length19",  true,   "6222330257246168703",   "6222330257246168703",   "6222330257246168703",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622234_length19",  true,   "6222344380304617223",   "6222344380304617223",   "6222344380304617223",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622235_length19",  true,   "6222358211701216801",   "6222358211701216801",   "6222358211701216801",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622236_length19",  true,   "6222362323728844822",   "6222362323728844822",   "6222362323728844822",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622237_length19",  true,   "6222375875843170305",   "6222375875843170305",   "6222375875843170305",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622238_length19",  true,   "6222383558271750026",   "6222383558271750026",   "6222383558271750026",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622239_length19",  true,   "6222391217507126549",   "6222391217507126549",   "6222391217507126549",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622240_length19",  true,   "6222408643487684606",   "6222408643487684606",   "6222408643487684606",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622241_length19",  true,   "6222418557117804087",   "6222418557117804087",   "6222418557117804087",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622242_length19",  true,   "6222425640360245140",   "6222425640360245140",   "6222425640360245140",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622243_length19",  true,   "6222433235674473031",   "6222433235674473031",   "6222433235674473031",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622244_length19",  true,   "6222441447012526756",   "6222441447012526756",   "6222441447012526756",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622245_length19",  true,   "6222455274857486232",   "6222455274857486232",   "6222455274857486232",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622246_length19",  true,   "6222466870740265068",   "6222466870740265068",   "6222466870740265068",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622247_length19",  true,   "6222473810301351346",   "6222473810301351346",   "6222473810301351346",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622248_length19",  true,   "6222482467235060276",   "6222482467235060276",   "6222482467235060276",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622249_length19",  true,   "6222497175317701674",   "6222497175317701674",   "6222497175317701674",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622250_length19",  true,   "6222502762248637045",   "6222502762248637045",   "6222502762248637045",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622251_length19",  true,   "6222514564468152341",   "6222514564468152341",   "6222514564468152341",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622252_length19",  true,   "6222527071767077034",   "6222527071767077034",   "6222527071767077034",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622253_length19",  true,   "6222531782248462322",   "6222531782248462322",   "6222531782248462322",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622254_length19",  true,   "6222544448432374575",   "6222544448432374575",   "6222544448432374575",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622255_length19",  true,   "6222557262361464131",   "6222557262361464131",   "6222557262361464131",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622256_length19",  true,   "6222561200857077607",   "6222561200857077607",   "6222561200857077607",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622257_length19",  true,   "6222577768085884087",   "6222577768085884087",   "6222577768085884087",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622258_length19",  true,   "6222588727245182284",   "6222588727245182284",   "6222588727245182284",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622259_length19",  true,   "6222592804183554644",   "6222592804183554644",   "6222592804183554644",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622260_length19",  true,   "6222606364213212154",   "6222606364213212154",   "6222606364213212154",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622261_length19",  true,   "6222616887534031380",   "6222616887534031380",   "6222616887534031380",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622262_length19",  true,   "6222625711825488373",   "6222625711825488373",   "6222625711825488373",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622263_length19",  true,   "6222635104210230618",   "6222635104210230618",   "6222635104210230618",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622264_length19",  true,   "6222643140584335401",   "6222643140584335401",   "6222643140584335401",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622265_length19",  true,   "6222655183664376056",   "6222655183664376056",   "6222655183664376056",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622266_length19",  true,   "6222667718231258828",   "6222667718231258828",   "6222667718231258828",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622267_length19",  true,   "6222672404281863600",   "6222672404281863600",   "6222672404281863600",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622268_length19",  true,   "6222687831715308153",   "6222687831715308153",   "6222687831715308153",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622269_length19",  true,   "6222695530836848242",   "6222695530836848242",   "6222695530836848242",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622270_length19",  true,   "6222703412213556377",   "6222703412213556377",   "6222703412213556377",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622271_length19",  true,   "6222717174710852774",   "6222717174710852774",   "6222717174710852774",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622272_length19",  true,   "6222726526510330617",   "6222726526510330617",   "6222726526510330617",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622273_length19",  true,   "6222732850765010027",   "6222732850765010027",   "6222732850765010027",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622274_length19",  true,   "6222745818722755625",   "6222745818722755625",   "6222745818722755625",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622275_length19",  true,   "6222750253601140065",   "6222750253601140065",   "6222750253601140065",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622276_length19",  true,   "6222761382412450483",   "6222761382412450483",   "6222761382412450483",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622277_length19",  true,   "6222777063015235701",   "6222777063015235701",   "6222777063015235701",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622278_length19",  true,   "6222787376137068752",   "6222787376137068752",   "6222787376137068752",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622279_length19",  true,   "6222792102672116449",   "6222792102672116449",   "6222792102672116449",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622280_length19",  true,   "6222801324400625868",   "6222801324400625868",   "6222801324400625868",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622281_length19",  true,   "6222818163034033821",   "6222818163034033821",   "6222818163034033821",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622282_length19",  true,   "6222826481210106363",   "6222826481210106363",   "6222826481210106363",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622283_length19",  true,   "6222838502457313846",   "6222838502457313846",   "6222838502457313846",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622284_length19",  true,   "6222841731822040439",   "6222841731822040439",   "6222841731822040439",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622285_length19",  true,   "6222858675715004137",   "6222858675715004137",   "6222858675715004137",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622286_length19",  true,   "6222861801432003252",   "6222861801432003252",   "6222861801432003252",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622287_length19",  true,   "6222873520362525581",   "6222873520362525581",   "6222873520362525581",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622288_length19",  true,   "6222886401140216519",   "6222886401140216519",   "6222886401140216519",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622289_length19",  true,   "6222894543825686423",   "6222894543825686423",   "6222894543825686423",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622290_length19",  true,   "6222902313473246833",   "6222902313473246833",   "6222902313473246833",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622291_length19",  true,   "6222915505340020847",   "6222915505340020847",   "6222915505340020847",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622292_length19",  true,   "6222928334571211859",   "6222928334571211859",   "6222928334571211859",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622293_length19",  true,   "6222933811218035562",   "6222933811218035562",   "6222933811218035562",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622294_length19",  true,   "6222941561072746131",   "6222941561072746131",   "6222941561072746131",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622295_length19",  true,   "6222950681021213005",   "6222950681021213005",   "6222950681021213005",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622296_length19",  true,   "6222966416253722585",   "6222966416253722585",   "6222966416253722585",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622297_length19",  true,   "6222971451715444059",   "6222971451715444059",   "6222971451715444059",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622298_length19",  true,   "6222983347616425666",   "6222983347616425666",   "6222983347616425666",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622299_length19",  true,   "6222997644718823200",   "6222997644718823200",   "6222997644718823200",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622300_length19",  true,   "6223006213561215729",   "6223006213561215729",   "6223006213561215729",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622301_length19",  true,   "6223015617862334782",   "6223015617862334782",   "6223015617862334782",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622302_length19",  true,   "6223026217208715310",   "6223026217208715310",   "6223026217208715310",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622303_length19",  true,   "6223035125707865156",   "6223035125707865156",   "6223035125707865156",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622304_length19",  true,   "6223046580683524358",   "6223046580683524358",   "6223046580683524358",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622305_length19",  true,   "6223053713062446774",   "6223053713062446774",   "6223053713062446774",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622306_length19",  true,   "6223061508667354518",   "6223061508667354518",   "6223061508667354518",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622307_length19",  true,   "6223073081056437589",   "6223073081056437589",   "6223073081056437589",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622308_length19",  true,   "6223082137860478083",   "6223082137860478083",   "6223082137860478083",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622309_length19",  true,   "6223092525624528532",   "6223092525624528532",   "6223092525624528532",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622310_length19",  true,   "6223106825570476361",   "6223106825570476361",   "6223106825570476361",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622311_length19",  true,   "6223115135044815338",   "6223115135044815338",   "6223115135044815338",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622312_length19",  true,   "6223126262403535369",   "6223126262403535369",   "6223126262403535369",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622313_length19",  true,   "6223138468676831544",   "6223138468676831544",   "6223138468676831544",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622314_length19",  true,   "6223148124655786724",   "6223148124655786724",   "6223148124655786724",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622315_length19",  true,   "6223151151534288584",   "6223151151534288584",   "6223151151534288584",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622316_length19",  true,   "6223164663234260569",   "6223164663234260569",   "6223164663234260569",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622317_length19",  true,   "6223171467041580875",   "6223171467041580875",   "6223171467041580875",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622318_length19",  true,   "6223181350270254289",   "6223181350270254289",   "6223181350270254289",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622319_length19",  true,   "6223193425257634772",   "6223193425257634772",   "6223193425257634772",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622320_length19",  true,   "6223206431861554385",   "6223206431861554385",   "6223206431861554385",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622321_length19",  true,   "6223215157514543249",   "6223215157514543249",   "6223215157514543249",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622322_length19",  true,   "6223227224721515380",   "6223227224721515380",   "6223227224721515380",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622323_length19",  true,   "6223232508816528131",   "6223232508816528131",   "6223232508816528131",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622324_length19",  true,   "6223246518258856621",   "6223246518258856621",   "6223246518258856621",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622325_length19",  true,   "6223256214187117163",   "6223256214187117163",   "6223256214187117163",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622326_length19",  true,   "6223265426046812243",   "6223265426046812243",   "6223265426046812243",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622327_length19",  true,   "6223272054338218274",   "6223272054338218274",   "6223272054338218274",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622328_length19",  true,   "6223281465812744321",   "6223281465812744321",   "6223281465812744321",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622329_length19",  true,   "6223294313545262879",   "6223294313545262879",   "6223294313545262879",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622330_length19",  true,   "6223300084733678018",   "6223300084733678018",   "6223300084733678018",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622331_length19",  true,   "6223317083653068219",   "6223317083653068219",   "6223317083653068219",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622332_length19",  true,   "6223320578353231772",   "6223320578353231772",   "6223320578353231772",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622333_length19",  true,   "6223338303341370362",   "6223338303341370362",   "6223338303341370362",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622334_length19",  true,   "6223341244865813657",   "6223341244865813657",   "6223341244865813657",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622335_length19",  true,   "6223357633800146069",   "6223357633800146069",   "6223357633800146069",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622336_length19",  true,   "6223361202750150069",   "6223361202750150069",   "6223361202750150069",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622337_length19",  true,   "6223376657604238514",   "6223376657604238514",   "6223376657604238514",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622338_length19",  true,   "6223383521604367478",   "6223383521604367478",   "6223383521604367478",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622339_length19",  true,   "6223396550051716114",   "6223396550051716114",   "6223396550051716114",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622340_length19",  true,   "6223405133037040468",   "6223405133037040468",   "6223405133037040468",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622341_length19",  true,   "6223410144801782675",   "6223410144801782675",   "6223410144801782675",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622342_length19",  true,   "6223420123228444380",   "6223420123228444380",   "6223420123228444380",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622343_length19",  true,   "6223436085570483427",   "6223436085570483427",   "6223436085570483427",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622344_length19",  true,   "6223440185046576004",   "6223440185046576004",   "6223440185046576004",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622345_length19",  true,   "6223453174052421184",   "6223453174052421184",   "6223453174052421184",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622346_length19",  true,   "6223463047627833364",   "6223463047627833364",   "6223463047627833364",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622347_length19",  true,   "6223471201023552363",   "6223471201023552363",   "6223471201023552363",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622348_length19",  true,   "6223487831282757121",   "6223487831282757121",   "6223487831282757121",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622349_length19",  true,   "6223491782605386219",   "6223491782605386219",   "6223491782605386219",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622350_length19",  true,   "6223508477786381128",   "6223508477786381128",   "6223508477786381128",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622351_length19",  true,   "6223515421357450533",   "6223515421357450533",   "6223515421357450533",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622352_length19",  true,   "6223524155064554455",   "6223524155064554455",   "6223524155064554455",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622353_length19",  true,   "6223537207102723785",   "6223537207102723785",   "6223537207102723785",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622354_length19",  true,   "6223541813758024388",   "6223541813758024388",   "6223541813758024388",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622355_length19",  true,   "6223556757150886443",   "6223556757150886443",   "6223556757150886443",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622356_length19",  true,   "6223567000583810863",   "6223567000583810863",   "6223567000583810863",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622357_length19",  true,   "6223570765001685163",   "6223570765001685163",   "6223570765001685163",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622358_length19",  true,   "6223586013621272175",   "6223586013621272175",   "6223586013621272175",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622359_length19",  true,   "6223594348616028863",   "6223594348616028863",   "6223594348616028863",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622360_length19",  true,   "6223601817218413781",   "6223601817218413781",   "6223601817218413781",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622361_length19",  true,   "6223612263608438467",   "6223612263608438467",   "6223612263608438467",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622362_length19",  true,   "6223624330863604020",   "6223624330863604020",   "6223624330863604020",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622363_length19",  true,   "6223630540524142481",   "6223630540524142481",   "6223630540524142481",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622364_length19",  true,   "6223640742584527076",   "6223640742584527076",   "6223640742584527076",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622365_length19",  true,   "6223650357110601019",   "6223650357110601019",   "6223650357110601019",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622366_length19",  true,   "6223661736836303389",   "6223661736836303389",   "6223661736836303389",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622367_length19",  true,   "6223672575213353071",   "6223672575213353071",   "6223672575213353071",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622368_length19",  true,   "6223680581252775570",   "6223680581252775570",   "6223680581252775570",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622369_length19",  true,   "6223691040153108834",   "6223691040153108834",   "6223691040153108834",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622370_length19",  true,   "6223703715070515643",   "6223703715070515643",   "6223703715070515643",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622371_length19",  true,   "6223716606587701666",   "6223716606587701666",   "6223716606587701666",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622372_length19",  true,   "6223722600433346737",   "6223722600433346737",   "6223722600433346737",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622373_length19",  true,   "6223736786130862748",   "6223736786130862748",   "6223736786130862748",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622374_length19",  true,   "6223747301585148507",   "6223747301585148507",   "6223747301585148507",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622375_length19",  true,   "6223751510648001585",   "6223751510648001585",   "6223751510648001585",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622376_length19",  true,   "6223761240113526704",   "6223761240113526704",   "6223761240113526704",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622377_length19",  true,   "6223772781625227825",   "6223772781625227825",   "6223772781625227825",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622378_length19",  true,   "6223785216443623736",   "6223785216443623736",   "6223785216443623736",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622379_length19",  true,   "6223795217686305179",   "6223795217686305179",   "6223795217686305179",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622380_length19",  true,   "6223807811643285650",   "6223807811643285650",   "6223807811643285650",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622381_length19",  true,   "6223810153207330233",   "6223810153207330233",   "6223810153207330233",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622382_length19",  true,   "6223827700544135757",   "6223827700544135757",   "6223827700544135757",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622383_length19",  true,   "6223834475045821681",   "6223834475045821681",   "6223834475045821681",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622384_length19",  true,   "6223848333505343775",   "6223848333505343775",   "6223848333505343775",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622385_length19",  true,   "6223855578605408643",   "6223855578605408643",   "6223855578605408643",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622386_length19",  true,   "6223866634083158049",   "6223866634083158049",   "6223866634083158049",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622387_length19",  true,   "6223872278571620144",   "6223872278571620144",   "6223872278571620144",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622388_length19",  true,   "6223886553575526537",   "6223886553575526537",   "6223886553575526537",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622389_length19",  true,   "6223896207428643563",   "6223896207428643563",   "6223896207428643563",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622390_length19",  true,   "6223903365138860132",   "6223903365138860132",   "6223903365138860132",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622391_length19",  true,   "6223913017048787081",   "6223913017048787081",   "6223913017048787081",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622392_length19",  true,   "6223928712064811178",   "6223928712064811178",   "6223928712064811178",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622393_length19",  true,   "6223931056870725817",   "6223931056870725817",   "6223931056870725817",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622394_length19",  true,   "6223948018670605889",   "6223948018670605889",   "6223948018670605889",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622395_length19",  true,   "6223955640530363209",   "6223955640530363209",   "6223955640530363209",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622396_length19",  true,   "6223965550278154728",   "6223965550278154728",   "6223965550278154728",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622397_length19",  true,   "6223970538844111614",   "6223970538844111614",   "6223970538844111614",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622398_length19",  true,   "6223983582147202147",   "6223983582147202147",   "6223983582147202147",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622399_length19",  true,   "6223990257851420646",   "6223990257851420646",   "6223990257851420646",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622400_length19",  true,   "6224001267676252756",   "6224001267676252756",   "6224001267676252756",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622401_length19",  true,   "6224012117073324657",   "6224012117073324657",   "6224012117073324657",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622402_length19",  true,   "6224023043880032001",   "6224023043880032001",   "6224023043880032001",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622403_length19",  true,   "6224037457662207025",   "6224037457662207025",   "6224037457662207025",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622404_length19",  true,   "6224040628357804236",   "6224040628357804236",   "6224040628357804236",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622405_length19",  true,   "6224052710860421578",   "6224052710860421578",   "6224052710860421578",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622406_length19",  true,   "6224068852414482128",   "6224068852414482128",   "6224068852414482128",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622407_length19",  true,   "6224076420180657172",   "6224076420180657172",   "6224076420180657172",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622408_length19",  true,   "6224088884323174641",   "6224088884323174641",   "6224088884323174641",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622409_length19",  true,   "6224092162484001885",   "6224092162484001885",   "6224092162484001885",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622410_length19",  true,   "6224104165484805615",   "6224104165484805615",   "6224104165484805615",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622411_length19",  true,   "6224113766404516205",   "6224113766404516205",   "6224113766404516205",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622412_length19",  true,   "6224128060718626204",   "6224128060718626204",   "6224128060718626204",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622413_length19",  true,   "6224133725857555645",   "6224133725857555645",   "6224133725857555645",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622414_length19",  true,   "6224144656470182623",   "6224144656470182623",   "6224144656470182623",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622415_length19",  true,   "6224151358645560474",   "6224151358645560474",   "6224151358645560474",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622416_length19",  true,   "6224165663413808755",   "6224165663413808755",   "6224165663413808755",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622417_length19",  true,   "6224178763436646532",   "6224178763436646532",   "6224178763436646532",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622418_length19",  true,   "6224186657245356004",   "6224186657245356004",   "6224186657245356004",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622419_length19",  true,   "6224192638333778459",   "6224192638333778459",   "6224192638333778459",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622420_length19",  true,   "6224200323602212387",   "6224200323602212387",   "6224200323602212387",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622421_length19",  true,   "6224217414018556227",   "6224217414018556227",   "6224217414018556227",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622422_length19",  true,   "6224228767326240520",   "6224228767326240520",   "6224228767326240520",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622423_length19",  true,   "6224232816780616479",   "6224232816780616479",   "6224232816780616479",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622424_length19",  true,   "6224244582126754244",   "6224244582126754244",   "6224244582126754244",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622425_length19",  true,   "6224258302528034316",   "6224258302528034316",   "6224258302528034316",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622426_length19",  true,   "6224262373267163107",   "6224262373267163107",   "6224262373267163107",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622427_length19",  true,   "6224278266137685782",   "6224278266137685782",   "6224278266137685782",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622428_length19",  true,   "6224288525806571310",   "6224288525806571310",   "6224288525806571310",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622429_length19",  true,   "6224294037717063777",   "6224294037717063777",   "6224294037717063777",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622430_length19",  true,   "6224305266627618803",   "6224305266627618803",   "6224305266627618803",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622431_length19",  true,   "6224312325254020708",   "6224312325254020708",   "6224312325254020708",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622432_length19",  true,   "6224324648216000476",   "6224324648216000476",   "6224324648216000476",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622433_length19",  true,   "6224333507624007078",   "6224333507624007078",   "6224333507624007078",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622434_length19",  true,   "6224345356446421117",   "6224345356446421117",   "6224345356446421117",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622435_length19",  true,   "6224351312257268155",   "6224351312257268155",   "6224351312257268155",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622436_length19",  true,   "6224364448225838565",   "6224364448225838565",   "6224364448225838565",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622437_length19",  true,   "6224374085168720000",   "6224374085168720000",   "6224374085168720000",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622438_length19",  true,   "6224388614671625507",   "6224388614671625507",   "6224388614671625507",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622439_length19",  true,   "6224390747110452871",   "6224390747110452871",   "6224390747110452871",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622440_length19",  true,   "6224408474441735607",   "6224408474441735607",   "6224408474441735607",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622441_length19",  true,   "6224412120645250174",   "6224412120645250174",   "6224412120645250174",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622442_length19",  true,   "6224421348181704150",   "6224421348181704150",   "6224421348181704150",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622443_length19",  true,   "6224435488254617352",   "6224435488254617352",   "6224435488254617352",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622444_length19",  true,   "6224443302623703225",   "6224443302623703225",   "6224443302623703225",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622445_length19",  true,   "6224454205124111861",   "6224454205124111861",   "6224454205124111861",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622446_length19",  true,   "6224464331063552531",   "6224464331063552531",   "6224464331063552531",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622447_length19",  true,   "6224472660350637666",   "6224472660350637666",   "6224472660350637666",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622448_length19",  true,   "6224481234258555674",   "6224481234258555674",   "6224481234258555674",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622449_length19",  true,   "6224490778761317740",   "6224490778761317740",   "6224490778761317740",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622450_length19",  true,   "6224507376405367287",   "6224507376405367287",   "6224507376405367287",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622451_length19",  true,   "6224512737878384559",   "6224512737878384559",   "6224512737878384559",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622452_length19",  true,   "6224525306314404846",   "6224525306314404846",   "6224525306314404846",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622453_length19",  true,   "6224532465676744842",   "6224532465676744842",   "6224532465676744842",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622454_length19",  true,   "6224540805144082277",   "6224540805144082277",   "6224540805144082277",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622455_length19",  true,   "6224553743786338307",   "6224553743786338307",   "6224553743786338307",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622456_length19",  true,   "6224560583857712662",   "6224560583857712662",   "6224560583857712662",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622457_length19",  true,   "6224572257855318261",   "6224572257855318261",   "6224572257855318261",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622458_length19",  true,   "6224585488210610622",   "6224585488210610622",   "6224585488210610622",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622459_length19",  true,   "6224592820340856439",   "6224592820340856439",   "6224592820340856439",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622460_length19",  true,   "6224600260243772674",   "6224600260243772674",   "6224600260243772674",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622461_length19",  true,   "6224613303518128647",   "6224613303518128647",   "6224613303518128647",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622462_length19",  true,   "6224622244514076258",   "6224622244514076258",   "6224622244514076258",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622463_length19",  true,   "6224634624017370009",   "6224634624017370009",   "6224634624017370009",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622464_length19",  true,   "6224641645664256358",   "6224641645664256358",   "6224641645664256358",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622465_length19",  true,   "6224656384421651279",   "6224656384421651279",   "6224656384421651279",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622466_length19",  true,   "6224661654880034354",   "6224661654880034354",   "6224661654880034354",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622467_length19",  true,   "6224677442858837459",   "6224677442858837459",   "6224677442858837459",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622468_length19",  true,   "6224681074641666137",   "6224681074641666137",   "6224681074641666137",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622469_length19",  true,   "6224694380283555347",   "6224694380283555347",   "6224694380283555347",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622470_length19",  true,   "6224700341537416738",   "6224700341537416738",   "6224700341537416738",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622471_length19",  true,   "6224717246585640835",   "6224717246585640835",   "6224717246585640835",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622472_length19",  true,   "6224723842364750639",   "6224723842364750639",   "6224723842364750639",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622473_length19",  true,   "6224738364355782847",   "6224738364355782847",   "6224738364355782847",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622474_length19",  true,   "6224744320264440143",   "6224744320264440143",   "6224744320264440143",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622475_length19",  true,   "6224753313837186176",   "6224753313837186176",   "6224753313837186176",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622476_length19",  true,   "6224765626605656609",   "6224765626605656609",   "6224765626605656609",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622477_length19",  true,   "6224773204773666089",   "6224773204773666089",   "6224773204773666089",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622478_length19",  true,   "6224780538410480847",   "6224780538410480847",   "6224780538410480847",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622479_length19",  true,   "6224791418276770515",   "6224791418276770515",   "6224791418276770515",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622480_length19",  true,   "6224802600553781847",   "6224802600553781847",   "6224802600553781847",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622481_length19",  true,   "6224812817705141161",   "6224812817705141161",   "6224812817705141161",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622482_length19",  true,   "6224821605152463884",   "6224821605152463884",   "6224821605152463884",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622483_length19",  true,   "6224830537827205458",   "6224830537827205458",   "6224830537827205458",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622484_length19",  true,   "6224840641238761311",   "6224840641238761311",   "6224840641238761311",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622485_length19",  true,   "6224850325702546229",   "6224850325702546229",   "6224850325702546229",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622486_length19",  true,   "6224864284505685748",   "6224864284505685748",   "6224864284505685748",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622487_length19",  true,   "6224877505504280817",   "6224877505504280817",   "6224877505504280817",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622488_length19",  true,   "6224884075370118039",   "6224884075370118039",   "6224884075370118039",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622489_length19",  true,   "6224893760844110360",   "6224893760844110360",   "6224893760844110360",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622490_length19",  true,   "6224907407506274670",   "6224907407506274670",   "6224907407506274670",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622491_length19",  true,   "6224914584264644434",   "6224914584264644434",   "6224914584264644434",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622492_length19",  true,   "6224921766774430542",   "6224921766774430542",   "6224921766774430542",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622493_length19",  true,   "6224932846283305182",   "6224932846283305182",   "6224932846283305182",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622494_length19",  true,   "6224948444224782412",   "6224948444224782412",   "6224948444224782412",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622495_length19",  true,   "6224951400763748754",   "6224951400763748754",   "6224951400763748754",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622496_length19",  true,   "6224967145738024433",   "6224967145738024433",   "6224967145738024433",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622497_length19",  true,   "6224972142670164353",   "6224972142670164353",   "6224972142670164353",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622498_length19",  true,   "6224981785463704063",   "6224981785463704063",   "6224981785463704063",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622499_length19",  true,   "6224998566771577107",   "6224998566771577107",   "6224998566771577107",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622500_length19",  true,   "6225005354000170244",   "6225005354000170244",   "6225005354000170244",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622501_length19",  true,   "6225011654373150315",   "6225011654373150315",   "6225011654373150315",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622502_length19",  true,   "6225026254054513346",   "6225026254054513346",   "6225026254054513346",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622503_length19",  true,   "6225032047444024434",   "6225032047444024434",   "6225032047444024434",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622504_length19",  true,   "6225042844753553104",   "6225042844753553104",   "6225042844753553104",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622505_length19",  true,   "6225056173234385727",   "6225056173234385727",   "6225056173234385727",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622506_length19",  true,   "6225067200783242772",   "6225067200783242772",   "6225067200783242772",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622507_length19",  true,   "6225077735527032532",   "6225077735527032532",   "6225077735527032532",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622508_length19",  true,   "6225088677225280285",   "6225088677225280285",   "6225088677225280285",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622509_length19",  true,   "6225098154141663612",   "6225098154141663612",   "6225098154141663612",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622510_length19",  true,   "6225101450085372474",   "6225101450085372474",   "6225101450085372474",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622511_length19",  true,   "6225112602433411621",   "6225112602433411621",   "6225112602433411621",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622512_length19",  true,   "6225125127503163212",   "6225125127503163212",   "6225125127503163212",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622513_length19",  true,   "6225138424002404212",   "6225138424002404212",   "6225138424002404212",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622514_length19",  true,   "6225142087143184227",   "6225142087143184227",   "6225142087143184227",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622515_length19",  true,   "6225151240382175384",   "6225151240382175384",   "6225151240382175384",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622516_length19",  true,   "6225167715630835063",   "6225167715630835063",   "6225167715630835063",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622517_length19",  true,   "6225177202400430654",   "6225177202400430654",   "6225177202400430654",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622518_length19",  true,   "6225186370380703728",   "6225186370380703728",   "6225186370380703728",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622519_length19",  true,   "6225198351836042404",   "6225198351836042404",   "6225198351836042404",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622520_length19",  true,   "6225204803386811317",   "6225204803386811317",   "6225204803386811317",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622521_length19",  true,   "6225214648463682679",   "6225214648463682679",   "6225214648463682679",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622522_length19",  true,   "6225228085748647314",   "6225228085748647314",   "6225228085748647314",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622523_length19",  true,   "6225234024836308689",   "6225234024836308689",   "6225234024836308689",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622524_length19",  true,   "6225248333536630563",   "6225248333536630563",   "6225248333536630563",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622525_length19",  true,   "6225256121541227361",   "6225256121541227361",   "6225256121541227361",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622526_length19",  true,   "6225260070024358173",   "6225260070024358173",   "6225260070024358173",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622527_length19",  true,   "6225278771182762144",   "6225278771182762144",   "6225278771182762144",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622528_length19",  true,   "6225282652544441730",   "6225282652544441730",   "6225282652544441730",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622529_length19",  true,   "6225298475743428411",   "6225298475743428411",   "6225298475743428411",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622530_length19",  true,   "6225302013302654806",   "6225302013302654806",   "6225302013302654806",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622531_length19",  true,   "6225313112283572628",   "6225313112283572628",   "6225313112283572628",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622532_length19",  true,   "6225322568175316656",   "6225322568175316656",   "6225322568175316656",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622533_length19",  true,   "6225338657504128551",   "6225338657504128551",   "6225338657504128551",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622534_length19",  true,   "6225347417600343854",   "6225347417600343854",   "6225347417600343854",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622535_length19",  true,   "6225358708256003578",   "6225358708256003578",   "6225358708256003578",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622536_length19",  true,   "6225360020351088603",   "6225360020351088603",   "6225360020351088603",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622537_length19",  true,   "6225373540245040341",   "6225373540245040341",   "6225373540245040341",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622538_length19",  true,   "6225387464732361553",   "6225387464732361553",   "6225387464732361553",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622539_length19",  true,   "6225394272036116644",   "6225394272036116644",   "6225394272036116644",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622540_length19",  true,   "6225406740731076046",   "6225406740731076046",   "6225406740731076046",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622541_length19",  true,   "6225417320648203079",   "6225417320648203079",   "6225417320648203079",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622542_length19",  true,   "6225424811733085521",   "6225424811733085521",   "6225424811733085521",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622543_length19",  true,   "6225431680744065157",   "6225431680744065157",   "6225431680744065157",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622544_length19",  true,   "6225445407154215229",   "6225445407154215229",   "6225445407154215229",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622545_length19",  true,   "6225455884662448210",   "6225455884662448210",   "6225455884662448210",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622546_length19",  true,   "6225466073401774451",   "6225466073401774451",   "6225466073401774451",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622547_length19",  true,   "6225475313384426680",   "6225475313384426680",   "6225475313384426680",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622548_length19",  true,   "6225485858010536888",   "6225485858010536888",   "6225485858010536888",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622549_length19",  true,   "6225493277542070409",   "6225493277542070409",   "6225493277542070409",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622550_length19",  true,   "6225504633215218609",   "6225504633215218609",   "6225504633215218609",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622551_length19",  true,   "6225512228653250865",   "6225512228653250865",   "6225512228653250865",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622552_length19",  true,   "6225526271338246431",   "6225526271338246431",   "6225526271338246431",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622553_length19",  true,   "6225532057665475780",   "6225532057665475780",   "6225532057665475780",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622554_length19",  true,   "6225547326167832456",   "6225547326167832456",   "6225547326167832456",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622555_length19",  true,   "6225551058380782548",   "6225551058380782548",   "6225551058380782548",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622556_length19",  true,   "6225562458447677722",   "6225562458447677722",   "6225562458447677722",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622557_length19",  true,   "6225578281623188526",   "6225578281623188526",   "6225578281623188526",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622558_length19",  true,   "6225582410877261242",   "6225582410877261242",   "6225582410877261242",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622559_length19",  true,   "6225598170807561606",   "6225598170807561606",   "6225598170807561606",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622560_length19",  true,   "6225608028382158743",   "6225608028382158743",   "6225608028382158743",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622561_length19",  true,   "6225615175075633283",   "6225615175075633283",   "6225615175075633283",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622562_length19",  true,   "6225623657554248659",   "6225623657554248659",   "6225623657554248659",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622563_length19",  true,   "6225633705528857242",   "6225633705528857242",   "6225633705528857242",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622564_length19",  true,   "6225640806508785477",   "6225640806508785477",   "6225640806508785477",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622565_length19",  true,   "6225650655012473089",   "6225650655012473089",   "6225650655012473089",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622566_length19",  true,   "6225664130121057359",   "6225664130121057359",   "6225664130121057359",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622567_length19",  true,   "6225670167388613336",   "6225670167388613336",   "6225670167388613336",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622568_length19",  true,   "6225687873605718854",   "6225687873605718854",   "6225687873605718854",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622569_length19",  true,   "6225692760752668037",   "6225692760752668037",   "6225692760752668037",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622570_length19",  true,   "6225700285870562623",   "6225700285870562623",   "6225700285870562623",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622571_length19",  true,   "6225718287303284445",   "6225718287303284445",   "6225718287303284445",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622572_length19",  true,   "6225724768452760311",   "6225724768452760311",   "6225724768452760311",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622573_length19",  true,   "6225736453380807304",   "6225736453380807304",   "6225736453380807304",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622574_length19",  true,   "6225744870240753453",   "6225744870240753453",   "6225744870240753453",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622575_length19",  true,   "6225757145163383412",   "6225757145163383412",   "6225757145163383412",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622576_length19",  true,   "6225764861441826409",   "6225764861441826409",   "6225764861441826409",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622577_length19",  true,   "6225775282764546044",   "6225775282764546044",   "6225775282764546044",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622578_length19",  true,   "6225785028283788072",   "6225785028283788072",   "6225785028283788072",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622579_length19",  true,   "6225791054267318167",   "6225791054267318167",   "6225791054267318167",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622580_length19",  true,   "6225808686673148448",   "6225808686673148448",   "6225808686673148448",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622581_length19",  true,   "6225813515100238139",   "6225813515100238139",   "6225813515100238139",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622582_length19",  true,   "6225821254518451627",   "6225821254518451627",   "6225821254518451627",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622583_length19",  true,   "6225836500253332015",   "6225836500253332015",   "6225836500253332015",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622584_length19",  true,   "6225841210748551640",   "6225841210748551640",   "6225841210748551640",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622585_length19",  true,   "6225858180054233333",   "6225858180054233333",   "6225858180054233333",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622586_length19",  true,   "6225860321353751577",   "6225860321353751577",   "6225860321353751577",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622587_length19",  true,   "6225873208452236789",   "6225873208452236789",   "6225873208452236789",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622588_length19",  true,   "6225883486583674700",   "6225883486583674700",   "6225883486583674700",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622589_length19",  true,   "6225891465212474724",   "6225891465212474724",   "6225891465212474724",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622590_length19",  true,   "6225902005006080225",   "6225902005006080225",   "6225902005006080225",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622591_length19",  true,   "6225914665884468168",   "6225914665884468168",   "6225914665884468168",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622592_length19",  true,   "6225924408646354634",   "6225924408646354634",   "6225924408646354634",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622593_length19",  true,   "6225931682235000706",   "6225931682235000706",   "6225931682235000706",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622594_length19",  true,   "6225941144282443527",   "6225941144282443527",   "6225941144282443527",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622595_length19",  true,   "6225957507535322212",   "6225957507535322212",   "6225957507535322212",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622596_length19",  true,   "6225961126148078733",   "6225961126148078733",   "6225961126148078733",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622597_length19",  true,   "6225972561243382878",   "6225972561243382878",   "6225972561243382878",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622598_length19",  true,   "6225987451283272556",   "6225987451283272556",   "6225987451283272556",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622599_length19",  true,   "6225997826886115732",   "6225997826886115732",   "6225997826886115732",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622600_length19",  true,   "6226006054153321100",   "6226006054153321100",   "6226006054153321100",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622601_length19",  true,   "6226014562373031689",   "6226014562373031689",   "6226014562373031689",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622602_length19",  true,   "6226023651303601718",   "6226023651303601718",   "6226023651303601718",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622603_length19",  true,   "6226032517274552272",   "6226032517274552272",   "6226032517274552272",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622604_length19",  true,   "6226041221403134636",   "6226041221403134636",   "6226041221403134636",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622605_length19",  true,   "6226056175666483464",   "6226056175666483464",   "6226056175666483464",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622606_length19",  true,   "6226062701151808873",   "6226062701151808873",   "6226062701151808873",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622607_length19",  true,   "6226071276366864507",   "6226071276366864507",   "6226071276366864507",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622608_length19",  true,   "6226081061737413822",   "6226081061737413822",   "6226081061737413822",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622609_length19",  true,   "6226093582821264710",   "6226093582821264710",   "6226093582821264710",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622610_length19",  true,   "6226101213405582125",   "6226101213405582125",   "6226101213405582125",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622611_length19",  true,   "6226114184526403423",   "6226114184526403423",   "6226114184526403423",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622612_length19",  true,   "6226124027760452119",   "6226124027760452119",   "6226124027760452119",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622613_length19",  true,   "6226135327064885411",   "6226135327064885411",   "6226135327064885411",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622614_length19",  true,   "6226145845400201462",   "6226145845400201462",   "6226145845400201462",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622615_length19",  true,   "6226152806423510529",   "6226152806423510529",   "6226152806423510529",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622616_length19",  true,   "6226162588313852728",   "6226162588313852728",   "6226162588313852728",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622617_length19",  true,   "6226175380438423212",   "6226175380438423212",   "6226175380438423212",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622618_length19",  true,   "6226188413510853629",   "6226188413510853629",   "6226188413510853629",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622619_length19",  true,   "6226197302611680040",   "6226197302611680040",   "6226197302611680040",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622620_length19",  true,   "6226204731142002855",   "6226204731142002855",   "6226204731142002855",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622621_length19",  true,   "6226215421134742315",   "6226215421134742315",   "6226215421134742315",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622622_length19",  true,   "6226227262523818183",   "6226227262523818183",   "6226227262523818183",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622623_length19",  true,   "6226237733707736571",   "6226237733707736571",   "6226237733707736571",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622624_length19",  true,   "6226240363354888551",   "6226240363354888551",   "6226240363354888551",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622625_length19",  true,   "6226254143055015529",   "6226254143055015529",   "6226254143055015529",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622626_length19",  true,   "6226267440775710784",   "6226267440775710784",   "6226267440775710784",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622627_length19",  true,   "6226270747570584130",   "6226270747570584130",   "6226270747570584130",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622628_length19",  true,   "6226287175611757021",   "6226287175611757021",   "6226287175611757021",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622629_length19",  true,   "6226295414213037452",   "6226295414213037452",   "6226295414213037452",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622630_length19",  true,   "6226304153473410277",   "6226304153473410277",   "6226304153473410277",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622631_length19",  true,   "6226314515866865002",   "6226314515866865002",   "6226314515866865002",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622632_length19",  true,   "6226321828710740664",   "6226321828710740664",   "6226321828710740664",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622633_length19",  true,   "6226333382283750532",   "6226333382283750532",   "6226333382283750532",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622634_length19",  true,   "6226343628338513277",   "6226343628338513277",   "6226343628338513277",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622635_length19",  true,   "6226351030518078511",   "6226351030518078511",   "6226351030518078511",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622636_length19",  true,   "6226367057432050724",   "6226367057432050724",   "6226367057432050724",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622637_length19",  true,   "6226372642484577154",   "6226372642484577154",   "6226372642484577154",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622638_length19",  true,   "6226383308320724106",   "6226383308320724106",   "6226383308320724106",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622639_length19",  true,   "6226398712376028739",   "6226398712376028739",   "6226398712376028739",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622640_length19",  true,   "6226400056604312887",   "6226400056604312887",   "6226400056604312887",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622641_length19",  true,   "6226413862514474203",   "6226413862514474203",   "6226413862514474203",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622642_length19",  true,   "6226427122054665577",   "6226427122054665577",   "6226427122054665577",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622643_length19",  true,   "6226431787060168479",   "6226431787060168479",   "6226431787060168479",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622644_length19",  true,   "6226443418453466884",   "6226443418453466884",   "6226443418453466884",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622645_length19",  true,   "6226451271064432384",   "6226451271064432384",   "6226451271064432384",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622646_length19",  true,   "6226461335238422833",   "6226461335238422833",   "6226461335238422833",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622647_length19",  true,   "6226476118860440858",   "6226476118860440858",   "6226476118860440858",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622648_length19",  true,   "6226487315674624860",   "6226487315674624860",   "6226487315674624860",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622649_length19",  true,   "6226494773461611378",   "6226494773461611378",   "6226494773461611378",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622650_length19",  true,   "6226507062267051236",   "6226507062267051236",   "6226507062267051236",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622651_length19",  true,   "6226513562406201438",   "6226513562406201438",   "6226513562406201438",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622652_length19",  true,   "6226522156548450042",   "6226522156548450042",   "6226522156548450042",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622653_length19",  true,   "6226532750714462019",   "6226532750714462019",   "6226532750714462019",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622654_length19",  true,   "6226545508352867054",   "6226545508352867054",   "6226545508352867054",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622655_length19",  true,   "6226552766326561209",   "6226552766326561209",   "6226552766326561209",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622656_length19",  true,   "6226567782857136637",   "6226567782857136637",   "6226567782857136637",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622657_length19",  true,   "6226578463251481500",   "6226578463251481500",   "6226578463251481500",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622658_length19",  true,   "6226585850103134215",   "6226585850103134215",   "6226585850103134215",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622659_length19",  true,   "6226591338863064543",   "6226591338863064543",   "6226591338863064543",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622660_length19",  true,   "6226604358603877454",   "6226604358603877454",   "6226604358603877454",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622661_length19",  true,   "6226613705143002648",   "6226613705143002648",   "6226613705143002648",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622662_length19",  true,   "6226627520610138708",   "6226627520610138708",   "6226627520610138708",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622663_length19",  true,   "6226637314577585400",   "6226637314577585400",   "6226637314577585400",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622664_length19",  true,   "6226646217735703147",   "6226646217735703147",   "6226646217735703147",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622665_length19",  true,   "6226651083685548342",   "6226651083685548342",   "6226651083685548342",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622666_length19",  true,   "6226666718130462606",   "6226666718130462606",   "6226666718130462606",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622667_length19",  true,   "6226671662835480211",   "6226671662835480211",   "6226671662835480211",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622668_length19",  true,   "6226688420073215281",   "6226688420073215281",   "6226688420073215281",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622669_length19",  true,   "6226694876864352611",   "6226694876864352611",   "6226694876864352611",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622670_length19",  true,   "6226707416151164208",   "6226707416151164208",   "6226707416151164208",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622671_length19",  true,   "6226713285776675118",   "6226713285776675118",   "6226713285776675118",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622672_length19",  true,   "6226723215456157168",   "6226723215456157168",   "6226723215456157168",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622673_length19",  true,   "6226732224385432865",   "6226732224385432865",   "6226732224385432865",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622674_length19",  true,   "6226744253343750759",   "6226744253343750759",   "6226744253343750759",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622675_length19",  true,   "6226752128623401589",   "6226752128623401589",   "6226752128623401589",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622676_length19",  true,   "6226761057604165781",   "6226761057604165781",   "6226761057604165781",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622677_length19",  true,   "6226770262888511747",   "6226770262888511747",   "6226770262888511747",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622678_length19",  true,   "6226783838516540201",   "6226783838516540201",   "6226783838516540201",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622679_length19",  true,   "6226794037743185123",   "6226794037743185123",   "6226794037743185123",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622680_length19",  true,   "6226804251131142764",   "6226804251131142764",   "6226804251131142764",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622681_length19",  true,   "6226814377640300136",   "6226814377640300136",   "6226814377640300136",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622682_length19",  true,   "6226825727565783640",   "6226825727565783640",   "6226825727565783640",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622683_length19",  true,   "6226833001363845013",   "6226833001363845013",   "6226833001363845013",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622684_length19",  true,   "6226841568606280232",   "6226841568606280232",   "6226841568606280232",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622685_length19",  true,   "6226850775877774755",   "6226850775877774755",   "6226850775877774755",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622686_length19",  true,   "6226861061537784188",   "6226861061537784188",   "6226861061537784188",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622687_length19",  true,   "6226871787408057043",   "6226871787408057043",   "6226871787408057043",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622688_length19",  true,   "6226881856562587539",   "6226881856562587539",   "6226881856562587539",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622689_length19",  true,   "6226898275435041841",   "6226898275435041841",   "6226898275435041841",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622690_length19",  true,   "6226902626836277042",   "6226902626836277042",   "6226902626836277042",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622691_length19",  true,   "6226910828201110820",   "6226910828201110820",   "6226910828201110820",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622692_length19",  true,   "6226923131876482789",   "6226923131876482789",   "6226923131876482789",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622693_length19",  true,   "6226930714621205703",   "6226930714621205703",   "6226930714621205703",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622694_length19",  true,   "6226941333248748743",   "6226941333248748743",   "6226941333248748743",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622695_length19",  true,   "6226952163870830428",   "6226952163870830428",   "6226952163870830428",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622696_length19",  true,   "6226964318314547303",   "6226964318314547303",   "6226964318314547303",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622697_length19",  true,   "6226976528045518136",   "6226976528045518136",   "6226976528045518136",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622698_length19",  true,   "6226986841006182380",   "6226986841006182380",   "6226986841006182380",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622699_length19",  true,   "6226990172414547467",   "6226990172414547467",   "6226990172414547467",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622700_length19",  true,   "6227007588607010014",   "6227007588607010014",   "6227007588607010014",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622701_length19",  true,   "6227018784600508644",   "6227018784600508644",   "6227018784600508644",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622702_length19",  true,   "6227021002352031342",   "6227021002352031342",   "6227021002352031342",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622703_length19",  true,   "6227030438230172404",   "6227030438230172404",   "6227030438230172404",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622704_length19",  true,   "6227047165687651181",   "6227047165687651181",   "6227047165687651181",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622705_length19",  true,   "6227050553505350280",   "6227050553505350280",   "6227050553505350280",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622706_length19",  true,   "6227066147287620010",   "6227066147287620010",   "6227066147287620010",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622707_length19",  true,   "6227072651407044177",   "6227072651407044177",   "6227072651407044177",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622708_length19",  true,   "6227084170628623145",   "6227084170628623145",   "6227084170628623145",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622709_length19",  true,   "6227095345600744567",   "6227095345600744567",   "6227095345600744567",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622710_length19",  true,   "6227108204574560761",   "6227108204574560761",   "6227108204574560761",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622711_length19",  true,   "6227114033602484104",   "6227114033602484104",   "6227114033602484104",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622712_length19",  true,   "6227121157283143548",   "6227121157283143548",   "6227121157283143548",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622713_length19",  true,   "6227134443276455627",   "6227134443276455627",   "6227134443276455627",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622714_length19",  true,   "6227140314563604247",   "6227140314563604247",   "6227140314563604247",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622715_length19",  true,   "6227153476807335526",   "6227153476807335526",   "6227153476807335526",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622716_length19",  true,   "6227163207113461237",   "6227163207113461237",   "6227163207113461237",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622717_length19",  true,   "6227176544774863029",   "6227176544774863029",   "6227176544774863029",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622718_length19",  true,   "6227186778480641513",   "6227186778480641513",   "6227186778480641513",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622719_length19",  true,   "6227193077254037813",   "6227193077254037813",   "6227193077254037813",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622720_length19",  true,   "6227206065508522339",   "6227206065508522339",   "6227206065508522339",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622721_length19",  true,   "6227212521463203762",   "6227212521463203762",   "6227212521463203762",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622722_length19",  true,   "6227227628847518121",   "6227227628847518121",   "6227227628847518121",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622723_length19",  true,   "6227237882018551027",   "6227237882018551027",   "6227237882018551027",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622724_length19",  true,   "6227248735670606215",   "6227248735670606215",   "6227248735670606215",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622725_length19",  true,   "6227251465450740869",   "6227251465450740869",   "6227251465450740869",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622726_length19",  true,   "6227262646484300732",   "6227262646484300732",   "6227262646484300732",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622727_length19",  true,   "6227278314864417350",   "6227278314864417350",   "6227278314864417350",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622728_length19",  true,   "6227280326681088731",   "6227280326681088731",   "6227280326681088731",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622729_length19",  true,   "6227291363158100068",   "6227291363158100068",   "6227291363158100068",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622730_length19",  true,   "6227303460037825661",   "6227303460037825661",   "6227303460037825661",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622731_length19",  true,   "6227316113018774359",   "6227316113018774359",   "6227316113018774359",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622732_length19",  true,   "6227321052228325276",   "6227321052228325276",   "6227321052228325276",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622733_length19",  true,   "6227330213114671160",   "6227330213114671160",   "6227330213114671160",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622734_length19",  true,   "6227347423634614001",   "6227347423634614001",   "6227347423634614001",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622735_length19",  true,   "6227358411656856739",   "6227358411656856739",   "6227358411656856739",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622736_length19",  true,   "6227365205123803584",   "6227365205123803584",   "6227365205123803584",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622737_length19",  true,   "6227376166358854881",   "6227376166358854881",   "6227376166358854881",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622738_length19",  true,   "6227382252483640676",   "6227382252483640676",   "6227382252483640676",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622739_length19",  true,   "6227390870145745482",   "6227390870145745482",   "6227390870145745482",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622740_length19",  true,   "6227404112823787112",   "6227404112823787112",   "6227404112823787112",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622741_length19",  true,   "6227410210034002743",   "6227410210034002743",   "6227410210034002743",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622742_length19",  true,   "6227421136551517119",   "6227421136551517119",   "6227421136551517119",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622743_length19",  true,   "6227432404736146155",   "6227432404736146155",   "6227432404736146155",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622744_length19",  true,   "6227444621414278358",   "6227444621414278358",   "6227444621414278358",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622745_length19",  true,   "6227454423417253877",   "6227454423417253877",   "6227454423417253877",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622746_length19",  true,   "6227467482202567102",   "6227467482202567102",   "6227467482202567102",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622747_length19",  true,   "6227471416022836101",   "6227471416022836101",   "6227471416022836101",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622748_length19",  true,   "6227482664676737888",   "6227482664676737888",   "6227482664676737888",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622749_length19",  true,   "6227492745147052615",   "6227492745147052615",   "6227492745147052615",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622750_length19",  true,   "6227507255616760337",   "6227507255616760337",   "6227507255616760337",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622751_length19",  true,   "6227518830531001624",   "6227518830531001624",   "6227518830531001624",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622752_length19",  true,   "6227526651708804032",   "6227526651708804032",   "6227526651708804032",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622753_length19",  true,   "6227532585782460679",   "6227532585782460679",   "6227532585782460679",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622754_length19",  true,   "6227546200086457488",   "6227546200086457488",   "6227546200086457488",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622755_length19",  true,   "6227556504630543025",   "6227556504630543025",   "6227556504630543025",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622756_length19",  true,   "6227561656067842008",   "6227561656067842008",   "6227561656067842008",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622757_length19",  true,   "6227570086074746563",   "6227570086074746563",   "6227570086074746563",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622758_length19",  true,   "6227587540764082300",   "6227587540764082300",   "6227587540764082300",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622759_length19",  true,   "6227595008677827047",   "6227595008677827047",   "6227595008677827047",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622760_length19",  true,   "6227605521554650645",   "6227605521554650645",   "6227605521554650645",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622761_length19",  true,   "6227618733027206385",   "6227618733027206385",   "6227618733027206385",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622762_length19",  true,   "6227626616578043069",   "6227626616578043069",   "6227626616578043069",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622763_length19",  true,   "6227632157626411760",   "6227632157626411760",   "6227632157626411760",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622764_length19",  true,   "6227645127055874510",   "6227645127055874510",   "6227645127055874510",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622765_length19",  true,   "6227656701834408414",   "6227656701834408414",   "6227656701834408414",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622766_length19",  true,   "6227663043258440610",   "6227663043258440610",   "6227663043258440610",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622767_length19",  true,   "6227670171416304708",   "6227670171416304708",   "6227670171416304708",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622768_length19",  true,   "6227687545774882705",   "6227687545774882705",   "6227687545774882705",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622769_length19",  true,   "6227690566442383558",   "6227690566442383558",   "6227690566442383558",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622770_length19",  true,   "6227700005856671610",   "6227700005856671610",   "6227700005856671610",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622771_length19",  true,   "6227714232166832401",   "6227714232166832401",   "6227714232166832401",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622772_length19",  true,   "6227725524065202620",   "6227725524065202620",   "6227725524065202620",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622773_length19",  true,   "6227733603886856754",   "6227733603886856754",   "6227733603886856754",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622774_length19",  true,   "6227747112008752580",   "6227747112008752580",   "6227747112008752580",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622775_length19",  true,   "6227754605618776618",   "6227754605618776618",   "6227754605618776618",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622776_length19",  true,   "6227763828634166007",   "6227763828634166007",   "6227763828634166007",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622777_length19",  true,   "6227770750075621657",   "6227770750075621657",   "6227770750075621657",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622778_length19",  true,   "6227781574826656243",   "6227781574826656243",   "6227781574826656243",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622779_length19",  true,   "6227795033765771244",   "6227795033765771244",   "6227795033765771244",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622780_length19",  true,   "6227807554373080443",   "6227807554373080443",   "6227807554373080443",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622781_length19",  true,   "6227816061144520573",   "6227816061144520573",   "6227816061144520573",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622782_length19",  true,   "6227822847547015530",   "6227822847547015530",   "6227822847547015530",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622783_length19",  true,   "6227831876881551866",   "6227831876881551866",   "6227831876881551866",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622784_length19",  true,   "6227842486842040764",   "6227842486842040764",   "6227842486842040764",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622785_length19",  true,   "6227851840647838582",   "6227851840647838582",   "6227851840647838582",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622786_length19",  true,   "6227863126423043761",   "6227863126423043761",   "6227863126423043761",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622787_length19",  true,   "6227874838665768387",   "6227874838665768387",   "6227874838665768387",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622788_length19",  true,   "6227887337003657233",   "6227887337003657233",   "6227887337003657233",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622789_length19",  true,   "6227891712507431828",   "6227891712507431828",   "6227891712507431828",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622790_length19",  true,   "6227907310520146762",   "6227907310520146762",   "6227907310520146762",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622791_length19",  true,   "6227916028577242057",   "6227916028577242057",   "6227916028577242057",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622792_length19",  true,   "6227920146150737162",   "6227920146150737162",   "6227920146150737162",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622793_length19",  true,   "6227934122614778328",   "6227934122614778328",   "6227934122614778328",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622794_length19",  true,   "6227945233124322726",   "6227945233124322726",   "6227945233124322726",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622795_length19",  true,   "6227953676515352828",   "6227953676515352828",   "6227953676515352828",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622796_length19",  true,   "6227964445137331140",   "6227964445137331140",   "6227964445137331140",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622797_length19",  true,   "6227978412320343500",   "6227978412320343500",   "6227978412320343500",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622798_length19",  true,   "6227986570462561187",   "6227986570462561187",   "6227986570462561187",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622799_length19",  true,   "6227996670580038536",   "6227996670580038536",   "6227996670580038536",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622800_length19",  true,   "6228006256365084857",   "6228006256365084857",   "6228006256365084857",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622801_length19",  true,   "6228017476614570608",   "6228017476614570608",   "6228017476614570608",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622802_length19",  true,   "6228028101312804169",   "6228028101312804169",   "6228028101312804169",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622803_length19",  true,   "6228036012830513382",   "6228036012830513382",   "6228036012830513382",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622804_length19",  true,   "6228048626264570554",   "6228048626264570554",   "6228048626264570554",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622805_length19",  true,   "6228057241267468802",   "6228057241267468802",   "6228057241267468802",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622806_length19",  true,   "6228068075313462600",   "6228068075313462600",   "6228068075313462600",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622807_length19",  true,   "6228078254726717003",   "6228078254726717003",   "6228078254726717003",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622808_length19",  true,   "6228085470460012101",   "6228085470460012101",   "6228085470460012101",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622809_length19",  true,   "6228096286836066879",   "6228096286836066879",   "6228096286836066879",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622810_length19",  true,   "6228106755811427841",   "6228106755811427841",   "6228106755811427841",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622811_length19",  true,   "6228110065147604459",   "6228110065147604459",   "6228110065147604459",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622812_length19",  true,   "6228121242042318785",   "6228121242042318785",   "6228121242042318785",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622813_length19",  true,   "6228136070002860527",   "6228136070002860527",   "6228136070002860527",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622814_length19",  true,   "6228140121376884520",   "6228140121376884520",   "6228140121376884520",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622815_length19",  true,   "6228152707331877511",   "6228152707331877511",   "6228152707331877511",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622816_length19",  true,   "6228163065614131180",   "6228163065614131180",   "6228163065614131180",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622817_length19",  true,   "6228170475877776756",   "6228170475877776756",   "6228170475877776756",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622818_length19",  true,   "6228186351004685214",   "6228186351004685214",   "6228186351004685214",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622819_length19",  true,   "6228191481462084528",   "6228191481462084528",   "6228191481462084528",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622820_length19",  true,   "6228204028013082553",   "6228204028013082553",   "6228204028013082553",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622821_length19",  true,   "6228215613412176846",   "6228215613412176846",   "6228215613412176846",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622822_length19",  true,   "6228224108378485447",   "6228224108378485447",   "6228224108378485447",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622823_length19",  true,   "6228238252353786215",   "6228238252353786215",   "6228238252353786215",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622824_length19",  true,   "6228245264564106324",   "6228245264564106324",   "6228245264564106324",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622825_length19",  true,   "6228252424106644238",   "6228252424106644238",   "6228252424106644238",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622826_length19",  true,   "6228268364156164319",   "6228268364156164319",   "6228268364156164319",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622827_length19",  true,   "6228272011133670827",   "6228272011133670827",   "6228272011133670827",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622828_length19",  true,   "6228286304025601024",   "6228286304025601024",   "6228286304025601024",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622829_length19",  true,   "6228291840361806175",   "6228291840361806175",   "6228291840361806175",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622830_length19",  true,   "6228308343164643466",   "6228308343164643466",   "6228308343164643466",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622831_length19",  true,   "6228316756631177562",   "6228316756631177562",   "6228316756631177562",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622832_length19",  true,   "6228323574578602703",   "6228323574578602703",   "6228323574578602703",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622833_length19",  true,   "6228330100872683214",   "6228330100872683214",   "6228330100872683214",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622834_length19",  true,   "6228343365043777022",   "6228343365043777022",   "6228343365043777022",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622835_length19",  true,   "6228355775620867282",   "6228355775620867282",   "6228355775620867282",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622836_length19",  true,   "6228366485237238326",   "6228366485237238326",   "6228366485237238326",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622837_length19",  true,   "6228373417481710321",   "6228373417481710321",   "6228373417481710321",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622838_length19",  true,   "6228385610616766301",   "6228385610616766301",   "6228385610616766301",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622839_length19",  true,   "6228391148477607712",   "6228391148477607712",   "6228391148477607712",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622840_length19",  true,   "6228407237685123224",   "6228407237685123224",   "6228407237685123224",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622841_length19",  true,   "6228415046880448108",   "6228415046880448108",   "6228415046880448108",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622842_length19",  true,   "6228426853665614144",   "6228426853665614144",   "6228426853665614144",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622843_length19",  true,   "6228432727840585381",   "6228432727840585381",   "6228432727840585381",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622844_length19",  true,   "6228445758313043561",   "6228445758313043561",   "6228445758313043561",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622845_length19",  true,   "6228458714755277047",   "6228458714755277047",   "6228458714755277047",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622846_length19",  true,   "6228463114732827514",   "6228463114732827514",   "6228463114732827514",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622847_length19",  true,   "6228470650205650587",   "6228470650205650587",   "6228470650205650587",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622848_length19",  true,   "6228480855258432860",   "6228480855258432860",   "6228480855258432860",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622849_length19",  true,   "6228497813301471840",   "6228497813301471840",   "6228497813301471840",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622850_length19",  true,   "6228503272077100707",   "6228503272077100707",   "6228503272077100707",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622851_length19",  true,   "6228513603837637752",   "6228513603837637752",   "6228513603837637752",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622852_length19",  true,   "6228522500380336783",   "6228522500380336783",   "6228522500380336783",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622853_length19",  true,   "6228532318114866324",   "6228532318114866324",   "6228532318114866324",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622854_length19",  true,   "6228541016455252802",   "6228541016455252802",   "6228541016455252802",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622855_length19",  true,   "6228557035844542609",   "6228557035844542609",   "6228557035844542609",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622856_length19",  true,   "6228568220513114875",   "6228568220513114875",   "6228568220513114875",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622857_length19",  true,   "6228572408731185454",   "6228572408731185454",   "6228572408731185454",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622858_length19",  true,   "6228585144035831833",   "6228585144035831833",   "6228585144035831833",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622859_length19",  true,   "6228598113052530250",   "6228598113052530250",   "6228598113052530250",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622860_length19",  true,   "6228608457655703337",   "6228608457655703337",   "6228608457655703337",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622861_length19",  true,   "6228618142144432064",   "6228618142144432064",   "6228618142144432064",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622862_length19",  true,   "6228620662147256042",   "6228620662147256042",   "6228620662147256042",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622863_length19",  true,   "6228635778112043281",   "6228635778112043281",   "6228635778112043281",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622864_length19",  true,   "6228647360033382829",   "6228647360033382829",   "6228647360033382829",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622865_length19",  true,   "6228657180322466886",   "6228657180322466886",   "6228657180322466886",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622866_length19",  true,   "6228668534827742331",   "6228668534827742331",   "6228668534827742331",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622867_length19",  true,   "6228670624775302141",   "6228670624775302141",   "6228670624775302141",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622868_length19",  true,   "6228682865728503402",   "6228682865728503402",   "6228682865728503402",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622869_length19",  true,   "6228693285805370087",   "6228693285805370087",   "6228693285805370087",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622870_length19",  true,   "6228708025237056547",   "6228708025237056547",   "6228708025237056547",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622871_length19",  true,   "6228715865726012522",   "6228715865726012522",   "6228715865726012522",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622872_length19",  true,   "6228725588536238404",   "6228725588536238404",   "6228725588536238404",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622873_length19",  true,   "6228735043052484048",   "6228735043052484048",   "6228735043052484048",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622874_length19",  true,   "6228742427412147505",   "6228742427412147505",   "6228742427412147505",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622875_length19",  true,   "6228750628353317424",   "6228750628353317424",   "6228750628353317424",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622876_length19",  true,   "6228768251578467831",   "6228768251578467831",   "6228768251578467831",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622877_length19",  true,   "6228774511478253041",   "6228774511478253041",   "6228774511478253041",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622878_length19",  true,   "6228787012302201566",   "6228787012302201566",   "6228787012302201566",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622879_length19",  true,   "6228798015432830177",   "6228798015432830177",   "6228798015432830177",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622880_length19",  true,   "6228808625511635723",   "6228808625511635723",   "6228808625511635723",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622881_length19",  true,   "6228817717826776679",   "6228817717826776679",   "6228817717826776679",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622882_length19",  true,   "6228823417252218716",   "6228823417252218716",   "6228823417252218716",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622883_length19",  true,   "6228832415848683160",   "6228832415848683160",   "6228832415848683160",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622884_length19",  true,   "6228843067716246047",   "6228843067716246047",   "6228843067716246047",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622885_length19",  true,   "6228852183432068207",   "6228852183432068207",   "6228852183432068207",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622886_length19",  true,   "6228866315686242708",   "6228866315686242708",   "6228866315686242708",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622887_length19",  true,   "6228875770827787558",   "6228875770827787558",   "6228875770827787558",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622888_length19",  true,   "6228883525810253632",   "6228883525810253632",   "6228883525810253632",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622889_length19",  true,   "6228896216364401117",   "6228896216364401117",   "6228896216364401117",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622890_length19",  true,   "6228905324203684239",   "6228905324203684239",   "6228905324203684239",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622891_length19",  true,   "6228910403421333879",   "6228910403421333879",   "6228910403421333879",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622892_length19",  true,   "6228925104774287018",   "6228925104774287018",   "6228925104774287018",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622893_length19",  true,   "6228936243438518660",   "6228936243438518660",   "6228936243438518660",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622894_length19",  true,   "6228947544775050739",   "6228947544775050739",   "6228947544775050739",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622895_length19",  true,   "6228953880027015216",   "6228953880027015216",   "6228953880027015216",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622896_length19",  true,   "6228962657454431416",   "6228962657454431416",   "6228962657454431416",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622897_length19",  true,   "6228977822778574209",   "6228977822778574209",   "6228977822778574209",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622898_length19",  true,   "6228988222433175053",   "6228988222433175053",   "6228988222433175053",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622899_length19",  true,   "6228995725637400029",   "6228995725637400029",   "6228995725637400029",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622900_length19",  true,   "6229008873414818626",   "6229008873414818626",   "6229008873414818626",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622901_length19",  true,   "6229017486025442303",   "6229017486025442303",   "6229017486025442303",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622902_length19",  true,   "6229020288031083336",   "6229020288031083336",   "6229020288031083336",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622903_length19",  true,   "6229031235087602672",   "6229031235087602672",   "6229031235087602672",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622904_length19",  true,   "6229044470213480363",   "6229044470213480363",   "6229044470213480363",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622905_length19",  true,   "6229055160350127259",   "6229055160350127259",   "6229055160350127259",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622906_length19",  true,   "6229060070147254014",   "6229060070147254014",   "6229060070147254014",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622907_length19",  true,   "6229077764478338187",   "6229077764478338187",   "6229077764478338187",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622908_length19",  true,   "6229080301844038053",   "6229080301844038053",   "6229080301844038053",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622909_length19",  true,   "6229092055630541185",   "6229092055630541185",   "6229092055630541185",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622910_length19",  true,   "6229100742825110088",   "6229100742825110088",   "6229100742825110088",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622911_length19",  true,   "6229110372143464278",   "6229110372143464278",   "6229110372143464278",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622912_length19",  true,   "6229121654828240017",   "6229121654828240017",   "6229121654828240017",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622913_length19",  true,   "6229138224185140340",   "6229138224185140340",   "6229138224185140340",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622914_length19",  true,   "6229142642067173655",   "6229142642067173655",   "6229142642067173655",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622915_length19",  true,   "6229153763404267012",   "6229153763404267012",   "6229153763404267012",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622916_length19",  true,   "6229160707608054628",   "6229160707608054628",   "6229160707608054628",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622917_length19",  true,   "6229178361355504441",   "6229178361355504441",   "6229178361355504441",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622918_length19",  true,   "6229185431633520377",   "6229185431633520377",   "6229185431633520377",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622919_length19",  true,   "6229198678814714543",   "6229198678814714543",   "6229198678814714543",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622920_length19",  true,   "6229201616563067023",   "6229201616563067023",   "6229201616563067023",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622921_length19",  true,   "6229212070631078819",   "6229212070631078819",   "6229212070631078819",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622922_length19",  true,   "6229225880670442378",   "6229225880670442378",   "6229225880670442378",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622923_length19",  true,   "6229230182371543619",   "6229230182371543619",   "6229230182371543619",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622924_length19",  true,   "6229246178874174383",   "6229246178874174383",   "6229246178874174383",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622925_length19",  true,   "6229250808267132860",   "6229250808267132860",   "6229250808267132860",   Event.VALIDATION_SUCCESS  ),
   // Begin invalid chars check
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix6011_length16_invalidChars",    true,   "b60t1130%70044;82082_+",  "6011307004482082",  "6011307004482082",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix622644_length16_invalidChars",  true,   "@6226x44711%8125]50o7",   "6226447118125507",  "6226447118125507",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix65_length16_invalidChars",      true,   "65-754464'1768F4229!",    "6575446417684229",  "6575446417684229",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_prefix644_length16_invalidChars",     true,   "6L44608^675k740504m6",    "6446086757405046",  "6446086757405046",   Event.VALIDATION_SUCCESS  ),
   // End invalid chars check
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix1",                  true,   "1",                       "",                     "",                  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix2",                  true,   "2",                       "",                     "",                  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix3",                  true,   "3",                       "",                     "",                  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix4",                  true,   "4",                       "",                     "",                  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix5",                  true,   "5",                       "",                     "",                  Event.VALIDATION_SUCCESS  ),
   // Begin check of 6011
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix6010",               true,   "6010",                    "601",                  "601",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix6012",               true,   "6012",                    "601",                  "601",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix6013",               true,   "6013",                    "601",                  "601",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix6014",               true,   "6014",                    "601",                  "601",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix6015",               true,   "6015",                    "601",                  "601",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix6016",               true,   "6016",                    "601",                  "601",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix6017",               true,   "6017",                    "601",                  "601",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix6018",               true,   "6018",                    "601",                  "601",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix6019",               true,   "6019",                    "601",                  "601",               Event.VALIDATION_FAILED  ),
   // End of check 6011
   // Begin check of 622126-622925
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix620",                true,   "620",                     "62",                   "62",                Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix621",                true,   "621",                     "62",                   "62",                Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix6220",               true,   "6220",                    "622",                  "622",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix62210",              true,   "62210",                   "6221",                 "6221",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix62211",              true,   "62211",                   "6221",                 "6221",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix622121",             true,   "622121",                  "62212",                "62212",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix622122",             true,   "622122",                  "62212",                "62212",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix622123",             true,   "622123",                  "62212",                "62212",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix622124",             true,   "622124",                  "62212",                "62212",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix622125",             true,   "622125",                  "62212",                "62212",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix622926",             true,   "622926",                  "62292",                "62292",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix622927",             true,   "622927",                  "62292",                "62292",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix622928",             true,   "622928",                  "62292",                "62292",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix622929",             true,   "622929",                  "62292",                "62292",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix62293",              true,   "62293",                   "6229",                 "6229",              Event.VALIDATION_FAILED  ),
   // End check of 622126-622925
   // Begin check of 644-649
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix640",                true,   "640",                     "64",                   "64",                Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix641",                true,   "641",                     "64",                   "64",                Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix642",                true,   "642",                     "64",                   "64",                Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix643",                true,   "643",                     "64",                   "64",                Event.VALIDATION_FAILED  ),
   // End check of 644-649
   // Begin check of 65
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix61",                true,   "61",                       "6",                   "6",                  Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix63",                true,   "63",                       "6",                   "6",                  Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix66",                true,   "66",                       "6",                   "6",                  Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix67",                true,   "67",                       "6",                   "6",                  Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix68",                true,   "68",                       "6",                   "6",                  Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix69",                true,   "69",                       "6",                   "6",                  Event.VALIDATION_FAILED  ),
   // End check of 65
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix7",                 true,   "7",                       "",                     "",                  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix8",                 true,   "8",                       "",                     "",                  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix9",                 true,   "9",                       "",                     "",                  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.DISCOVER,   "ignore_discover_invalidPrefix0",                 true,   "0",                       "",                     "",                  Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix51_length16",    true,   "5135607880621304",   "5135607880621304",   "5135607880621304",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix52_length16",    true,   "5217801253014533",   "5217801253014533",   "5217801253014533",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix53_length16",    true,   "5343043472540777",   "5343043472540777",   "5343043472540777",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix54_length16",    true,   "5451347224828804",   "5451347224828804",   "5451347224828804",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix55_length16",    true,   "5574045605155753",   "5574045605155753",   "5574045605155753",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2221_length16",  true,   "2221266606077424",   "2221266606077424",   "2221266606077424",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2222_length16",  true,   "2222117606040723",   "2222117606040723",   "2222117606040723",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2223_length16",  true,   "2223251402851253",   "2223251402851253",   "2223251402851253",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2224_length16",  true,   "2224715407858686",   "2224715407858686",   "2224715407858686",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2225_length16",  true,   "2225358313721042",   "2225358313721042",   "2225358313721042",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2226_length16",  true,   "2226582242084623",   "2226582242084623",   "2226582242084623",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2227_length16",  true,   "2227184256467650",   "2227184256467650",   "2227184256467650",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2228_length16",  true,   "2228721315828411",   "2228721315828411",   "2228721315828411",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2229_length16",  true,   "2229003511338605",   "2229003511338605",   "2229003511338605",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2230_length16",  true,   "2230060100737271",   "2230060100737271",   "2230060100737271",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2231_length16",  true,   "2231027407276880",   "2231027407276880",   "2231027407276880",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2232_length16",  true,   "2232135313445769",   "2232135313445769",   "2232135313445769",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2233_length16",  true,   "2233215533415005",   "2233215533415005",   "2233215533415005",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2234_length16",  true,   "2234082610342471",   "2234082610342471",   "2234082610342471",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2235_length16",  true,   "2235835166375636",   "2235835166375636",   "2235835166375636",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2236_length16",  true,   "2236205871434335",   "2236205871434335",   "2236205871434335",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2237_length16",  true,   "2237885670550404",   "2237885670550404",   "2237885670550404",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2238_length16",  true,   "2238346001300604",   "2238346001300604",   "2238346001300604",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2239_length16",  true,   "2239877411630510",   "2239877411630510",   "2239877411630510",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2240_length16",  true,   "2240104241058268",   "2240104241058268",   "2240104241058268",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2241_length16",  true,   "2241076276818841",   "2241076276818841",   "2241076276818841",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2242_length16",  true,   "2242313221077226",   "2242313221077226",   "2242313221077226",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2243_length16",  true,   "2243677877882413",   "2243677877882413",   "2243677877882413",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2244_length16",  true,   "2244515523507126",   "2244515523507126",   "2244515523507126",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2245_length16",  true,   "2245534043885309",   "2245534043885309",   "2245534043885309",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2246_length16",  true,   "2246800182221518",   "2246800182221518",   "2246800182221518",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2247_length16",  true,   "2247066147438006",   "2247066147438006",   "2247066147438006",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2248_length16",  true,   "2248070420205081",   "2248070420205081",   "2248070420205081",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2249_length16",  true,   "2249218136727463",   "2249218136727463",   "2249218136727463",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2250_length16",  true,   "2250850503425580",   "2250850503425580",   "2250850503425580",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2251_length16",  true,   "2251407360485600",   "2251407360485600",   "2251407360485600",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2252_length16",  true,   "2252080051265554",   "2252080051265554",   "2252080051265554",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2253_length16",  true,   "2253272113270834",   "2253272113270834",   "2253272113270834",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2254_length16",  true,   "2254700424181117",   "2254700424181117",   "2254700424181117",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2255_length16",  true,   "2255525843673819",   "2255525843673819",   "2255525843673819",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2256_length16",  true,   "2256808043357337",   "2256808043357337",   "2256808043357337",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2257_length16",  true,   "2257333510624233",   "2257333510624233",   "2257333510624233",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2258_length16",  true,   "2258076036224686",   "2258076036224686",   "2258076036224686",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2259_length16",  true,   "2259042108231560",   "2259042108231560",   "2259042108231560",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2260_length16",  true,   "2260687023578185",   "2260687023578185",   "2260687023578185",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2261_length16",  true,   "2261646855700043",   "2261646855700043",   "2261646855700043",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2262_length16",  true,   "2262861422176333",   "2262861422176333",   "2262861422176333",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2263_length16",  true,   "2263084822614550",   "2263084822614550",   "2263084822614550",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2264_length16",  true,   "2264081101464888",   "2264081101464888",   "2264081101464888",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2265_length16",  true,   "2265550670516467",   "2265550670516467",   "2265550670516467",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2266_length16",  true,   "2266762236233573",   "2266762236233573",   "2266762236233573",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2267_length16",  true,   "2267747824207146",   "2267747824207146",   "2267747824207146",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2268_length16",  true,   "2268700315728228",   "2268700315728228",   "2268700315728228",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2269_length16",  true,   "2269756714340352",   "2269756714340352",   "2269756714340352",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2270_length16",  true,   "2270206578737779",   "2270206578737779",   "2270206578737779",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2271_length16",  true,   "2271545276662071",   "2271545276662071",   "2271545276662071",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2272_length16",  true,   "2272448085053856",   "2272448085053856",   "2272448085053856",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2273_length16",  true,   "2273577000784861",   "2273577000784861",   "2273577000784861",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2274_length16",  true,   "2274605457660745",   "2274605457660745",   "2274605457660745",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2275_length16",  true,   "2275571736538632",   "2275571736538632",   "2275571736538632",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2276_length16",  true,   "2276877017861323",   "2276877017861323",   "2276877017861323",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2277_length16",  true,   "2277472047623528",   "2277472047623528",   "2277472047623528",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2278_length16",  true,   "2278811251622206",   "2278811251622206",   "2278811251622206",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2279_length16",  true,   "2279477354435562",   "2279477354435562",   "2279477354435562",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2280_length16",  true,   "2280220662380535",   "2280220662380535",   "2280220662380535",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2281_length16",  true,   "2281040888083534",   "2281040888083534",   "2281040888083534",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2282_length16",  true,   "2282735538247806",   "2282735538247806",   "2282735538247806",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2283_length16",  true,   "2283841860762450",   "2283841860762450",   "2283841860762450",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2284_length16",  true,   "2284887160588425",   "2284887160588425",   "2284887160588425",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2285_length16",  true,   "2285685621331321",   "2285685621331321",   "2285685621331321",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2286_length16",  true,   "2286120262840330",   "2286120262840330",   "2286120262840330",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2287_length16",  true,   "2287676782551607",   "2287676782551607",   "2287676782551607",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2288_length16",  true,   "2288483001283776",   "2288483001283776",   "2288483001283776",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2289_length16",  true,   "2289664136742500",   "2289664136742500",   "2289664136742500",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2290_length16",  true,   "2290676268846385",   "2290676268846385",   "2290676268846385",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2291_length16",  true,   "2291136721467336",   "2291136721467336",   "2291136721467336",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2292_length16",  true,   "2292222302725380",   "2292222302725380",   "2292222302725380",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2293_length16",  true,   "2293681476125744",   "2293681476125744",   "2293681476125744",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2294_length16",  true,   "2294118501323001",   "2294118501323001",   "2294118501323001",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2295_length16",  true,   "2295143750236323",   "2295143750236323",   "2295143750236323",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2296_length16",  true,   "2296236134838431",   "2296236134838431",   "2296236134838431",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2297_length16",  true,   "2297285843522306",   "2297285843522306",   "2297285843522306",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2298_length16",  true,   "2298010387853779",   "2298010387853779",   "2298010387853779",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2299_length16",  true,   "2299507528207020",   "2299507528207020",   "2299507528207020",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2300_length16",  true,   "2300158375831244",   "2300158375831244",   "2300158375831244",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2301_length16",  true,   "2301133733381371",   "2301133733381371",   "2301133733381371",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2302_length16",  true,   "2302026100526017",   "2302026100526017",   "2302026100526017",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2303_length16",  true,   "2303504865648282",   "2303504865648282",   "2303504865648282",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2304_length16",  true,   "2304546212455688",   "2304546212455688",   "2304546212455688",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2305_length16",  true,   "2305527816725600",   "2305527816725600",   "2305527816725600",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2306_length16",  true,   "2306710284772028",   "2306710284772028",   "2306710284772028",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2307_length16",  true,   "2307675280531281",   "2307675280531281",   "2307675280531281",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2308_length16",  true,   "2308184057687649",   "2308184057687649",   "2308184057687649",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2309_length16",  true,   "2309632712761208",   "2309632712761208",   "2309632712761208",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2310_length16",  true,   "2310337202825177",   "2310337202825177",   "2310337202825177",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2311_length16",  true,   "2311716473342005",   "2311716473342005",   "2311716473342005",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2312_length16",  true,   "2312151528443443",   "2312151528443443",   "2312151528443443",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2313_length16",  true,   "2313776251672625",   "2313776251672625",   "2313776251672625",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2314_length16",  true,   "2314013836408732",   "2314013836408732",   "2314013836408732",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2315_length16",  true,   "2315785406511321",   "2315785406511321",   "2315785406511321",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2316_length16",  true,   "2316020331456445",   "2316020331456445",   "2316020331456445",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2317_length16",  true,   "2317876857571209",   "2317876857571209",   "2317876857571209",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2318_length16",  true,   "2318605276617262",   "2318605276617262",   "2318605276617262",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2319_length16",  true,   "2319243804472767",   "2319243804472767",   "2319243804472767",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2320_length16",  true,   "2320250668336472",   "2320250668336472",   "2320250668336472",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2321_length16",  true,   "2321455882437001",   "2321455882437001",   "2321455882437001",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2322_length16",  true,   "2322211487265480",   "2322211487265480",   "2322211487265480",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2323_length16",  true,   "2323326558777301",   "2323326558777301",   "2323326558777301",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2324_length16",  true,   "2324756167388075",   "2324756167388075",   "2324756167388075",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2325_length16",  true,   "2325377212856831",   "2325377212856831",   "2325377212856831",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2326_length16",  true,   "2326368587155239",   "2326368587155239",   "2326368587155239",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2327_length16",  true,   "2327053476154043",   "2327053476154043",   "2327053476154043",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2328_length16",  true,   "2328743133303640",   "2328743133303640",   "2328743133303640",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2329_length16",  true,   "2329742618630112",   "2329742618630112",   "2329742618630112",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2330_length16",  true,   "2330633215133203",   "2330633215133203",   "2330633215133203",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2331_length16",  true,   "2331355204075661",   "2331355204075661",   "2331355204075661",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2332_length16",  true,   "2332757711566760",   "2332757711566760",   "2332757711566760",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2333_length16",  true,   "2333442104722556",   "2333442104722556",   "2333442104722556",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2334_length16",  true,   "2334371628421867",   "2334371628421867",   "2334371628421867",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2335_length16",  true,   "2335248184783071",   "2335248184783071",   "2335248184783071",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2336_length16",  true,   "2336450144573332",   "2336450144573332",   "2336450144573332",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2337_length16",  true,   "2337888407116613",   "2337888407116613",   "2337888407116613",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2338_length16",  true,   "2338284651246737",   "2338284651246737",   "2338284651246737",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2339_length16",  true,   "2339701175224162",   "2339701175224162",   "2339701175224162",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2340_length16",  true,   "2340640432010153",   "2340640432010153",   "2340640432010153",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2341_length16",  true,   "2341166348048425",   "2341166348048425",   "2341166348048425",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2342_length16",  true,   "2342174271101558",   "2342174271101558",   "2342174271101558",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2343_length16",  true,   "2343686113004442",   "2343686113004442",   "2343686113004442",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2344_length16",  true,   "2344416423610863",   "2344416423610863",   "2344416423610863",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2345_length16",  true,   "2345651187081575",   "2345651187081575",   "2345651187081575",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2346_length16",  true,   "2346327517381485",   "2346327517381485",   "2346327517381485",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2347_length16",  true,   "2347446857762713",   "2347446857762713",   "2347446857762713",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2348_length16",  true,   "2348412044837023",   "2348412044837023",   "2348412044837023",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2349_length16",  true,   "2349738600167788",   "2349738600167788",   "2349738600167788",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2350_length16",  true,   "2350801633400703",   "2350801633400703",   "2350801633400703",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2351_length16",  true,   "2351214327106777",   "2351214327106777",   "2351214327106777",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2352_length16",  true,   "2352222263607368",   "2352222263607368",   "2352222263607368",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2353_length16",  true,   "2353473087680029",   "2353473087680029",   "2353473087680029",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2354_length16",  true,   "2354278720463785",   "2354278720463785",   "2354278720463785",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2355_length16",  true,   "2355435188823715",   "2355435188823715",   "2355435188823715",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2356_length16",  true,   "2356301200343554",   "2356301200343554",   "2356301200343554",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2357_length16",  true,   "2357633400566264",   "2357633400566264",   "2357633400566264",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2358_length16",  true,   "2358301420412179",   "2358301420412179",   "2358301420412179",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2359_length16",  true,   "2359023848724816",   "2359023848724816",   "2359023848724816",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2360_length16",  true,   "2360726570633537",   "2360726570633537",   "2360726570633537",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2361_length16",  true,   "2361781170424448",   "2361781170424448",   "2361781170424448",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2362_length16",  true,   "2362762703222813",   "2362762703222813",   "2362762703222813",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2363_length16",  true,   "2363433218478477",   "2363433218478477",   "2363433218478477",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2364_length16",  true,   "2364587452124805",   "2364587452124805",   "2364587452124805",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2365_length16",  true,   "2365543284755133",   "2365543284755133",   "2365543284755133",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2366_length16",  true,   "2366132080670602",   "2366132080670602",   "2366132080670602",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2367_length16",  true,   "2367206008117349",   "2367206008117349",   "2367206008117349",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2368_length16",  true,   "2368018316512189",   "2368018316512189",   "2368018316512189",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2369_length16",  true,   "2369601875631778",   "2369601875631778",   "2369601875631778",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2370_length16",  true,   "2370274466753364",   "2370274466753364",   "2370274466753364",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2371_length16",  true,   "2371068610068847",   "2371068610068847",   "2371068610068847",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2372_length16",  true,   "2372783174260742",   "2372783174260742",   "2372783174260742",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2373_length16",  true,   "2373425305572673",   "2373425305572673",   "2373425305572673",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2374_length16",  true,   "2374413200457363",   "2374413200457363",   "2374413200457363",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2375_length16",  true,   "2375248532554084",   "2375248532554084",   "2375248532554084",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2376_length16",  true,   "2376877665727726",   "2376877665727726",   "2376877665727726",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2377_length16",  true,   "2377204305221870",   "2377204305221870",   "2377204305221870",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2378_length16",  true,   "2378524400388475",   "2378524400388475",   "2378524400388475",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2379_length16",  true,   "2379873013162721",   "2379873013162721",   "2379873013162721",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2380_length16",  true,   "2380660841586420",   "2380660841586420",   "2380660841586420",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2381_length16",  true,   "2381856650601529",   "2381856650601529",   "2381856650601529",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2382_length16",  true,   "2382045034272822",   "2382045034272822",   "2382045034272822",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2383_length16",  true,   "2383503451027474",   "2383503451027474",   "2383503451027474",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2384_length16",  true,   "2384286454666261",   "2384286454666261",   "2384286454666261",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2385_length16",  true,   "2385758237255447",   "2385758237255447",   "2385758237255447",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2386_length16",  true,   "2386717054174635",   "2386717054174635",   "2386717054174635",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2387_length16",  true,   "2387176124260842",   "2387176124260842",   "2387176124260842",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2388_length16",  true,   "2388045782675139",   "2388045782675139",   "2388045782675139",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2389_length16",  true,   "2389151133371813",   "2389151133371813",   "2389151133371813",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2390_length16",  true,   "2390453742868339",   "2390453742868339",   "2390453742868339",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2391_length16",  true,   "2391034827020571",   "2391034827020571",   "2391034827020571",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2392_length16",  true,   "2392084043318845",   "2392084043318845",   "2392084043318845",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2393_length16",  true,   "2393506767213116",   "2393506767213116",   "2393506767213116",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2394_length16",  true,   "2394683585444451",   "2394683585444451",   "2394683585444451",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2395_length16",  true,   "2395213087740765",   "2395213087740765",   "2395213087740765",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2396_length16",  true,   "2396240300851532",   "2396240300851532",   "2396240300851532",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2397_length16",  true,   "2397241808138082",   "2397241808138082",   "2397241808138082",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2398_length16",  true,   "2398116285501581",   "2398116285501581",   "2398116285501581",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2399_length16",  true,   "2399732387261244",   "2399732387261244",   "2399732387261244",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2400_length16",  true,   "2400841771457834",   "2400841771457834",   "2400841771457834",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2401_length16",  true,   "2401488366531505",   "2401488366531505",   "2401488366531505",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2402_length16",  true,   "2402048533706429",   "2402048533706429",   "2402048533706429",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2403_length16",  true,   "2403353575764073",   "2403353575764073",   "2403353575764073",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2404_length16",  true,   "2404636778050079",   "2404636778050079",   "2404636778050079",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2405_length16",  true,   "2405356143484783",   "2405356143484783",   "2405356143484783",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2406_length16",  true,   "2406418034144329",   "2406418034144329",   "2406418034144329",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2407_length16",  true,   "2407133305273652",   "2407133305273652",   "2407133305273652",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2408_length16",  true,   "2408575735770559",   "2408575735770559",   "2408575735770559",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2409_length16",  true,   "2409450200726628",   "2409450200726628",   "2409450200726628",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2410_length16",  true,   "2410374314041301",   "2410374314041301",   "2410374314041301",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2411_length16",  true,   "2411353058362650",   "2411353058362650",   "2411353058362650",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2412_length16",  true,   "2412624576232065",   "2412624576232065",   "2412624576232065",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2413_length16",  true,   "2413600574181800",   "2413600574181800",   "2413600574181800",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2414_length16",  true,   "2414118821287212",   "2414118821287212",   "2414118821287212",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2415_length16",  true,   "2415776265538231",   "2415776265538231",   "2415776265538231",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2416_length16",  true,   "2416528783772183",   "2416528783772183",   "2416528783772183",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2417_length16",  true,   "2417436716321418",   "2417436716321418",   "2417436716321418",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2418_length16",  true,   "2418166520886756",   "2418166520886756",   "2418166520886756",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2419_length16",  true,   "2419857278235654",   "2419857278235654",   "2419857278235654",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2420_length16",  true,   "2420258815146057",   "2420258815146057",   "2420258815146057",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2421_length16",  true,   "2421322582754045",   "2421322582754045",   "2421322582754045",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2422_length16",  true,   "2422203456167036",   "2422203456167036",   "2422203456167036",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2423_length16",  true,   "2423708841525481",   "2423708841525481",   "2423708841525481",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2424_length16",  true,   "2424706568200840",   "2424706568200840",   "2424706568200840",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2425_length16",  true,   "2425217872740488",   "2425217872740488",   "2425217872740488",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2426_length16",  true,   "2426684286705119",   "2426684286705119",   "2426684286705119",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2427_length16",  true,   "2427574627786341",   "2427574627786341",   "2427574627786341",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2428_length16",  true,   "2428230001872665",   "2428230001872665",   "2428230001872665",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2429_length16",  true,   "2429384022605486",   "2429384022605486",   "2429384022605486",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2430_length16",  true,   "2430714102833409",   "2430714102833409",   "2430714102833409",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2431_length16",  true,   "2431015633253649",   "2431015633253649",   "2431015633253649",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2432_length16",  true,   "2432116057608026",   "2432116057608026",   "2432116057608026",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2433_length16",  true,   "2433444040625744",   "2433444040625744",   "2433444040625744",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2434_length16",  true,   "2434500178221611",   "2434500178221611",   "2434500178221611",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2435_length16",  true,   "2435311704782251",   "2435311704782251",   "2435311704782251",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2436_length16",  true,   "2436266886668653",   "2436266886668653",   "2436266886668653",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2437_length16",  true,   "2437624522888805",   "2437624522888805",   "2437624522888805",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2438_length16",  true,   "2438671585034107",   "2438671585034107",   "2438671585034107",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2439_length16",  true,   "2439866855220589",   "2439866855220589",   "2439866855220589",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2440_length16",  true,   "2440867480112602",   "2440867480112602",   "2440867480112602",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2441_length16",  true,   "2441106623845151",   "2441106623845151",   "2441106623845151",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2442_length16",  true,   "2442681470187831",   "2442681470187831",   "2442681470187831",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2443_length16",  true,   "2443776413738671",   "2443776413738671",   "2443776413738671",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2444_length16",  true,   "2444254010205360",   "2444254010205360",   "2444254010205360",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2445_length16",  true,   "2445648246372861",   "2445648246372861",   "2445648246372861",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2446_length16",  true,   "2446081867852202",   "2446081867852202",   "2446081867852202",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2447_length16",  true,   "2447173840860250",   "2447173840860250",   "2447173840860250",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2448_length16",  true,   "2448381736433558",   "2448381736433558",   "2448381736433558",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2449_length16",  true,   "2449014088013822",   "2449014088013822",   "2449014088013822",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2450_length16",  true,   "2450180173455370",   "2450180173455370",   "2450180173455370",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2451_length16",  true,   "2451845258127610",   "2451845258127610",   "2451845258127610",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2452_length16",  true,   "2452738258662802",   "2452738258662802",   "2452738258662802",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2453_length16",  true,   "2453230045122307",   "2453230045122307",   "2453230045122307",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2454_length16",  true,   "2454636418765069",   "2454636418765069",   "2454636418765069",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2455_length16",  true,   "2455773843051473",   "2455773843051473",   "2455773843051473",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2456_length16",  true,   "2456670270856888",   "2456670270856888",   "2456670270856888",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2457_length16",  true,   "2457687424112421",   "2457687424112421",   "2457687424112421",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2458_length16",  true,   "2458341622116813",   "2458341622116813",   "2458341622116813",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2459_length16",  true,   "2459083051230082",   "2459083051230082",   "2459083051230082",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2460_length16",  true,   "2460031077181000",   "2460031077181000",   "2460031077181000",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2461_length16",  true,   "2461005704628467",   "2461005704628467",   "2461005704628467",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2462_length16",  true,   "2462045048878856",   "2462045048878856",   "2462045048878856",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2463_length16",  true,   "2463525666023157",   "2463525666023157",   "2463525666023157",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2464_length16",  true,   "2464553133256530",   "2464553133256530",   "2464553133256530",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2465_length16",  true,   "2465647007075742",   "2465647007075742",   "2465647007075742",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2466_length16",  true,   "2466174543810580",   "2466174543810580",   "2466174543810580",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2467_length16",  true,   "2467168185750418",   "2467168185750418",   "2467168185750418",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2468_length16",  true,   "2468485685032389",   "2468485685032389",   "2468485685032389",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2469_length16",  true,   "2469864487425471",   "2469864487425471",   "2469864487425471",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2470_length16",  true,   "2470103016138835",   "2470103016138835",   "2470103016138835",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2471_length16",  true,   "2471113662176723",   "2471113662176723",   "2471113662176723",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2472_length16",  true,   "2472875825324858",   "2472875825324858",   "2472875825324858",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2473_length16",  true,   "2473663027665859",   "2473663027665859",   "2473663027665859",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2474_length16",  true,   "2474316276614685",   "2474316276614685",   "2474316276614685",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2475_length16",  true,   "2475068168053311",   "2475068168053311",   "2475068168053311",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2476_length16",  true,   "2476548626834401",   "2476548626834401",   "2476548626834401",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2477_length16",  true,   "2477335118502772",   "2477335118502772",   "2477335118502772",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2478_length16",  true,   "2478186616678559",   "2478186616678559",   "2478186616678559",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2479_length16",  true,   "2479446864788750",   "2479446864788750",   "2479446864788750",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2480_length16",  true,   "2480077801208169",   "2480077801208169",   "2480077801208169",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2481_length16",  true,   "2481628252360112",   "2481628252360112",   "2481628252360112",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2482_length16",  true,   "2482640843385853",   "2482640843385853",   "2482640843385853",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2483_length16",  true,   "2483732341171205",   "2483732341171205",   "2483732341171205",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2484_length16",  true,   "2484616064232709",   "2484616064232709",   "2484616064232709",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2485_length16",  true,   "2485866247812328",   "2485866247812328",   "2485866247812328",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2486_length16",  true,   "2486700275382665",   "2486700275382665",   "2486700275382665",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2487_length16",  true,   "2487522035304865",   "2487522035304865",   "2487522035304865",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2488_length16",  true,   "2488838546531609",   "2488838546531609",   "2488838546531609",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2489_length16",  true,   "2489734123171480",   "2489734123171480",   "2489734123171480",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2490_length16",  true,   "2490145338534072",   "2490145338534072",   "2490145338534072",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2491_length16",  true,   "2491382720211733",   "2491382720211733",   "2491382720211733",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2492_length16",  true,   "2492361610331768",   "2492361610331768",   "2492361610331768",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2493_length16",  true,   "2493316468224779",   "2493316468224779",   "2493316468224779",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2494_length16",  true,   "2494240471560202",   "2494240471560202",   "2494240471560202",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2495_length16",  true,   "2495853321148850",   "2495853321148850",   "2495853321148850",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2496_length16",  true,   "2496718443140813",   "2496718443140813",   "2496718443140813",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2497_length16",  true,   "2497578656506277",   "2497578656506277",   "2497578656506277",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2498_length16",  true,   "2498516105108567",   "2498516105108567",   "2498516105108567",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2499_length16",  true,   "2499376521504116",   "2499376521504116",   "2499376521504116",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2500_length16",  true,   "2500220674063008",   "2500220674063008",   "2500220674063008",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2501_length16",  true,   "2501383717262414",   "2501383717262414",   "2501383717262414",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2502_length16",  true,   "2502115743137775",   "2502115743137775",   "2502115743137775",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2503_length16",  true,   "2503165240841048",   "2503165240841048",   "2503165240841048",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2504_length16",  true,   "2504637017218112",   "2504637017218112",   "2504637017218112",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2505_length16",  true,   "2505684550146028",   "2505684550146028",   "2505684550146028",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2506_length16",  true,   "2506517461110361",   "2506517461110361",   "2506517461110361",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2507_length16",  true,   "2507073850247025",   "2507073850247025",   "2507073850247025",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2508_length16",  true,   "2508111747870564",   "2508111747870564",   "2508111747870564",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2509_length16",  true,   "2509241230017719",   "2509241230017719",   "2509241230017719",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2510_length16",  true,   "2510384536318683",   "2510384536318683",   "2510384536318683",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2511_length16",  true,   "2511635685008600",   "2511635685008600",   "2511635685008600",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2512_length16",  true,   "2512143022578467",   "2512143022578467",   "2512143022578467",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2513_length16",  true,   "2513620200552660",   "2513620200552660",   "2513620200552660",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2514_length16",  true,   "2514727227144261",   "2514727227144261",   "2514727227144261",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2515_length16",  true,   "2515011523021732",   "2515011523021732",   "2515011523021732",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2516_length16",  true,   "2516572218223288",   "2516572218223288",   "2516572218223288",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2517_length16",  true,   "2517738207148070",   "2517738207148070",   "2517738207148070",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2518_length16",  true,   "2518162501666050",   "2518162501666050",   "2518162501666050",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2519_length16",  true,   "2519266172828003",   "2519266172828003",   "2519266172828003",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2520_length16",  true,   "2520635262286859",   "2520635262286859",   "2520635262286859",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2521_length16",  true,   "2521635322614461",   "2521635322614461",   "2521635322614461",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2522_length16",  true,   "2522215620147750",   "2522215620147750",   "2522215620147750",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2523_length16",  true,   "2523242208423063",   "2523242208423063",   "2523242208423063",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2524_length16",  true,   "2524837107783670",   "2524837107783670",   "2524837107783670",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2525_length16",  true,   "2525222456158825",   "2525222456158825",   "2525222456158825",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2526_length16",  true,   "2526145152727750",   "2526145152727750",   "2526145152727750",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2527_length16",  true,   "2527154183145858",   "2527154183145858",   "2527154183145858",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2528_length16",  true,   "2528673476317766",   "2528673476317766",   "2528673476317766",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2529_length16",  true,   "2529250365784114",   "2529250365784114",   "2529250365784114",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2530_length16",  true,   "2530200536568117",   "2530200536568117",   "2530200536568117",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2531_length16",  true,   "2531827703647552",   "2531827703647552",   "2531827703647552",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2532_length16",  true,   "2532548588363805",   "2532548588363805",   "2532548588363805",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2533_length16",  true,   "2533553175183177",   "2533553175183177",   "2533553175183177",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2534_length16",  true,   "2534140272432068",   "2534140272432068",   "2534140272432068",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2535_length16",  true,   "2535560563233264",   "2535560563233264",   "2535560563233264",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2536_length16",  true,   "2536427843078589",   "2536427843078589",   "2536427843078589",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2537_length16",  true,   "2537267084003162",   "2537267084003162",   "2537267084003162",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2538_length16",  true,   "2538111112743119",   "2538111112743119",   "2538111112743119",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2539_length16",  true,   "2539232652524021",   "2539232652524021",   "2539232652524021",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2540_length16",  true,   "2540172638240879",   "2540172638240879",   "2540172638240879",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2541_length16",  true,   "2541347502874818",   "2541347502874818",   "2541347502874818",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2542_length16",  true,   "2542508213051009",   "2542508213051009",   "2542508213051009",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2543_length16",  true,   "2543115472741582",   "2543115472741582",   "2543115472741582",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2544_length16",  true,   "2544358304713036",   "2544358304713036",   "2544358304713036",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2545_length16",  true,   "2545545840258018",   "2545545840258018",   "2545545840258018",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2546_length16",  true,   "2546737356767859",   "2546737356767859",   "2546737356767859",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2547_length16",  true,   "2547415243726029",   "2547415243726029",   "2547415243726029",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2548_length16",  true,   "2548176803080319",   "2548176803080319",   "2548176803080319",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2549_length16",  true,   "2549422568365118",   "2549422568365118",   "2549422568365118",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2550_length16",  true,   "2550583247287647",   "2550583247287647",   "2550583247287647",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2551_length16",  true,   "2551868311017866",   "2551868311017866",   "2551868311017866",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2552_length16",  true,   "2552175865877581",   "2552175865877581",   "2552175865877581",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2553_length16",  true,   "2553873504188118",   "2553873504188118",   "2553873504188118",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2554_length16",  true,   "2554445441646174",   "2554445441646174",   "2554445441646174",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2555_length16",  true,   "2555741247640372",   "2555741247640372",   "2555741247640372",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2556_length16",  true,   "2556523662201032",   "2556523662201032",   "2556523662201032",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2557_length16",  true,   "2557141114843365",   "2557141114843365",   "2557141114843365",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2558_length16",  true,   "2558258728774882",   "2558258728774882",   "2558258728774882",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2559_length16",  true,   "2559646266636464",   "2559646266636464",   "2559646266636464",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2560_length16",  true,   "2560363286800776",   "2560363286800776",   "2560363286800776",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2561_length16",  true,   "2561655752565604",   "2561655752565604",   "2561655752565604",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2562_length16",  true,   "2562236285828253",   "2562236285828253",   "2562236285828253",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2563_length16",  true,   "2563302675674787",   "2563302675674787",   "2563302675674787",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2564_length16",  true,   "2564128176505330",   "2564128176505330",   "2564128176505330",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2565_length16",  true,   "2565043267525452",   "2565043267525452",   "2565043267525452",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2566_length16",  true,   "2566728205520644",   "2566728205520644",   "2566728205520644",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2567_length16",  true,   "2567551502438552",   "2567551502438552",   "2567551502438552",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2568_length16",  true,   "2568588602762712",   "2568588602762712",   "2568588602762712",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2569_length16",  true,   "2569013137264703",   "2569013137264703",   "2569013137264703",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2570_length16",  true,   "2570005578004348",   "2570005578004348",   "2570005578004348",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2571_length16",  true,   "2571351247485271",   "2571351247485271",   "2571351247485271",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2572_length16",  true,   "2572850504503360",   "2572850504503360",   "2572850504503360",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2573_length16",  true,   "2573058842647688",   "2573058842647688",   "2573058842647688",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2574_length16",  true,   "2574330014830213",   "2574330014830213",   "2574330014830213",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2575_length16",  true,   "2575762072701879",   "2575762072701879",   "2575762072701879",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2576_length16",  true,   "2576853272000631",   "2576853272000631",   "2576853272000631",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2577_length16",  true,   "2577806751831024",   "2577806751831024",   "2577806751831024",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2578_length16",  true,   "2578457217784446",   "2578457217784446",   "2578457217784446",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2579_length16",  true,   "2579130488587108",   "2579130488587108",   "2579130488587108",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2580_length16",  true,   "2580865021726500",   "2580865021726500",   "2580865021726500",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2581_length16",  true,   "2581685750642317",   "2581685750642317",   "2581685750642317",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2582_length16",  true,   "2582448535837234",   "2582448535837234",   "2582448535837234",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2583_length16",  true,   "2583146687147019",   "2583146687147019",   "2583146687147019",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2584_length16",  true,   "2584432380640867",   "2584432380640867",   "2584432380640867",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2585_length16",  true,   "2585630267276015",   "2585630267276015",   "2585630267276015",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2586_length16",  true,   "2586677655112285",   "2586677655112285",   "2586677655112285",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2587_length16",  true,   "2587735363772508",   "2587735363772508",   "2587735363772508",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2588_length16",  true,   "2588441017383854",   "2588441017383854",   "2588441017383854",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2589_length16",  true,   "2589483445558607",   "2589483445558607",   "2589483445558607",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2590_length16",  true,   "2590726770284885",   "2590726770284885",   "2590726770284885",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2591_length16",  true,   "2591420454842478",   "2591420454842478",   "2591420454842478",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2592_length16",  true,   "2592080151551670",   "2592080151551670",   "2592080151551670",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2593_length16",  true,   "2593748853855602",   "2593748853855602",   "2593748853855602",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2594_length16",  true,   "2594166730130470",   "2594166730130470",   "2594166730130470",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2595_length16",  true,   "2595843436781868",   "2595843436781868",   "2595843436781868",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2596_length16",  true,   "2596266707482348",   "2596266707482348",   "2596266707482348",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2597_length16",  true,   "2597340732865352",   "2597340732865352",   "2597340732865352",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2598_length16",  true,   "2598505706785278",   "2598505706785278",   "2598505706785278",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2599_length16",  true,   "2599120410446388",   "2599120410446388",   "2599120410446388",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2600_length16",  true,   "2600152118478808",   "2600152118478808",   "2600152118478808",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2601_length16",  true,   "2601780262542653",   "2601780262542653",   "2601780262542653",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2602_length16",  true,   "2602607756625158",   "2602607756625158",   "2602607756625158",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2603_length16",  true,   "2603368145741029",   "2603368145741029",   "2603368145741029",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2604_length16",  true,   "2604386782703176",   "2604386782703176",   "2604386782703176",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2605_length16",  true,   "2605318561503484",   "2605318561503484",   "2605318561503484",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2606_length16",  true,   "2606720363543338",   "2606720363543338",   "2606720363543338",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2607_length16",  true,   "2607154047224850",   "2607154047224850",   "2607154047224850",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2608_length16",  true,   "2608261050704105",   "2608261050704105",   "2608261050704105",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2609_length16",  true,   "2609337878242228",   "2609337878242228",   "2609337878242228",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2610_length16",  true,   "2610116843041874",   "2610116843041874",   "2610116843041874",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2611_length16",  true,   "2611607682321541",   "2611607682321541",   "2611607682321541",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2612_length16",  true,   "2612354760135712",   "2612354760135712",   "2612354760135712",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2613_length16",  true,   "2613454643645371",   "2613454643645371",   "2613454643645371",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2614_length16",  true,   "2614316242331233",   "2614316242331233",   "2614316242331233",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2615_length16",  true,   "2615630047826422",   "2615630047826422",   "2615630047826422",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2616_length16",  true,   "2616186402430333",   "2616186402430333",   "2616186402430333",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2617_length16",  true,   "2617707304756647",   "2617707304756647",   "2617707304756647",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2618_length16",  true,   "2618457808236576",   "2618457808236576",   "2618457808236576",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2619_length16",  true,   "2619361435782425",   "2619361435782425",   "2619361435782425",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2620_length16",  true,   "2620878116233201",   "2620878116233201",   "2620878116233201",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2621_length16",  true,   "2621354402875336",   "2621354402875336",   "2621354402875336",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2622_length16",  true,   "2622741265143571",   "2622741265143571",   "2622741265143571",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2623_length16",  true,   "2623422758451818",   "2623422758451818",   "2623422758451818",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2624_length16",  true,   "2624061081546743",   "2624061081546743",   "2624061081546743",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2625_length16",  true,   "2625717005832464",   "2625717005832464",   "2625717005832464",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2626_length16",  true,   "2626376718358710",   "2626376718358710",   "2626376718358710",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2627_length16",  true,   "2627828415767261",   "2627828415767261",   "2627828415767261",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2628_length16",  true,   "2628505452436773",   "2628505452436773",   "2628505452436773",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2629_length16",  true,   "2629741475388662",   "2629741475388662",   "2629741475388662",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2630_length16",  true,   "2630843342516470",   "2630843342516470",   "2630843342516470",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2631_length16",  true,   "2631424207482188",   "2631424207482188",   "2631424207482188",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2632_length16",  true,   "2632230456756308",   "2632230456756308",   "2632230456756308",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2633_length16",  true,   "2633634365658746",   "2633634365658746",   "2633634365658746",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2634_length16",  true,   "2634888734268863",   "2634888734268863",   "2634888734268863",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2635_length16",  true,   "2635717661161883",   "2635717661161883",   "2635717661161883",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2636_length16",  true,   "2636837152157288",   "2636837152157288",   "2636837152157288",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2637_length16",  true,   "2637055061454568",   "2637055061454568",   "2637055061454568",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2638_length16",  true,   "2638378454742368",   "2638378454742368",   "2638378454742368",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2639_length16",  true,   "2639808382063163",   "2639808382063163",   "2639808382063163",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2640_length16",  true,   "2640881350504648",   "2640881350504648",   "2640881350504648",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2641_length16",  true,   "2641270652532839",   "2641270652532839",   "2641270652532839",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2642_length16",  true,   "2642354853162726",   "2642354853162726",   "2642354853162726",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2643_length16",  true,   "2643563261321844",   "2643563261321844",   "2643563261321844",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2644_length16",  true,   "2644786181763675",   "2644786181763675",   "2644786181763675",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2645_length16",  true,   "2645005101601256",   "2645005101601256",   "2645005101601256",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2646_length16",  true,   "2646111428300421",   "2646111428300421",   "2646111428300421",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2647_length16",  true,   "2647405617647322",   "2647405617647322",   "2647405617647322",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2648_length16",  true,   "2648131246555731",   "2648131246555731",   "2648131246555731",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2649_length16",  true,   "2649023526744243",   "2649023526744243",   "2649023526744243",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2650_length16",  true,   "2650301521683111",   "2650301521683111",   "2650301521683111",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2651_length16",  true,   "2651335505283307",   "2651335505283307",   "2651335505283307",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2652_length16",  true,   "2652483428654623",   "2652483428654623",   "2652483428654623",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2653_length16",  true,   "2653253274602151",   "2653253274602151",   "2653253274602151",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2654_length16",  true,   "2654112217043742",   "2654112217043742",   "2654112217043742",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2655_length16",  true,   "2655723232372251",   "2655723232372251",   "2655723232372251",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2656_length16",  true,   "2656340748835637",   "2656340748835637",   "2656340748835637",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2657_length16",  true,   "2657855156612276",   "2657855156612276",   "2657855156612276",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2658_length16",  true,   "2658788048331384",   "2658788048331384",   "2658788048331384",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2659_length16",  true,   "2659227004078530",   "2659227004078530",   "2659227004078530",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2660_length16",  true,   "2660515305508347",   "2660515305508347",   "2660515305508347",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2661_length16",  true,   "2661385738670356",   "2661385738670356",   "2661385738670356",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2662_length16",  true,   "2662178735666116",   "2662178735666116",   "2662178735666116",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2663_length16",  true,   "2663474377731063",   "2663474377731063",   "2663474377731063",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2664_length16",  true,   "2664582358500304",   "2664582358500304",   "2664582358500304",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2665_length16",  true,   "2665721211854560",   "2665721211854560",   "2665721211854560",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2666_length16",  true,   "2666770085724283",   "2666770085724283",   "2666770085724283",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2667_length16",  true,   "2667347036025059",   "2667347036025059",   "2667347036025059",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2668_length16",  true,   "2668378401170880",   "2668378401170880",   "2668378401170880",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2669_length16",  true,   "2669156546748268",   "2669156546748268",   "2669156546748268",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2670_length16",  true,   "2670447152571863",   "2670447152571863",   "2670447152571863",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2671_length16",  true,   "2671327642681085",   "2671327642681085",   "2671327642681085",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2672_length16",  true,   "2672484463616077",   "2672484463616077",   "2672484463616077",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2673_length16",  true,   "2673753404411734",   "2673753404411734",   "2673753404411734",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2674_length16",  true,   "2674868888770766",   "2674868888770766",   "2674868888770766",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2675_length16",  true,   "2675880045143133",   "2675880045143133",   "2675880045143133",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2676_length16",  true,   "2676406431431301",   "2676406431431301",   "2676406431431301",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2677_length16",  true,   "2677706125651570",   "2677706125651570",   "2677706125651570",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2678_length16",  true,   "2678615731353662",   "2678615731353662",   "2678615731353662",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2679_length16",  true,   "2679366151573848",   "2679366151573848",   "2679366151573848",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2680_length16",  true,   "2680025603711169",   "2680025603711169",   "2680025603711169",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2681_length16",  true,   "2681734758220467",   "2681734758220467",   "2681734758220467",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2682_length16",  true,   "2682580723438281",   "2682580723438281",   "2682580723438281",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2683_length16",  true,   "2683344686655566",   "2683344686655566",   "2683344686655566",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2684_length16",  true,   "2684630120632685",   "2684630120632685",   "2684630120632685",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2685_length16",  true,   "2685225322356750",   "2685225322356750",   "2685225322356750",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2686_length16",  true,   "2686130437714761",   "2686130437714761",   "2686130437714761",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2687_length16",  true,   "2687011308562837",   "2687011308562837",   "2687011308562837",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2688_length16",  true,   "2688880476340013",   "2688880476340013",   "2688880476340013",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2689_length16",  true,   "2689506525052312",   "2689506525052312",   "2689506525052312",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2690_length16",  true,   "2690372514104763",   "2690372514104763",   "2690372514104763",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2691_length16",  true,   "2691552558072609",   "2691552558072609",   "2691552558072609",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2692_length16",  true,   "2692185672575535",   "2692185672575535",   "2692185672575535",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2693_length16",  true,   "2693171064545020",   "2693171064545020",   "2693171064545020",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2694_length16",  true,   "2694353442358768",   "2694353442358768",   "2694353442358768",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2695_length16",  true,   "2695614072002615",   "2695614072002615",   "2695614072002615",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2696_length16",  true,   "2696830325120421",   "2696830325120421",   "2696830325120421",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2697_length16",  true,   "2697818808215759",   "2697818808215759",   "2697818808215759",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2698_length16",  true,   "2698887711503220",   "2698887711503220",   "2698887711503220",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2699_length16",  true,   "2699270200573104",   "2699270200573104",   "2699270200573104",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2700_length16",  true,   "2700645555346130",   "2700645555346130",   "2700645555346130",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2701_length16",  true,   "2701660564112737",   "2701660564112737",   "2701660564112737",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2702_length16",  true,   "2702042085851672",   "2702042085851672",   "2702042085851672",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2703_length16",  true,   "2703571357135439",   "2703571357135439",   "2703571357135439",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2704_length16",  true,   "2704776274782606",   "2704776274782606",   "2704776274782606",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2705_length16",  true,   "2705870055520266",   "2705870055520266",   "2705870055520266",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2706_length16",  true,   "2706688700260008",   "2706688700260008",   "2706688700260008",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2707_length16",  true,   "2707040646437127",   "2707040646437127",   "2707040646437127",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2708_length16",  true,   "2708273561400288",   "2708273561400288",   "2708273561400288",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2709_length16",  true,   "2709527334404276",   "2709527334404276",   "2709527334404276",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2710_length16",  true,   "2710353508614666",   "2710353508614666",   "2710353508614666",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2711_length16",  true,   "2711853582381552",   "2711853582381552",   "2711853582381552",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2712_length16",  true,   "2712577047300639",   "2712577047300639",   "2712577047300639",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2713_length16",  true,   "2713582878300129",   "2713582878300129",   "2713582878300129",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2714_length16",  true,   "2714884530375674",   "2714884530375674",   "2714884530375674",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2715_length16",  true,   "2715547007276605",   "2715547007276605",   "2715547007276605",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2716_length16",  true,   "2716210742818780",   "2716210742818780",   "2716210742818780",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2717_length16",  true,   "2717318141301156",   "2717318141301156",   "2717318141301156",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2718_length16",  true,   "2718538738518149",   "2718538738518149",   "2718538738518149",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2719_length16",  true,   "2719184621702786",   "2719184621702786",   "2719184621702786",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2720_length16",  true,   "2720502475813374",   "2720502475813374",   "2720502475813374",   Event.VALIDATION_SUCCESS  ),
   // Begin invalid length check
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix51_invalidLength15",          true,   "518426704611088",          "518426704611088",    "518426704611088",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix51_invalidLength17",          true,   "51328637405243756",        "5132863740524375",   "5132863740524375",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix52_invalidLength15",          true,   "521054153757767",          "521054153757767",    "521054153757767",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix52_invalidLength17",          true,   "52644131212736785",        "5264413121273678",   "5264413121273678",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix53_invalidLength15",          true,   "535601544067753",          "535601544067753",    "535601544067753",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix53_invalidLength17",          true,   "53454121683377109",        "5345412168337710",   "5345412168337710",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix54_invalidLength15",          true,   "546633663170024",          "546633663170024",    "546633663170024",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix54_invalidLength17",          true,   "54631086273232861",        "5463108627323286",   "5463108627323286",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix55_invalidLength15",          true,   "551424704848014",          "551424704848014",    "551424704848014",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix55_invalidLength17",          true,   "55073621202282553",        "5507362120228255",   "5507362120228255",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2221_invalidLength15",        true,   "222103615153214",          "222103615153214",    "222103615153214",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2221_invalidLength17",        true,   "55073621202282553",        "5507362120228255",   "5507362120228255",   Event.VALIDATION_FAILED  ),
   // End invalid length check
   // Begin invalid chars check
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix51_length16_invalidChars",    true,   "a51X3560$7880.62130]4",  "5135607880621304",   "5135607880621304",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix52_length16_invalidChars",    true,   "52!178;0125301453[3",    "5217801253014533",   "5217801253014533",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix53_length16_invalidChars",    true,   "5b3B4304=3472540 777",   "5343043472540777",   "5343043472540777",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix54_length16_invalidChars",    true,   "5451-3472-2482-8804",    "5451347224828804",   "5451347224828804",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix55_length16_invalidChars",    true,   "55u^74045605155753 ",    "5574045605155753",   "5574045605155753",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_prefix2221_length16_invalidChars",  true,   "22:21266)6060R774o24",   "2221266606077424",   "2221266606077424",   Event.VALIDATION_SUCCESS  ),
   // End invalid chars check
   // Begin check of 2221
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix20",     true,   "20",     "2",     "2",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix21",     true,   "21",     "2",     "2",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix220",    true,   "220",    "22",    "22",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix221",    true,   "221",    "22",    "22",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix2220",   true,   "2220",   "222",   "222",   Event.VALIDATION_FAILED  ),
   // End check of 2221
   // Begin check of 2720
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix2721",   true,   "2721",   "272",   "272",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix2722",   true,   "2722",   "272",   "272",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix2723",   true,   "2723",   "272",   "272",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix2724",   true,   "2724",   "272",   "272",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix2725",   true,   "2725",   "272",   "272",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix2726",   true,   "2726",   "272",   "272",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix2727",   true,   "2727",   "272",   "272",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix2728",   true,   "2728",   "272",   "272",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix2729",   true,   "2729",   "272",   "272",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix273",    true,   "273",    "27",    "27",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix28",     true,   "28",     "2",     "2",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix29",     true,   "29",     "2",     "2",     Event.VALIDATION_FAILED  ),
   // End check of 2720
   // Begin blatantly wrong prefix check
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix1",      true,   "1",      "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix3",      true,   "3",      "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix4",      true,   "4",      "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix6",      true,   "6",      "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix7",      true,   "7",      "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix8",      true,   "8",      "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix9",      true,   "9",      "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MASTERCARD,   "ignore_masterCard_invalidPrefix0",      true,   "0",      "",      "",      Event.VALIDATION_SUCCESS  ),
   // End blatantly wrong prefix check

   tc(  FieldType.VISA,         "ignore_visa_prefix4_length13",          true,   "4455067444713",          "4455067444713",         "4455067444713",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.VISA,         "ignore_visa_prefix4_length16",          true,   "4371447711783213",       "4371447711783213",      "4371447711783213",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.VISA,         "ignore_visa_prefix4_length19",          true,   "4212144770344706041",    "4212144770344706041",   "4212144770344706041",   Event.VALIDATION_SUCCESS  ),
   // Begin invalid length check
   tc(  FieldType.VISA,         "ignore_visa_prefix4_length12",          true,   "427815235648",           "427815235648",          "427815235648",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,         "ignore_visa_prefix4_length14",          true,   "45842811557182",         "45842811557182",        "45842811557182",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,         "ignore_visa_prefix4_length15",          true,   "438740434546761",        "438740434546761",       "438740434546761",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,         "ignore_visa_prefix4_length17",          true,   "43487538814261138",      "43487538814261138",     "43487538814261138",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,         "ignore_visa_prefix4_length18",          true,   "421431601867875553",     "421431601867875553",    "421431601867875553",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,         "ignore_visa_prefix4_length20",          true,   "43213753745312750349",   "4321375374531275034",   "4321375374531275034",   Event.VALIDATION_FAILED  ),
   // End invalid length check
   // Begin invalid chars check
   tc(  FieldType.VISA,         "ignore_visa_prefix4_length13_invalidChars",   true,   "#4455-067.4 44%71f3A",   "4455067444713",         "4455067444713",         Event.VALIDATION_SUCCESS  ),
   // End invalid chars check
   // Begin wrong prefix check
   tc(  FieldType.VISA,   "ignore_visa_invalidPrefix1",      true,   "1",      "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.VISA,   "ignore_visa_invalidPrefix2",      true,   "2",      "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.VISA,   "ignore_visa_invalidPrefix3",      true,   "3",      "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.VISA,   "ignore_visa_invalidPrefix5",      true,   "5",      "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.VISA,   "ignore_visa_invalidPrefix6",      true,   "6",      "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.VISA,   "ignore_visa_invalidPrefix7",      true,   "7",      "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.VISA,   "ignore_visa_invalidPrefix8",      true,   "8",      "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.VISA,   "ignore_visa_invalidPrefix9",      true,   "9",      "",      "",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.VISA,   "ignore_visa_invalidPrefix0",      true,   "0",      "",      "",      Event.VALIDATION_SUCCESS  ),
   // End wrong prefix check

   tc(  FieldType.US_ZIP,   "ignore_usZip_1digit",            true,   "1",            "1",            "1",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP,   "ignore_usZip_2digits",           true,   "12",           "12",           "12",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP,   "ignore_usZip_3digits",           true,   "123",          "123",          "123",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP,   "ignore_usZip_4digits",           true,   "1234",         "1234",         "1234",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP,   "ignore_usZip_5digits",           true,   "12345",        "12345",        "12345",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP,   "ignore_usZip_6digitsNoHyphen",   true,   "123456",       "12345",        "12345",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP,   "ignore_usZip_6digits",           true,   "12345-6",      "12345-6",      "12345-6",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP,   "ignore_usZip_7digits",           true,   "12345-67",     "12345-67",     "12345-67",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP,   "ignore_usZip_8digits",           true,   "12345-678",    "12345-678",    "12345-678",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP,   "ignore_usZip_9digits",           true,   "12345-6789",   "12345-6789",   "12345-6789",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP,   "ignore_usZip_invalidChars",      true,   "1-2 3d4.5$",   "12345",        "12345",        Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.US_ZIP5,   "ignore_usZip5_1digit",         true,   "1",            "1",       "1",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP5,   "ignore_usZip5_2digits",        true,   "12",           "12",      "12",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP5,   "ignore_usZip5_3digits",        true,   "123",          "123",     "123",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP5,   "ignore_usZip5_4digits",        true,   "1234",         "1234",    "1234",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP5,   "ignore_usZip5_5digits",        true,   "12345",        "12345",   "12345",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP5,   "ignore_usZip5_6digits",        true,   "123456",       "12345",   "12345",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP5,   "ignore_usZip5_invalidChars",   true,   "1-2 3d4.5$",   "12345",   "12345",   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.US_ZIP_SUFFIX,   "ignore_usZipSuffix_1digit",        true,   "1",          "1",      "1",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP_SUFFIX,   "ignore_usZipSuffix_2digits",       true,   "12",         "12",     "12",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP_SUFFIX,   "ignore_usZipSuffix_3digits",       true,   "123",        "123",    "123",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP_SUFFIX,   "ignore_usZipSuffix_4digits",       true,   "1234",       "1234",   "1234",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP_SUFFIX,   "ignore_usZipSuffix_5digits",       true,   "12345",      "1234",   "1234",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP_SUFFIX,   "ignore_usZipSuffix_invalidChars",  true,   "1-2 3d4.$",  "1234",   "1234",   Event.VALIDATION_SUCCESS  ),

   // Second set:  don't ignore invalid input

   tc(  FieldType.ALPHA,         "noIgnore_alpha_invalid1",        false,   "!",   "!",   "!",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.ALPHA,         "noIgnore_alpha_invalid2",        false,   "1",   "1",   "1",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.ALPHA,         "noIgnore_alpha_invalid3",        false,   " ",   " ",   " ",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.ALPHA,         "noIgnore_alpha_valid1",          false,   Characters.UPPER_ALPHA,   Characters.UPPER_ALPHA,   Characters.UPPER_ALPHA,   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ALPHA,         "noIgnore_alpha_valid2",          false,   Characters.LOWER_ALPHA,   Characters.LOWER_ALPHA,   Characters.LOWER_ALPHA,   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.ALPHA,         "noIgnore_alpha_valid3",          false,   Characters.ALPHA,         Characters.ALPHA,         Characters.ALPHA,         Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.UPPER_ALPHA,   "noIgnore_upperAlpha_invalid1",   false,   "@",   "@",   "@",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.UPPER_ALPHA,   "noIgnore_upperAlpha_invalid2",   false,   "2",   "2",   "2",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.UPPER_ALPHA,   "noIgnore_upperAlpha_invalid3",   false,   " ",   " ",   " ",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.UPPER_ALPHA,   "noIgnore_upperAlpha_invalid4",   false,   "a",   "a",  "a",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.UPPER_ALPHA,   "noIgnore_upperAlpha_valid",      false,   Characters.UPPER_ALPHA,   Characters.UPPER_ALPHA,   Characters.UPPER_ALPHA,   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.LOWER_ALPHA,   "noIgnore_lowerAlpha_invalid1",   false,   "#",   "#",   "#",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.LOWER_ALPHA,   "noIgnore_lowerAlpha_invalid2",   false,   "3",   "3",   "3",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.LOWER_ALPHA,   "noIgnore_lowerAlpha_invalid3",   false,   " ",   " ",   " ",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.LOWER_ALPHA,   "noIgnore_lowerAlpha_invalid4",   false,   Characters.UPPER_ALPHA,   Characters.UPPER_ALPHA,   Characters.UPPER_ALPHA,   Event.VALIDATION_FAILED  ),
   tc(  FieldType.LOWER_ALPHA,   "noIgnore_lowerAlpha_valid",      false,   Characters.LOWER_ALPHA,   Characters.LOWER_ALPHA,   Characters.LOWER_ALPHA,   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.ALPHA_SPACE,   "noIgnore_alphaSpace_invalid1",   false,   "%",   "%",   "%",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.ALPHA_SPACE,   "noIgnore_alphaSpace_invalid2",   false,   "5",   "5",   "5",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.ALPHA_SPACE,   "noIgnore_alphaSpace_valid",      false,   Characters.ALPHA_SPACE,   Characters.ALPHA_SPACE,   Characters.ALPHA_SPACE,   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.UPPER_ALPHA_SPACE,   "noIgnore_upperAlphaSpace_invalid1",   false,   "^",   "^",   "^",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.UPPER_ALPHA_SPACE,   "noIgnore_upperAlphaSpace_invalid2",   false,   "6",   "6",   "6",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.UPPER_ALPHA_SPACE,   "noIgnore_upperAlphaSpace_invalid3",   false,   "b",   "b",   "b",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.UPPER_ALPHA_SPACE,   "noIgnore_upperAlphaSpace_valid",      false,   Characters.UPPER_ALPHA_SPACE,   Characters.UPPER_ALPHA_SPACE,   Characters.UPPER_ALPHA_SPACE,   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.LOWER_ALPHA_SPACE,   "noIgnore_lowerAlphaSpace_invalid1",   false,   "&",   "&",   "&",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.LOWER_ALPHA_SPACE,   "noIgnore_lowerAlphaSpace_invalid2",   false,   "7",   "7",   "7",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.LOWER_ALPHA_SPACE,   "noIgnore_lowerAlphaSpace_invalid3",   false,   "C",   "C",   "C",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.LOWER_ALPHA_SPACE,   "noIgnore_lowerAlphaSpace_valid",      false,   Characters.LOWER_ALPHA_SPACE,   Characters.LOWER_ALPHA_SPACE,   Characters.LOWER_ALPHA_SPACE, Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.ALPHANUMERIC,        "noIgnore_alphanumeric_invalid1",      false,   "*",   "*",   "*",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.ALPHANUMERIC,        "noIgnore_alphanumeric_valid",         false,   Characters.ALPHANUMERIC,   Characters.ALPHANUMERIC,   Characters.ALPHANUMERIC,   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.UPPER_ALPHANUMERIC,  "noIgnore_upperAlphanumeric_invalid1",  false,   "d",   "d",   "d",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.UPPER_ALPHANUMERIC,  "noIgnore_upperAlphanumeric_invalid2",  false,   "/",   "/",   "/",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.UPPER_ALPHANUMERIC,  "noIgnore_upperAlphanumeric_valid",     false,   Characters.UPPER_ALPHANUMERIC,   Characters.UPPER_ALPHANUMERIC,   Characters.UPPER_ALPHANUMERIC,   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.LOWER_ALPHANUMERIC,  "noIgnore_lowerAlphanumeric_invalid1",  false,   "E",   "E",   "E",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.LOWER_ALPHANUMERIC,  "noIgnore_lowerAlphanumeric_invalid2",  false,   "?",   "?",   "?",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.LOWER_ALPHANUMERIC,  "noIgnore_lowerAlphanumeric_valid",     false,   Characters.LOWER_ALPHANUMERIC,   Characters.LOWER_ALPHANUMERIC,   Characters.LOWER_ALPHANUMERIC,   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.ALPHANUMERIC_SPACE,  "noIgnore_alphanumericSpace_invalid1",  false,   ";",   ";",   ";",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.ALPHANUMERIC_SPACE,  "noIgnore_alphanumericSpace_all",       false,   Characters.ALPHANUMERIC_SPACE,   Characters.ALPHANUMERIC_SPACE,   Characters.ALPHANUMERIC_SPACE,   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.UPPER_ALPHANUMERIC_SPACE,  "noIgnore_upperAlphanumericSpace_invalid1",   false,   "f",   "f",   "f",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.UPPER_ALPHANUMERIC_SPACE,  "noIgnore_upperAlphanumericSpace_invalid2",   false,   ":",   ":",   ":",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.UPPER_ALPHANUMERIC_SPACE,  "noIgnore_upperAlphanumericSpace_valid",      false,   Characters.UPPER_ALPHANUMERIC_SPACE,   Characters.UPPER_ALPHANUMERIC_SPACE,   Characters.UPPER_ALPHANUMERIC_SPACE,   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.LOWER_ALPHANUMERIC_SPACE,  "noIgnore_lowerAlphanumericSpace_invalid1",   false,   "G",   "G",   "G",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.LOWER_ALPHANUMERIC_SPACE,  "noIgnore_lowerAlphanumericSpace_invalid2",   false,   "'",   "'",   "'",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.LOWER_ALPHANUMERIC_SPACE,  "noIgnore_lowerAlphanumericSpace_valid",      false,   Characters.LOWER_ALPHANUMERIC_SPACE,   Characters.LOWER_ALPHANUMERIC_SPACE,   Characters.LOWER_ALPHANUMERIC_SPACE,   Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.INT,   "noIgnore_int",                         false,   Characters.NUMBERS_END_ZERO,   Characters.NUMBERS_END_ZERO,   Characters.NUMBERS_END_ZERO,   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.INT,   "noIgnore_int_multipleZero",            false,   "000",      "000",      "000",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.INT,   "noIgnore_int_positive_leadingZero",    false,   "001",      "001",      "001",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.INT,   "noIgnore_int_dash",                    false,   "-",        "-",        "-",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.INT,   "noIgnore_int_negative_negativeZero",   false,   "-0",       "-0",       "-0",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.INT,   "noIgnore_int_negative",                false,   "-123",     "-123",     "-123",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.INT,   "noIgnore_int_negative_leadingZero",    false,   "-00432",   "-00432",   "-00432",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.INT,   "noIgnore_int_doubleNegative",          false,   "--1",      "--1",      "--1",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.INT,   "noIgnore_int_floatingPoint",           false,   "1.23",     "1.23",     "1.23",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.INT,   "noIgnore_int_letter",                  false,   "h",        "h",        "h",        Event.VALIDATION_FAILED  ),

   tc(  FieldType.POSITIVE_INT,   "noIgnore_positiveInt",                  false,   Characters.NUMBERS_END_ZERO,   Characters.NUMBERS_END_ZERO,   Characters.NUMBERS_END_ZERO,   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_INT,   "noIgnore_positiveInt_multipleZero",     false,  "000",    "000",   "000",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_INT,   "noIgnore_positiveInt_leadingZero",      false,  "001",    "001",   "001",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_INT,   "noIgnore_positiveInt_dash",             false,   "-",     "-",      "-",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_INT,   "noIgnore_positiveInt_negative",         false,  "-1",     "-1",     "-1",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_INT,   "noIgnore_positiveInt_floatingPoint",    false,  "1.23",   "1.23",   "1.23",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_INT,   "noIgnore_positiveInt_letter",           false,  "i",      "i",      "i",      Event.VALIDATION_FAILED  ),

   tc(  FieldType.NEGATIVE_INT,   "noIgnore_negativeInt",                        false,   "-" + Characters.NUMBERS_END_ZERO,
                                                                                          "-" + Characters.NUMBERS_END_ZERO,
                                                                                          "-" + Characters.NUMBERS_END_ZERO,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_INT,   "noIgnore_negativeInt_multipleZero1",          false,   "000",      "000",      "000",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_INT,   "noIgnore_negativeInt_multipleZero2",          false,   "-000",     "-000",     "-000",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_INT,   "noIgnore_negativeInt_positive",               false,   "1",        "1",        "1",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_INT,   "noIgnore_negativeInt_dash",                   false,   "-",        "-",        "-",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_INT,   "noIgnore_negativeInt_negativeZero",           false,   "-0",       "-0",       "-0",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_INT,   "noIgnore_negativeInt_negative_leadingZero",   false,   "-00432",   "-00432",   "-00432",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_INT,   "noIgnore_negativeInt_doubleDash1",            false,   "--123",    "--123",    "--123",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_INT,   "noIgnore_negativeInt_doubleDash2",            false,   "-12-3",    "-12-3",    "-12-3",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_INT,   "noIgnore_negativeInt_floatingPoint",          false,   "-1.23",    "-1.23",    "-1.23",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_INT,   "noIgnore_negativeInt_letter",                 false,   "j",        "j",        "j",        Event.VALIDATION_FAILED  ),

   tc(  FieldType.STRICT_INT,     "noIgnore_strictInt_negative",                 false,   "-" + Characters.NUMBERS_END_ZERO,
                                                                                          "-" + Characters.NUMBERS_END_ZERO,
                                                                                          "-" + Characters.NUMBERS_END_ZERO,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_INT,     "noIgnore_strictInt_positive",                 false,   Characters.NUMBERS_END_ZERO,   Characters.NUMBERS_END_ZERO,   Characters.NUMBERS_END_ZERO,   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_INT,     "noIgnore_strictInt_letter",                   false,   "k",        "k",        "k",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_INT,     "noIgnore_strictInt_doubleZero",               false,   "00",       "00",       "00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_INT,     "noIgnore_strictInt_positive_leadingZero",     false,   "01",       "01",       "01",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_INT,     "noIgnore_strictInt_negative_leadingZero",     false,   "-00432",   "-00432",   "-00432",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_INT,     "noIgnore_strictInt_dash",                     false,   "-",        "-",        "-",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_INT,     "noIgnore_strictInt_negative_negativeZero",    false,   "-0",       "-0",       "-0",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_INT,     "noIgnore_strictInt_doubleNegative",           false,   "--1",      "--1",      "--1",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_INT,     "noIgnore_strictInt_floatingPoint",            false,   "1.23",     "1.23",     "1.23",     Event.VALIDATION_FAILED  ),

   tc(  FieldType.STRICT_POSITIVE_INT,   "noIgnore_strictPositiveInt_positive",        false,   Characters.NUMBERS_END_ZERO,   Characters.NUMBERS_END_ZERO,   Characters.NUMBERS_END_ZERO,   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_INT,   "noIgnore_strictPositiveInt_negative",        false,   "-1",     "-1",   "-1",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_INT,   "noIgnore_strictPositiveInt_letter",          false,   "l",      "l",      "l",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_INT,   "noIgnore_strictPositiveInt_doubleZero",      false,   "00",     "00",     "00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_INT,   "noIgnore_strictPositiveInt_leadingZero",     false,   "01",     "01",     "01",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_INT,   "noIgnore_strictPositiveInt_dash",            false,   "-",      "-",      "-",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_INT,   "noIgnore_strictPositiveInt_negativeZero",    false,   "-0",     "-0",     "-0",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_INT,   "noIgnore_strictPositiveInt_floatingPoint",   false,   "1.23",   "1.23",   "1.23",   Event.VALIDATION_FAILED  ),

   tc(  FieldType.STRICT_NEGATIVE_INT,   "noIgnore_strictNegativeInt_negative",        false,   "-" + Characters.NUMBERS_START_ZERO,
                                                                                                "-" + Characters.NUMBERS_START_ZERO,
                                                                                                "-" + Characters.NUMBERS_START_ZERO,  Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,   "noIgnore_strictNegativeInt_positive",        false,   "1",       "1",       "1",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,   "noIgnore_strictNegativeInt_letter",          false,   "m",       "m",       "m",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,   "noIgnore_strictNegativeInt_doubleZero",      false,   "00",      "00",      "00",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,   "noIgnore_strictNegativeInt_dash",            false,   "-",       "-",       "-",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,   "noIgnore_strictNegativeInt_leadingZero",     false,   "-01",     "-01",     "-01",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,   "noIgnore_strictNegativeInt_negativeZero",    false,   "-0",      "-0",      "-0",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,   "noIgnore_strictNegativeInt_floatingPoint",   false,   "-1.23",   "-1.23",   "-1.23",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,   "noIgnore_strictNegativeInt_doubleDash1",     false,   "--123",   "--123",   "--123",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_INT,   "noIgnore_strictNegativeInt_doubleDash2",     false,   "-12-3",   "-12-3",   "-12-3",   Event.VALIDATION_FAILED  ),

   tc(  FieldType.FLOAT,  "noIgnore_float_all",                   false,   Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_START_ZERO,
                                                                           Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_START_ZERO,
                                                                           Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_START_ZERO,   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_bad",                   false,   "1.2a",           "1.2a",           "1.2a",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_posInt",                false,   "123",            "123",            "123",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_negInt",                false,   "-123",           "-123",           "-123",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_negFloat",              false,   "-1023.456789",   "-1023.456789",   "-1023.456789",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_zero1",                 false,   "0",              "0",              "0",              Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_zero2",                 false,   "0.0",            "0.0",            "0.0",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_zero3",                 false,   ".0",             ".0",             ".0",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_leadingDoubleZero1",    false,   "00",             "00",             "00",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_leadingDoubleZero2",    false,   "00.0",           "00.0",           "00.0",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_extraTrailingZero1",    false,   "0.00",           "0.00",           "0.00",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_extraTrailingZero2",    false,   "12.3450",        "12.3450",        "12.3450",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_leadingDoubleZeros3",   false,   "-00.0",          "-00.0",          "-00.0",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_negativeZero1",         false,   "-0",             "-0",             "-0",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_negativeZero2",         false,   "-.0",            "-.0",            "-.0",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_negativeZero3",         false,   "-0.000000",      "-0.000000",      "-0.000000",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_negativeZero4",         false,   "-0.0",           "-0.0",           "-0.0",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_dash",                  false,   "-",              "-",              "-",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_doubleDash",            false,   "--",             "--",             "--",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_dashDot",               false,   "-.",             "-.",             "-.",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_endInDot",              false,   "-1.",            "-1.",            "-1.",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_dashInWrongPlace1",     false,   "1-.2",           "1-.2",           "1-.2",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_dashInWrongPlace2",     false,   "1.-2",           "1.-2",           "1.-2",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_dashInWrongPlace3",     false,   "1.2-",           "1.2-",           "1.2-",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_doubleDot1",            false,   "..",             "..",             "..",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_doubleDot2",            false,   "1..2",           "1..2",           "1..2",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.FLOAT,  "noIgnore_float_dotsEverywhere",        false,   ".1.2.",          ".1.2.",          ".1.2.",          Event.VALIDATION_FAILED  ),

   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_all",  false,  Characters.NUMBERS_START_ZERO + "." + Characters.NUMBERS_END_ZERO,
                                                                           Characters.NUMBERS_START_ZERO + "." + Characters.NUMBERS_END_ZERO,
                                                                           Characters.NUMBERS_START_ZERO + "." + Characters.NUMBERS_END_ZERO,      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_bad",                   false,   "1.2a",           "1.2a",           "1.2a",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_posInt",                false,   "123",            "123",            "123",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_negInt",                false,   "-123",           "-123",           "-123",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_negFloat",              false,   "-1023.456789",   "-1023.456789",   "-1023.456789",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_zero1",                 false,   "0",              "0",              "0",              Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_zero2",                 false,   "0.0",            "0.0",            "0.0",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_zero3",                 false,   ".0",             ".0",             ".0",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_leadingDoubleZero1",    false,   "00",             "00",             "00",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_leadingDoubleZero2",    false,   "00.0",           "00.0",           "00.0",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_extraTrailingZero1",    false,   "0.00",           "0.00",           "0.00",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_extraTrailingZero2",    false,   "12.3450",        "12.3450",        "12.3450",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_leadingDoubleZeros3",   false,   "-00.0",          "-00.0",          "-00.0",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_negativeZero1",         false,   "-0",             "-0",             "-0",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_negativeZero2",         false,   "-.0",            "-.0",            "-.0",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_negativeZero3",         false,   "-0.000000",      "-0.000000",      "-0.000000",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_negativeZero4",         false,   "-0.0",           "-0.0",           "-0.0",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_dash",                  false,   "-",              "-",              "-",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_doubleDash",            false,   "--",             "--",             "--",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_dashDot",               false,   "-.",             "-.",             "-.",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_endInDot",              false,   "-1.",            "-1.",            "-1.",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_dashInWrongPlace1",     false,   "1-.2",           "1-.2",           "1-.2",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_dashInWrongPlace2",     false,   "1.-2",           "1.-2",           "1.-2",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_dashInWrongPlace3",     false,   "1.2-",           "1.2-",           "1.2-",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_doubleDot1",            false,   "..",             "..",             "..",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_doubleDot2",            false ,  "1..2",           "1..2",           "1..2",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_FLOAT,   "noIgnore_positiveFloat_dotsEverywhere",        false,   ".1.2.",          ".1.2.",          ".1.2.",          Event.VALIDATION_FAILED  ),

   tc(  FieldType.NEGATIVE_FLOAT,  "noIgnore_negativeFloat_all",                   false,  "-" + Characters.NUMBERS_START_ZERO + "." + Characters.NUMBERS_END_ZERO,
                                                                                           "-" + Characters.NUMBERS_START_ZERO + "." + Characters.NUMBERS_END_ZERO,
                                                                                           "-" + Characters.NUMBERS_START_ZERO + "." + Characters.NUMBERS_END_ZERO,   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_bad",                   false,   "-1.2a",          "-1.2a",          "-1.2a",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_posInt",                false,   "123",            "123",            "123",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_negInt",                false,   "-123",           "-123",           "-123",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_negFloat",              false,   "-1023.456789",   "-1023.456789",   "-1023.456789",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_zero1",                 false,   "0",              "0",              "0",              Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_zero2",                 false,   "0.0",            "0.0",            "0.0",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_zero3",                 false,   ".0",             ".0",             ".0",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_leadingDoubleZero1",    false,   "00",             "00",             "00",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_leadingDoubleZero2",    false,   "00.0",           "00.0",           "00.0",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_extraTrailingZero1",    false,   "0.00",           "0.00",           "0.00",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_extraTrailingZero2",    false,   "12.3450",        "12.3450",        "12.3450",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_leadingDoubleZeros3",   false,   "-00.0",          "-00.0",          "-00.0",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_negativeZero1",         false,   "-0",             "-0",             "-0",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_negativeZero2",         false,   "-.0",            "-.0",            "-.0",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_negativeZero3",         false,   "-0.000000",      "-0.000000",      "-0.000000",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_negativeZero4",         false,   "-0.0",           "-0.0",           "-0.0",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_dash",                  false,   "-",              "-",             "-",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_doubleDash",            false,   "--",             "--",            "--",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_dashDot",               false,   "-.",             "-.",            "-.",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_endInDot",              false,   "-1.",            "-1.",           "-1.",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_dashInWrongPlace1",     false,   "1-.2",           "1-.2",          "1-.2",            Event.VALIDATION_FAILED    ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_dashInWrongPlace2",     false,   "1.-2",           "1.-2",          "1.-2",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_dashInWrongPlace3",     false,   "1.2-",           "1.2-",          "1.2-",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_doubleDot1",            false,   "..",             "..",            "..",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_doubleDot2",            false,   "1..2",           "1..2",          "1..2",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_FLOAT,   "noIgnore_negativeFloat_dotsEverywhere",        false,   ".1.2.",          ".1.2.",         ".1.2.",           Event.VALIDATION_FAILED  ),

   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_all",                   false,  "-" + Characters.NUMBERS_START_ZERO + "." + Characters.NUMBERS_END_ZERO,
                                                                                        "-" + Characters.NUMBERS_START_ZERO + "." + Characters.NUMBERS_END_ZERO,
                                                                                        "-" + Characters.NUMBERS_START_ZERO + "." + Characters.NUMBERS_END_ZERO,   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_bad",                   false,   "1.2a",          "1.2a",          "1.2a",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_posInt",                false,   "123",           "123",           "123",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_negInt",                false,   "-123",          "-123",          "-123",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_posFloat",              false,   "1023.456789",   "1023.456789",    "1023.456789",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_negFloat",              false,   "-1023.456789",  "-1023.456789",   "-1023.456789",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_zero1",                 false,   "0",             "0",              "0",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_zero2",                 false,   "0.0",           "0.0",            "0.0",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_leadingDoubleZero1",    false,   "00",            "00",             "00",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_leadingDoubleZero2",    false,   "00.0",          "00.0",          "00.0",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_extraTrailingZero1",    false,   "0.00",          "0.00",          "0.00",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_extraTrailingZero2",    false,   "12.3450",       "12.3450",       "12.3450",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_leadingDoubleZeros3",   false,   "-00.0",         "-00.0",         "-00.0",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_negativeZero1",         false,   "-0",            "-0",            "-0",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_negativeZero2",         false,   "-0.000000",     "-0.000000",     "-0.000000",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_negativeZero3",         false,   "-0.0",          "-0.0",          "-0.0",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_dash",                  false,   "-",             "-",             "-",                Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_doubleDash",            false,   "--",            "--",            "--",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_dashDot",               false,   "-.",            "-.",            "-.",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_endInDot",              false,   "-1.",           "-1.",           "-1.",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_dashInWrongPlace1",     false,   "1-.2",          "1-.2",          "1-.2",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_dashInWrongPlace2",     false,   "1.-2",          "1.-2",          "1.-2",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_dashInWrongPlace3",     false,   "1.2-",          "1.2-",          "1.2-",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_doubleDot1",            false,   "..",            "..",            "..",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_doubleDot2",            false,   "1..2",          "1..2",          "1..2",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_FLOAT,   "noIgnore_strictFloat_dotsEverywhere",        false,   ".1.2.",         ".1.2.",         ".1.2.",            Event.VALIDATION_FAILED  ),

   tc(  FieldType.STRICT_POSITIVE_FLOAT,  "noIgnore_strictPositiveFloat_all",                    false,   Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_END_ZERO,
                                                                                                          Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_END_ZERO,
                                                                                                          Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_END_ZERO,   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_bad",                   false,   "1.2a",          "1.2a",          "1.2a",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_posInt",                false,   "123",           "123",           "123",             Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_negInt",                false,   "-123",          "-123",          "-123",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_negFloat",              false,   "-1023.456789",  "-1023.456789",   "-1023.456789",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_zero1",                 false,   "0",             "0",             "0",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_zero2",                 false,   "0.0",           "0.0",           "0.0",             Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_zero3",                 false,   ".0",            ".0",            ".0",              Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_leadingZero1",          false,   "00",            "00",            "00",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_leadingZero2",          false,   "00.0",          "00.0",          "00.0",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_leadingZero3",          false,   "0123.456",      "0123.456",      "0123.456",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_extraTrailingZero1",    false,   "0.00",          "0.00",          "0.00",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_extraTrailingZero2",    false,   "12.3450",       "12.3450",       "12.3450",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_leadingDoubleZeros3",   false,   "00.0",          "00.0",          "00.0",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_negativeZero",          false,   "-0.0",          "-0.0",          "-0.0",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_dash",                  false,   "-",             "-",             "-",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_dashDot",               false,   ".",             ".",             ".",               Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_doubleDot1",            false,   "..",            "..",            "..",              Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_doubleDot2",            false,   "1..2",          "1..2",          "1..2",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_POSITIVE_FLOAT,   "noIgnore_strictPositiveFloat_dotsEverywhere",        false,   ".1.2.",         ".1.2.",         ".1.2.",           Event.VALIDATION_FAILED  ),

   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_all",                  false,    "-" + Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_END_ZERO,
                                                                                                          "-" + Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_END_ZERO,
                                                                                                          "-" + Characters.NUMBERS_END_ZERO + "." + Characters.NUMBERS_END_ZERO,   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_bad",                   false,   "-1.2a",      "-1.2a",      "-1.2a",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_posInt",                false,   "123",        "123",        "123",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_negInt",                false,   "-123",       "-123",       "-123",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_zero1",                 false,   "0",          "0",          "0",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_zero2",                 false,   "0.0",        "0.0",        "0.0",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_zero3",                 false,   ".0",         ".0",         ".0",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_leadingZero1",          false,   "00",         "00",         "00",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_leadingZero2",          false,   "00.0",       "00.0",       "00.0",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_leadingZero3",          false,   "0123.456",   "0123.456",   "0123.456",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_extraTrailingZero1",    false,   "0.00",       "0.00",       "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_extraTrailingZero2",    false,   "-12.3450",   "-12.3450",   "-12.3450",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_leadingDoubleZeros3",   false,   "-00.0",      "-00.0",      "-00.0",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_negativeZero",          false,   "-0.0",       "-0.0",       "-0.0",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_dash",                  false,   "-",          "-",          "-",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_dashDot",               false,   ".",          ".",          ".",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_doubleDot1",            false,   "..",         "..",         "..",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_doubleDot2",            false,   "1..2",       "1..2",       "1..2",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.STRICT_NEGATIVE_FLOAT,   "noIgnore_strictNegativeFloat_dotsEverywhere",        false,   ".1.2.",      ".1.2.",      ".1.2.",      Event.VALIDATION_FAILED  ),

   tc(  FieldType.MONEY,   "noIgnore_money_all",                   false,   Characters.ALL_EXCEPT_MINUS + ".01",
                                                                            Characters.ALL_EXCEPT_MINUS + ".01",
                                                                            Characters.ALL_EXCEPT_MINUS + ".01",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MONEY,   "noIgnore_money_all2",                  false,   Characters.NUMBERS_END_ZERO + ".01",
                                                                            Characters.NUMBERS_END_ZERO + ".01",
                                                                            Characters.NUMBERS_END_ZERO + ".01",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_blank",                 false,   "",             "",             "",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_space",                 false,   " ",            " ",            " ",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.MONEY,   "noIgnore_money_negInt",                false,   "-123",         "-123",         "-123.00",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_zero1",                 false,   "0",            "0",            "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_zero2",                 false,   "0.0",          "0.0",          "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_zero3",                 false,   ".0",           ".0",           "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_leadingZero1",          false,   "00",           "00",           "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_leadingZero2",          false,   "00.0",         "00.0",         "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_leadingZero3",          false,   "0123.456",     "0123.456",     "0123.456",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MONEY,   "noIgnore_money_leadingZero4",          false,   "0123.45",      "0123.45",      "123.45",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_leadingZero5",          false,   "-0123.45",     "-0123.45",     "-123.45",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_leadingZero6",          false,   "-000123.45",   "-000123.45",   "-123.45",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_extraTrailingZero1",    false,   "0.00",         "0.00",         "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_extraTrailingZero2",    false,   "12.3450",      "12.3450",      "12.3450",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.MONEY,   "noIgnore_money_leadingDoubleZeros3",   false,   "-00.0",        "-00.0",        "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_negativeZero",          false,   "-0.000000",    "-0.000000",    "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_dash",                  false,   "-",            "-",            "-",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.MONEY,   "noIgnore_money_dashDot",               false,   ".",            ".",            ".",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.MONEY,   "noIgnore_money_doubleDot1",            false,   "..",           "..",           "..",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.MONEY,   "noIgnore_money_doubleDot2",            false,   "-1..2",        "-1..2",        "-1..2",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.MONEY,   "noIgnore_money_dotsEverywhere",        false,   "-.1.2.",       "-.1.2.",       "-.1.2.",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.MONEY,   "noIgnore_money_nothingAfterDot",       false,   "1.",           "1.",           "1.",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.MONEY,   "noIgnore_money_letter1",               false,   "1.a",          "1.a",          "1.a",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.MONEY,   "noIgnore_money_1",                     false,   ".2",           ".2",           "0.20",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_2",                     false,   ".20",          ".20",          "0.20",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_3",                     false,   "0.2",          "0.2",          "0.20",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_4",                     false,   "0.20",         "0.20",         "0.20",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_5",                     false,   "1.2",          "1.2",          "1.20",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_6",                     false,   "1.23",         "1.23",         "1.23",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_7",                     false,   "-.2",          "-.2",          "-0.20",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.MONEY,   "noIgnore_money_8",                     false,   "-0.2",         "-0.2",         "-0.20",      Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_all",                   false,   Characters.ALL_EXCEPT_MINUS + "." + "01",
                                                                                             Characters.ALL_EXCEPT_MINUS + ".01",
                                                                                             Characters.ALL_EXCEPT_MINUS + ".01",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_all2",                  false,   Characters.NUMBERS_END_ZERO + "." + "01",
                                                                                             Characters.NUMBERS_END_ZERO + ".01",
                                                                                             Characters.NUMBERS_END_ZERO + ".01",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_blank",                 false,   "",            "",            "",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_space",                 false,   " ",           " ",           " ",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_negInt",                false,   "-123",        "-123",        "-123",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_zero1",                 false,   "0",           "0",           "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_zero2",                 false,   "0.0",         "0.0",         "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_zero3",                 false,   ".0",          ".0",          "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_leadingZero1",          false,   "00",          "00",          "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_leadingZero2",          false,   "00.0",        "00.0",        "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_leadingZero3",          false,   "0123.456",    "0123.456",    "0123.456",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_leadingZero4",          false,   "0123.45",     "0123.45",     "123.45",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_leadingZero5",          false,   "000123.45",   "000123.45",   "123.45",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_zeroDotZeroZero",       false,   "0.00",        "0.00",        "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_extraTrailingDigits",   false,   "12.3450",     "12.3450",     "12.3450",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_leadingDoubleZeros",    false,   "00.0",        "00.0",        "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_extraTrailingZeros",    false,   "-0.000000",   "-0.000000",   "0.00",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_dash",                  false,   "-",           "-",           "-",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_dashDot",               false,   ".",           ".",           ".",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_doubleDot1",            false,   "..",          "..",          "..",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_doubleDot2",            false,   "1..2",        "1..2",        "1..2",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_dotsEverywhere",        false,   ".1.2.",       ".1.2.",       ".1.2.",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_PositiveMoney_nothingAfterDot",       false,   "1.",          "1.",          "1.",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_letter1",               false,   "1.a",         "1.a",         "1.a",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_1",                     false,   ".2",          ".2",          "0.20",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_2",                     false,   ".20",         ".20",         "0.20",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_3",                     false,   "0.2",         "0.2",         "0.20",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_4",                     false,   "0.20",        "0.20",        "0.20",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_5",                     false,   "1.2",         "1.2",         "1.20",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_6",                     false,   "1.23",        "1.23",        "1.23",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.POSITIVE_MONEY,   "noIgnore_positiveMoney_8",                     false,   "0.2",         "0.2",         "0.20",       Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_all",                   false,   "-" + Characters.ALL_EXCEPT_MINUS + "." + "01",
                                                                                             "-" + Characters.ALL_EXCEPT_MINUS + ".01",
                                                                                             "-" + Characters.ALL_EXCEPT_MINUS + ".01",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_all2",                  false,   "-" + Characters.NUMBERS_END_ZERO + "." + "01",
                                                                                                                 "-" + Characters.NUMBERS_END_ZERO + ".01",
                                                                                                                 "-" + Characters.NUMBERS_END_ZERO + ".01",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_blank",                 false,   "",             "",             "",            Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_space",                 false,   " ",            " ",            " ",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_negInt",                false,   "-123",         "-123",         "-123.00",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_posInt",                false,   "123",          "123",          "123",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_zero1",                 false,   "0",            "0",            "0.00",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_zero2",                 false,   "0.0",          "0.0",          "0.00",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_zero3",                 false,   ".0",           ".0",           "0.00",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_leadingZero1",          false,   "00",           "00",           "0.00",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_leadingZero2",          false,   "00.0",         "00.0",         "0.00",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_leadingZero3",          false,   "-0123.456",    "-0123.456",    "-0123.456",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_leadingZero4",          false,   "-0123.45",     "-0123.45",     "-123.45",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_leadingZero5",          false,   "-000123.45",   "-000123.45",   "-123.45",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_zeroDotZeroZero",       false,   "-0.00",        "-0.00",        "0.00",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_extraTrailingDigits",   false,   "-12.3450",     "-12.3450",     "-12.3450",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_leadingDoubleZeros",    false,   "00.0",         "00.0",         "0.00",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_extraTrailingZeros",    false,   "0.000000",     "0.000000",     "0.00",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_dash",                  false,   "-",            "-",            "-",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_dashDot",               false,   ".",            ".",            ".",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_doubleDot1",            false,   "..",           "..",           "..",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_doubleDot2",            false,   "-1..2",        "-1..2",        "-1..2",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_dotsEverywhere",        false,   "-.1.2.",       "-.1.2.",       "-.1.2.",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_nothingAfterDot",       false,   "1.",           "1.",           "1.",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_letter1",               false,   "-1.a",         "-1.a",         "-1.a",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_1",                     false,    "-.2",         "-.2",          "-0.20",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_2",                     false,   "-.20",         "-.20",         "-0.20",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_3",                     false,   "-0.2",         "-0.2",         "-0.20",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_4",                     false,   "-0.20",        "-0.20",        "-0.20",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_5",                     false,   "-1.2",         "-1.2",         "-1.20",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_6",                     false,   "-1.23",        "-1.23",        "-1.23",       Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_MONEY,   "noIgnore_negativeMoney_8",                     false,   "-0.2",         "-0.2",         "-0.20",       Event.VALIDATION_SUCCESS  ),

   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_all",                   false,   "(" + Characters.ALPHANUMERIC + Characters.SYMBOLS_EXCEPT_PARENS + "." + Characters.NUMBERS_END_ZERO + ")",
                                                                                                                  "(" + Characters.ALPHANUMERIC + Characters.SYMBOLS_EXCEPT_PARENS + "." + Characters.NUMBERS_END_ZERO + ")",
                                                                                                                  "(" + Characters.ALPHANUMERIC + Characters.SYMBOLS_EXCEPT_PARENS + "." + Characters.NUMBERS_END_ZERO + ")",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_space",                 false,   " ",           " ",          " ",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_dash",                  false,   "-",           "-",          "-",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_negInt",                false,   "(123)",       "(123)",      "(123.00)",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_posInt",                false,   "123",         "123",        "123",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_posFloat1",             false,   "1.23",        "1.23",       "1.23",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_posFloat2",             false,   "1.2",         "1.2",        "1.2",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_zero1",                 false,   "0",           "0",          "0.00",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_zero2",                 false,   "0.0",         "0.0",        "0.00",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_zero3",                 false,   ".0",          ".0",         "0.00",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_leadingZero1",          false,   "00",          "00",         "0.00",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_leadingZero2",          false,   "00.0",        "00.0",       "0.00",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_leadingZero3",          false,   "(0123.456)",  "(0123.456)", "(0123.456)",  Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_extraTrailingZeros1",   false,   "0.000000",    "0.000000",   "0.00",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_extraTrailingZeros2",   false,   "(0.000000)",  "(0.000000)", "0.00",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_dashDot",               false,   ".",           ".",          ".",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_doubleDot1",            false,   "..",          "..",         "..",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_doubleDot2",            false,   "(1..2)",      "(1..2)",     "(1..2)",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_dotsEverywhere",        false,   "(.1.2.)",     "(.1.2.)",    "(.1.2.)",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_letter1",               false,   "(1.a)",       "(1.a)",      "(1.a)",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_1",                     false,   "(.2)",        "(.2)",       "(0.20)",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_2",                     false,   "(.20)",       "(.20)",      "(0.20)",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_3",                     false,   "(0.2)",       "(0.2)",      "(0.20)",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_4",                     false,   "(0.20)",      "(0.20)",     "(0.20)",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_5",                     false,   "(1.2)",       "(1.2)",      "(1.20)",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_6",                     false,   "(1.23)",      "(1.23)",     "(1.23)",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_noClosingParen",        false,   "(1.23",       "(1.23",      "(1.23",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_noOpeningParen",        false,   "1.23)",       "1.23)",      "1.23)",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_nonDigit1",             false,   "1.a",         "1.a",        "1.a",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.NEGATIVE_ACCOUNTING_MONEY,   "noIgnore_negativeAccountingMoney_nonDigit2",             false,   "(1.a",        "(1.a",       "(1.a",        Event.VALIDATION_FAILED  ),

   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_prefix34_length15",               false,   "342466101232205",         "342466101232205",         "342466101232205",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_prefix37_length15",               false,   "376766541844884",         "376766541844884",         "376766541844884",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_prefix34_invalidLength14",        false,   "34351314365583",          "34351314365583",          "34351314365583",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_prefix34_invalidLength16",        false,   "3418170037118164",        "3418170037118164",        "3418170037118164",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_prefix37_invalidLength14",        false,   "37124610876877",          "37124610876877",          "37124610876877",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_prefix37_invalidLength16",        false,   "3731310754648247",        "3731310754648247",        "3731310754648247",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_prefix34_length15_invalidChars",  false,   "a#- 34246610G1232_205$",  "a#- 34246610G1232_205$",  "a#- 34246610G1232_205$",  Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix1",                  false,   "110533335310535",         "110533335310535",         "110533335310535",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix2",                  false,   "235384710700605",         "235384710700605",         "235384710700605",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix30",                 false,   "305821522055038",         "305821522055038",         "305821522055038",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix31",                 false,   "310554515025436",         "310554515025436",         "310554515025436",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix32",                 false,   "323285216278850",         "323285216278850",         "323285216278850",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix33",                 false,   "334661661140844",         "334661661140844",         "334661661140844",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix35",                 false,   "358455622458127",         "358455622458127",         "358455622458127",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix36",                 false,   "367742827400114",         "367742827400114",         "367742827400114",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix38",                 false,   "381850360004201",         "381850360004201",         "381850360004201",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix39",                 false,   "392105252864684",         "392105252864684",         "392105252864684",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix4",                  false,   "423665854673869",         "423665854673869",         "423665854673869",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix5",                  false,   "561612036607649",         "561612036607649",         "561612036607649",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix6",                  false,   "611317481740537",         "611317481740537",         "611317481740537",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix7",                  false,   "712036268735837",         "712036268735837",         "712036268735837",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix8",                  false,   "883583531758248",         "883583531758248",         "883583531758248",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix9",                  false,   "918467501545034",         "918467501545034",         "918467501545034",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.AMERICAN_EXPRESS,   "noIgnore_americanExpress_invalidPrefix0",                  false,   "052877548455029",         "052877548455029",         "052877548455029",         Event.VALIDATION_FAILED  ),

   // Begin invalid length check
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix6011_invalidLength15",       false,    "601113250018169",        "601113250018169",       "601113250018169",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix6011_invalidLength17",       false,    "60115061515701181",      "60115061515701181",     "60115061515701181",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix6011_invalidLength18",       false,    "601153441648503411",     "601153441648503411",    "601153441648503411",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix6011_invalidLength20",       false,    "60116551331382308537",   "60116551331382308537",  "60116551331382308537",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix622126_invalidLength15",     false,    "622126004380672",        "622126004380672",       "622126004380672",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix622126_invalidLength17",     false,    "62212641866873586",      "62212641866873586",     "62212641866873586",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix622126_invalidLength18",     false,    "622126126327675339",     "622126126327675339",    "622126126327675339",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix622126_invalidLength20",     false,    "62212687126061620224",   "62212687126061620224",  "62212687126061620224",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix644_invalidLength15",        false,    "644756606387446",        "644756606387446",       "644756606387446",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix644_invalidLength17",        false,    "64450658852328034",      "64450658852328034",     "64450658852328034",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix644_invalidLength18",        false,    "644738072107280359",     "644738072107280359",    "644738072107280359",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix644_invalidLength20",        false,    "64402134217085608883",   "64402134217085608883",  "64402134217085608883",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix645_invalidLength15",        false,    "645325137238525",        "645325137238525",       "645325137238525",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix645_invalidLength17",        false,    "64517041878408406",      "64517041878408406",     "64517041878408406",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix645_invalidLength18",        false,    "645171642626304087",     "645171642626304087",    "645171642626304087",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix645_invalidLength20",        false,    "64524161408182660722",   "64524161408182660722",  "64524161408182660722",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix646_invalidLength15",        false,    "646614811810553",        "646614811810553",       "646614811810553",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix646_invalidLength17",        false,    "64617426406243319",      "64617426406243319",     "64617426406243319",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix646_invalidLength18",        false,    "646630860588643713",     "646630860588643713",    "646630860588643713",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix646_invalidLength20",        false,    "64653583267408667474",   "64653583267408667474",  "64653583267408667474",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix647_invalidLength15",        false,    "647002003326407",        "647002003326407",       "647002003326407",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix647_invalidLength17",        false,    "64748211504450301",      "64748211504450301",     "64748211504450301",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix647_invalidLength18",        false,    "647881170248165527",     "647881170248165527",    "647881170248165527",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix647_invalidLength20",        false,    "64728284687165554189",   "64728284687165554189",  "64728284687165554189",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix648_invalidLength15",        false,    "648385588347065",        "648385588347065",       "648385588347065",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix648_invalidLength17",        false,    "64845326563124159",      "64845326563124159",     "64845326563124159",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix648_invalidLength18",        false,    "648255783171775421",     "648255783171775421",    "648255783171775421",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix648_invalidLength20",        false,    "64878048725744221688",   "64878048725744221688",  "64878048725744221688",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix649_invalidLength15",        false,    "649274143307286",        "649274143307286",       "649274143307286",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix649_invalidLength17",        false,    "64920403303634447",      "64920403303634447",     "64920403303634447",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix649_invalidLength18",        false,    "649438660560073667",     "649438660560073667",    "649438660560073667",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix649_invalidLength20",        false,    "64966668531581488089",   "64966668531581488089",  "64966668531581488089",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix65_invalidLength15",         false,    "658827080321400",        "658827080321400",       "658827080321400",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix65_invalidLength17",         false,    "65166676311003586",      "65166676311003586",     "65166676311003586",      Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix65_invalidLength18",         false,    "655527725847521157",     "655527725847521157",    "655527725847521157",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnore_discover_prefix65_invalidLength20",         false,    "65386161762781287755",   "65386161762781287755",  "65386161762781287755",   Event.VALIDATION_FAILED  ),
   // End invalid length check
   // Begin invalid chars check
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_prefix6011_length16_invalidChars",    false,   "b60t1130%70044;82082_+",   "b60t1130%70044;82082_+",   "b60t1130%70044;82082_+",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_prefix622644_length16_invlaidChars",  false,   "@6226x44711%8125]50o7",    "@6226x44711%8125]50o7",    "@6226x44711%8125]50o7",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_prefix65_length16_invalidChars",      false,   "65-754464'1768F4229!",     "65-754464'1768F4229!",     "65-754464'1768F4229!",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_prefix644_length16_invalidChars",     false,   "6L44608^675k740504m6",     "6L44608^675k740504m6",     "6L44608^675k740504m6",     Event.VALIDATION_FAILED  ),
   // End invalid chars check
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix1",                      false,   "1470336445841148",         "1470336445841148",   "1470336445841148",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix2",                      false,   "2331184710706670",         "2331184710706670",   "2331184710706670",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix3",                      false,   "3407166401078268",         "3407166401078268",   "3407166401078268",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix4",                      false,   "4712231176638155",         "4712231176638155",   "4712231176638155",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix5",                      false,   "5030181551316434",         "5030181551316434",   "5030181551316434",   Event.VALIDATION_FAILED  ),
   // Begin check of 6011
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix6010",                   false,   "6010110872853363",         "6010110872853363",   "6010110872853363",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix6012",                   false,   "6012136762285265",         "6012136762285265",   "6012136762285265",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix6013",                   false,   "6013415673133130",         "6013415673133130",   "6013415673133130",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix6014",                   false,   "6014317653573724",         "6014317653573724",   "6014317653573724",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix6015",                   false,   "6015106588356738",         "6015106588356738",   "6015106588356738",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix6016",                   false,   "6016233133477311",         "6016233133477311",   "6016233133477311",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix6017",                   false,   "6017724412487350",         "6017724412487350",   "6017724412487350",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix6018",                   false,   "6018331363865573",         "6018331363865573",   "6018331363865573",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix6019",                   false,   "6019611518210083",         "6019611518210083",   "6019611518210083",   Event.VALIDATION_FAILED  ),
   // End of check 6011
   // Begin check of 622126-622925
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix620",                    false,   "6206262740660753",         "6206262740660753",   "6206262740660753",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix621",                    false,   "6217652406406102",         "6217652406406102",   "6217652406406102",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix6220",                   false,   "6220300714742728",         "6220300714742728",   "6220300714742728",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix62210",                  false,   "6221025426011588",         "6221025426011588",   "6221025426011588",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix62211",                  false,   "6221120034581617",         "6221120034581617",   "6221120034581617",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix622121",                 false,   "6221210187238360",         "6221210187238360",   "6221210187238360",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix622122",                 false,   "6221228502235002",         "6221228502235002",   "6221228502235002",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix622123",                 false,   "6221237772553432",         "6221237772553432",   "6221237772553432",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix622124",                 false,   "6221240062530235",         "6221240062530235",   "6221240062530235",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix622125",                 false,   "6221258114221504",         "6221258114221504",   "6221258114221504",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix622926",                 false,   "6229262456808243",         "6229262456808243",   "6229262456808243",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix622927",                 false,   "6229275708688189",         "6229275708688189",   "6229275708688189",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix622928",                 false,   "6229284038808277",         "6229284038808277",   "6229284038808277",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix622929",                 false,   "6229294830633831",         "6229294830633831",   "6229294830633831",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix62293",                  false,   "6229306107813720",         "6229306107813720",   "6229306107813720",   Event.VALIDATION_FAILED  ),
   // End check of 622126-622925
   // Begin check of 644-649
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix640",                    false,   "6403463407714013",         "6403463407714013",   "6403463407714013",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix641",                    false,   "6410467716531720",         "6410467716531720",   "6410467716531720",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix642",                    false,   "6420558280431152",         "6420558280431152",   "6420558280431152",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix643",                    false,   "6438758550731345",         "6438758550731345",   "6438758550731345",   Event.VALIDATION_FAILED  ),
   // End check of 644-649
   // Begin check of 65
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix61",                    false,   "6131460445268019",          "6131460445268019",   "6131460445268019",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix63",                    false,   "6368248412255745",          "6368248412255745",   "6368248412255745",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix66",                    false,   "6606200217844142",          "6606200217844142",   "6606200217844142",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix67",                    false,   "6782716743078364",          "6782716743078364",   "6782716743078364",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix68",                    false,   "6823557574621851",          "6823557574621851",   "6823557574621851",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix69",                    false,   "6923884463143584",          "6923884463143584",   "6923884463143584",   Event.VALIDATION_FAILED  ),
   // End check of 65
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix7",                     false,   "7835078042573057",          "7835078042573057",   "7835078042573057",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix8",                     false,   "8671618203021183",          "8671618203021183",   "8671618203021183",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix9",                     false,   "9133348252506245",          "9133348252506245",   "9133348252506245",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.DISCOVER,   "noIgnoreDiscover_invalidPrefix0",                     false,   "0502622771555244",          "0502622771555244",   "0502622771555244",   Event.VALIDATION_FAILED  ),

   // Begin invalid length check
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix51_invalidLength15",          false,   "518426704611088",          "518426704611088",     "518426704611088",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix51_invalidLength17",          false,   "51328637405243756",        "51328637405243756",   "51328637405243756",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix52_invalidLength15",          false,   "521054153757767",          "521054153757767",     "521054153757767",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix52_invalidLength17",          false,   "52644131212736785",        "52644131212736785",   "52644131212736785",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix53_invalidLength15",          false,   "535601544067753",          "535601544067753",     "535601544067753",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix53_invalidLength17",          false,   "53454121683377109",        "53454121683377109",   "53454121683377109",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix54_invalidLength15",          false,   "546633663170024",          "546633663170024",     "546633663170024",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix54_invalidLength17",          false,   "54631086273232861",        "54631086273232861",   "54631086273232861",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix55_invalidLength15",          false,   "551424704848014",          "551424704848014",     "551424704848014",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix55_invalidLength17",          false,   "55073621202282553",        "55073621202282553",   "55073621202282553",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix2221_invalidLength15",        false,   "222103615153214",          "222103615153214",     "222103615153214",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix2221_invalidLength17",        false,   "55073621202282553",        "55073621202282553",   "55073621202282553",   Event.VALIDATION_FAILED  ),
   // End invalid length check
   // Begin invalid chars check
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix51_length16_invalidChars",    false,   "a51X3560$7880.62130]4",    "a51X3560$7880.62130]4",   "a51X3560$7880.62130]4",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix52_length16_invalidChars",    false,   "52!178;0125301453[3",      "52!178;0125301453[3",     "52!178;0125301453[3",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix53_length16_invalidChars",    false,   "5b3B4304=3472540 777",     "5b3B4304=3472540 777",    "5b3B4304=3472540 777",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix54_length16_invalidChars",    false,   "5451-3472-2482-8804",      "5451-3472-2482-8804",     "5451-3472-2482-8804",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix55_length16_invalidChars",    false,   "55u^74045605155753 ",      "55u^74045605155753 ",     "55u^74045605155753 ",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_prefix2221_length16_invalidChars",  false,   "22:21266)6060R774o24",     "22:21266)6060R774o24",    "22:21266)6060R774o24",    Event.VALIDATION_FAILED  ),
   // End invalid chars check
   // Begin check of 2221
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix20",     false,   "2030812372066660",   "2030812372066660",   "2030812372066660",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix21",     false,   "2106307611231448",   "2106307611231448",   "2106307611231448",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix220",    false,   "2203030823445034",   "2203030823445034",   "2203030823445034",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix221",    false,   "2213682873071314",   "2213682873071314",   "2213682873071314",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix2220",   false,   "2220408416600273",   "2220408416600273",   "2220408416600273",   Event.VALIDATION_FAILED  ),
   // End check of 2221
   // Begin check of 2720
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix2721",   false,   "2721238631335809",   "2721238631335809",   "2721238631335809",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix2722",   false,   "2722531040230002",   "2722531040230002",   "2722531040230002",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix2723",   false,   "2723313138867717",   "2723313138867717",   "2723313138867717",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix2724",   false,   "2724718331221430",   "2724718331221430",   "2724718331221430",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix2725",   false,   "2725648551032515",   "2725648551032515",   "2725648551032515",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix2726",   false,   "2726380750672250",   "2726380750672250",   "2726380750672250",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix2727",   false,   "2727118060501382",   "2727118060501382",   "2727118060501382",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix2728",   false,   "2728044225263651",   "2728044225263651",   "2728044225263651",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix2729",   false,   "2729775837166753",   "2729775837166753",   "2729775837166753",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix273",    false,   "2734756154516641",   "2734756154516641",   "2734756154516641",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix28",     false,   "2863756772643044",   "2863756772643044",   "2863756772643044",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix29",     false,   "2957534277228489",   "2957534277228489",   "2957534277228489",   Event.VALIDATION_FAILED  ),
   // End check of 2720
   // Begin blatantly wrong prefix check
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix1",      false,   "1605245848825848",   "1605245848825848",   "1605245848825848",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix3",      false,   "3666013168163600",   "3666013168163600",   "3666013168163600",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix4",      false,   "4566612656551553",   "4566612656551553",   "4566612656551553",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix6",      false,   "6548487325884463",   "6548487325884463",   "6548487325884463",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix7",      false,   "7248126431710417",   "7248126431710417",   "7248126431710417",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix8",      false,   "8641488077660210",   "8641488077660210",   "8641488077660210",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix9",      false,   "9277072425886062",   "9277072425886062",   "9277072425886062",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.MASTERCARD,   "noIgnore_masterCard_invalidPrefix0",      false,   "0454145386713147",   "0454145386713147",   "0454145386713147",   Event.VALIDATION_FAILED  ),
   // End blatantly wrong prefix check

   // Begin invalid length check
   tc(  FieldType.VISA,   "noIgnore_visa_prefix4_length12",   false,   "427815235648",           "427815235648",          "427815235648",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,   "noIgnore_visa_prefix4_length14",   false,   "45842811557182",         "45842811557182",        "45842811557182",        Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,   "noIgnore_visa_prefix4_length15",   false,   "438740434546761",        "438740434546761",       "438740434546761",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,   "noIgnore_visa_prefix4_length17",   false,   "43487538814261138",      "43487538814261138",     "43487538814261138",     Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,   "noIgnore_visa_prefix4_length18",   false,   "421431601867875553",     "421431601867875553",    "421431601867875553",    Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,   "noIgnore_visa_prefix4_length20",   false,   "43213753745312750349",   "43213753745312750349",  "43213753745312750349",  Event.VALIDATION_FAILED  ),
   // End invalid length check
   // Begin invalid chars check
   tc(  FieldType.VISA,   "noIgnore_visa_prefix4_length13_invalidChars",   false,   "4455-0674-44713",   "4455-0674-44713",   "4455-0674-44713",  Event.VALIDATION_FAILED  ),
   // End invalid chars check
   // Begin wrong prefix check
   tc(  FieldType.VISA,   "noIgnore_visa_invalidPrefix1",     false,   "1605245848825848",   "1605245848825848",   "1605245848825848",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,   "noIgnore_visa_invalidPrefix2",     false,   "2470338735648223",   "2470338735648223",   "2470338735648223",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,   "noIgnore_visa_invalidPrefix3",     false,   "3666013168163600",   "3666013168163600",   "3666013168163600",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,   "noIgnore_visa_invalidPrefix5",     false,   "5781802805381236",   "5781802805381236",   "5781802805381236",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,   "noIgnore_visa_invalidPrefix6",     false,   "6548487325884463",   "6548487325884463",   "6548487325884463",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,   "noIgnore_visa_invalidPrefix7",     false,   "7248126431710417",   "7248126431710417",   "7248126431710417",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,   "noIgnore_visa_invalidPrefix8",     false,   "8641488077660210",   "8641488077660210",   "8641488077660210",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,   "noIgnore_visa_invalidPrefix9",     false,   "9277072425886062",   "9277072425886062",   "9277072425886062",   Event.VALIDATION_FAILED  ),
   tc(  FieldType.VISA,   "noIgnore_visa_invalidPrefix0",     false,   "0454145386713147",   "0454145386713147",   "0454145386713147",   Event.VALIDATION_FAILED  ),
   // End wrong prefix check

   tc(  FieldType.US_ZIP,   "noIgnore_usZip_1digit",            false,   "1",            "1",            "1",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP,   "noIgnore_usZip_2digits",           false,   "12",           "12",           "12",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP,   "noIgnore_usZip_3digits",           false,   "123",          "123",          "123",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP,   "noIgnore_usZip_4digits",           false,   "1234",         "1234",         "1234",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP,   "noIgnore_usZip_5digits",           false,   "12345",        "12345",        "12345",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP,   "noIgnore_usZip_6digitsNoHyphen",   false,   "123456",       "123456",       "123456",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP,   "noIgnore_usZip_6digits",           false,   "12345-6",      "12345-6",      "12345-6",      Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP,   "noIgnore_usZip_7digits",           false,   "12345-67",     "12345-67",     "12345-67",     Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP,   "noIgnore_usZip_8digits",           false,   "12345-678",    "12345-678",    "12345-678",    Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP,   "noIgnore_usZip_9digits",           false,   "12345-6789",   "12345-6789",   "12345-6789",   Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP,   "noIgnore_usZip_invalidChars",      false,   "1-2 3d4.5$",   "1-2 3d4.5$",   "1-2 3d4.5$",   Event.VALIDATION_FAILED  ),

   tc(  FieldType.US_ZIP5,   "noIgnore_usZip5_1digit",         false,   "1",            "1",            "1",            Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP5,   "noIgnore_usZip5_2digits",        false,   "12",           "12",           "12",           Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP5,   "noIgnore_usZip5_3digits",        false,   "123",          "123",          "123",          Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP5,   "noIgnore_usZip5_4digits",        false,   "1234",         "1234",         "1234",         Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP5,   "noIgnore_usZip5_5digits",        false,   "12345",        "12345",        "12345",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP5,   "noIgnore_usZip5_6digits",        false,   "123456",       "123456",       "123456",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP5,   "noIgnore_usZip5_invalidChars",   false,   "1-2 3d4.5$",   "1-2 3d4.5$",   "1-2 3d4.5$",   Event.VALIDATION_FAILED  ),

   tc(  FieldType.US_ZIP_SUFFIX,   "noIgnore_usZipSuffix_1digit",        false,   "1",           "1",           "1",           Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP_SUFFIX,   "noIgnore_usZipSuffix_2digits",       false,   "12",          "12",          "12",          Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP_SUFFIX,   "noIgnore_usZipSuffix_3digits",       false,   "123",         "123",         "123",         Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP_SUFFIX,   "noIgnore_usZipSuffix_4digits",       false,   "1234",        "1234",        "1234",        Event.VALIDATION_SUCCESS  ),
   tc(  FieldType.US_ZIP_SUFFIX,   "noIgnore_usZipSuffix_5digits",       false,   "12345",       "12345",       "12345",       Event.VALIDATION_FAILED  ),
   tc(  FieldType.US_ZIP_SUFFIX,   "noIgnore_usZipSuffix_invalidChars",  false,   "1-2 3d4.$",   "1-2 3d4.$",   "1-2 3d4.$",   Event.VALIDATION_FAILED  )
];

/** Creates a test case */
function tc( fieldType, title, preventInvalidInput, input, expectedValueBeforeBlur, expectedValueAfterBlur, expectedEventOnBlur ) {
   if( fieldType == null || fieldType == undefined ) throw "Test [" + title + "] has no fieldType - perhaps a typo in the FieldType member name?";
   if( title == null || title == undefined || title === "" ) throw "Test has no name";
   if( input == null || input == undefined ) throw "Test [" + title + "] has no input.  If this was intentional, use empty string.";
   if( expectedValueBeforeBlur == null || expectedValueBeforeBlur == undefined ) throw "Test [" + title + "] has no expectedValueBeforeBlur.  If this was intentional, use empty string.";
   if( expectedValueAfterBlur == null || expectedValueAfterBlur == undefined ) throw "Test [" + title + "] has no expectedValueAfterBlur.  If this was intentional, use empty string.";
   if( expectedEventOnBlur == null || expectedEventOnBlur == undefined ) throw "Test [" + title + "] has no expected event - perhaps a typo in the Event name?";

   if( !preventInvalidInput && expectedValueBeforeBlur !== input ) {
      throw "Tests that allow invalid input can't have the input change pre-blur: " + title;
      // Note, however, that if it's a money type, it can change POST-blur due to automatic formatting
   }

   return {
      fieldType               : fieldType,
      title                   : title,
      preventInvalidInput     : preventInvalidInput,
      input                   : input,
      expectedValueBeforeBlur : expectedValueBeforeBlur,
      expectedValueAfterBlur  : expectedValueAfterBlur,
      expectedEventOnBlur     : expectedEventOnBlur
   };
}

function validateTestCases( tests ) {
   // Check the test cases for duplicate test names

   for( var i = 0; i < tests.length; i++ ) {
      var name = tests[i].title;

      for( var j = i + 1; j < tests.length; j++ ) {
         var name2 = tests[j].title;

         if( name.toLowerCase() === name2.toLowerCase() ) {
            throw "Duplicate test name (case-insensitive): " + name;
         }
      }
   }

   return true;
}
